@@ -6,6 +6,8 @@
 #include "bionics.h"
 #include "line.h"
 
+#define BATTERY_AMOUNT 4 // How much batteries increase your power
+
 void bionics_install_failure(game *g, player *u, int success);
 
 
@@ -303,6 +305,7 @@ void player::activate_bionic(int b, game *g)
      else
       traj = line_to(i, j, posx, posy, 0);
     }
+    traj.insert(traj.begin(), point(i, j));
     for (int k = 0; k < g->m.i_at(i, j).size(); k++) {
      if (g->m.i_at(i, j)[k].made_of(IRON) || g->m.i_at(i, j)[k].made_of(STEEL)){
       tmp_item = g->m.i_at(i, j)[k];
@@ -310,13 +313,12 @@ void player::activate_bionic(int b, game *g)
       for (l = 0; l < traj.size(); l++) {
        index = g->mon_at(traj[l].x, traj[l].y);
        if (index != -1) {
-        if (g->z[index].hurt(tmp_item.weight() * tmp_item.volume()))
+        if (g->z[index].hurt(tmp_item.weight() * 2))
          g->kill_mon(index);
         g->m.add_item(traj[l].x, traj[l].y, tmp_item);
         l = traj.size() + 1;
        } else if (l > 0 && g->m.move_cost(traj[l].x, traj[l].y) == 0) {
-        g->m.bash(traj[l].x, traj[l].y, tmp_item.weight() * tmp_item.volume(),
-                  junk);
+        g->m.bash(traj[l].x, traj[l].y, tmp_item.weight() * 2, junk);
         g->sound(traj[l].x, traj[l].y, 12, junk);
         if (g->m.move_cost(traj[l].x, traj[l].y) == 0) {
          g->m.add_item(traj[l - 1].x, traj[l - 1].y, tmp_item);
@@ -419,7 +421,7 @@ bool player::install_bionics(game *g, it_bionic* type)
  wrefresh(w);
 
  if (type->id == itm_bionics_battery) {	// No selection list; just confirm
-  mvwprintz(w,  2, 0, h_ltblue, "Battery Level +10");
+  mvwprintz(w,  2, 0, h_ltblue, "Battery Level +%d", BATTERY_AMOUNT);
   mvwprintz(w, 22, 0, c_ltblue, "\
 Installing this bionic will increase your total battery capacity by 10.\n\
 Batteries are necessary for most bionics to function.  They also require a\n\
@@ -433,7 +435,7 @@ charge mechanism, which must be installed from another CBM.");
    int success = chance_of_success - rng(1, 100);
    if (success > 0) {
     g->add_msg("Successfully installed batteries.");
-    max_power_level += 10;
+    max_power_level += BATTERY_AMOUNT;
    } else
     bionics_install_failure(g, this, success);
    werase(w);
