@@ -159,7 +159,7 @@ bool computer::hack_attempt(player *p, int Security)
  if (Security == -1)
   Security = security; // Set to main system security if no value passed
 
- p->practice(sk_computer, Security * 2);
+ p->practice(sk_computer, 5 + Security * 2);
  int player_roll = p->sklevel[sk_computer];
  if (p->int_cur < 8 && one_in(2))
   player_roll -= rng(0, 8 - p->int_cur);
@@ -358,7 +358,6 @@ void computer::activate_function(game *g, computer_action action)
      if (tmp.find_first_of('%') == 0)
       choice--;
     }
-    bool get_okay;
     getline(fin, tmp);
     do {
      lines++;
@@ -391,6 +390,28 @@ void computer::activate_function(game *g, computer_action action)
    print_line("Surface map data downloaded.");
   } break;
 
+  case COMPACT_MAP_SEWER: {
+   int minx = int(g->levx / 2) - 60;
+   int maxx = int(g->levx / 2) + 60;
+   int miny = int(g->levy / 2) - 60;
+   int maxy = int(g->levy / 2) + 60;
+   if (minx < 0)             minx = 0;
+   if (maxx >= OMAPX) maxx = OMAPX - 1;
+   if (miny < 0)             miny = 0;
+   if (maxy >= OMAPY) maxy = OMAPY - 1;
+   overmap tmp(g, g->cur_om.posx, g->cur_om.posy, g->cur_om.posz);
+   for (int i = minx; i <= maxx; i++) {
+    for (int j = miny; j <= maxy; j++)
+     if ((tmp.ter(i, j) >= ot_sewer_ns && tmp.ter(i, j) <= ot_sewer_nesw) || 
+         (tmp.ter(i, j) >= ot_sewage_treatment &&
+          tmp.ter(i, j) <= ot_sewage_treatment_under))
+     tmp.seen(i, j) = true;
+   }
+   tmp.save(g->u.name, g->cur_om.posx, g->cur_om.posy, 0);
+   print_line("Sewage map data downloaded.");
+  } break;
+
+
   case COMPACT_MISS_LAUNCH: {
    overmap tmp_om(g, g->cur_om.posx, g->cur_om.posy, 0);
 // Target Acquisition.
