@@ -6,6 +6,7 @@
 #include "inventory.h"
 #include "mapdata.h"
 #include "skill.h"
+#include "crafting.h" // For the use_comps use_tools functions
 
 #define PICKUP_RANGE 2
 
@@ -45,6 +46,10 @@ void game::init_construction()
   STAGE(t_pit, 10);
    TOOL(itm_shovel, NULL);
 
+ CONSTRUCT("Spike Pit", 0, &construct::able_pit, &construct::done_trap_pit);
+  STAGE(t_pit_spiked, 5);
+   COMP(itm_spear_wood, 4, NULL);
+
  CONSTRUCT("Fill Pit", 0, &construct::able_pit, &construct::done_fill_pit);
   STAGE(t_pit_shallow, 5);
    TOOL(itm_shovel, NULL);
@@ -53,15 +58,41 @@ void game::init_construction()
 
  CONSTRUCT("Clean Broken Window", 0, &construct::able_broken_window,
                                      &construct::done_nothing);
-  STAGE(t_window_empty, 8);
+  STAGE(t_window_empty, 5);
+
+ CONSTRUCT("Remove Window Pane",  1, &construct::able_window_pane,
+                                     &construct::done_window_pane);
+  STAGE(t_window_empty, 10);
+   TOOL(itm_hammer, itm_rock, itm_hatchet, NULL);
+   TOOL(itm_screwdriver, itm_knife_butter, NULL);
+
+ CONSTRUCT("Repair Door", 1, &construct::able_door_broken,
+                             &construct::done_nothing);
+  STAGE(t_door_c, 10);
+   TOOL(itm_hammer, itm_hatchet, itm_nailgun, NULL);
+   COMP(itm_2x4, 3, NULL);
+   COMP(itm_nail, 12, NULL);
+
+ CONSTRUCT("Board Up Door", 0, &construct::able_door, &construct::done_nothing);
+  STAGE(t_door_boarded, 8);
+   TOOL(itm_hammer, itm_hatchet, itm_nailgun, NULL);
+   COMP(itm_2x4, 4, NULL);
+   COMP(itm_nail, 8, NULL);
+
+ CONSTRUCT("Board Up Window", 0, &construct::able_window,
+                                 &construct::done_nothing);
+  STAGE(t_window_boarded, 5);
+   TOOL(itm_hammer, itm_hatchet, itm_nailgun, NULL);
+   COMP(itm_2x4, 4, NULL);
+   COMP(itm_nail, 8, NULL);
 
  CONSTRUCT("Build Wall", 2, &construct::able_empty, &construct::done_nothing);
   STAGE(t_wall_half, 10);
-   TOOL(itm_hammer, itm_nailgun, NULL);
+   TOOL(itm_hammer, itm_hatchet, itm_nailgun, NULL);
    COMP(itm_2x4, 10, NULL);
    COMP(itm_nail, 20, NULL);
   STAGE(t_wall_wood, 10);
-   TOOL(itm_hammer, itm_nailgun, NULL);
+   TOOL(itm_hammer, itm_hatchet, itm_nailgun, NULL);
    COMP(itm_2x4, 10, NULL);
    COMP(itm_nail, 20, NULL);
 
@@ -77,25 +108,25 @@ void game::init_construction()
   STAGE(t_door_frame, 15);
    TOOL(itm_saw, NULL);
   STAGE(t_door_b, 15);
-   TOOL(itm_hammer, itm_nailgun, NULL);
+   TOOL(itm_hammer, itm_hatchet, itm_nailgun, NULL);
    COMP(itm_2x4, 4, NULL);
    COMP(itm_nail, 12, NULL);
   STAGE(t_door_c, 15);
-   TOOL(itm_hammer, itm_nailgun, NULL);
+   TOOL(itm_hammer, itm_hatchet, itm_nailgun, NULL);
    COMP(itm_2x4, 4, NULL);
    COMP(itm_nail, 12, NULL);
 
 /*  Removed until we have some way of auto-aligning fences!
  CONSTRUCT("Build Fence", 1, 15, &construct::able_empty);
   STAGE(t_fence_h, 10);
-   TOOL(itm_hammer, NULL);
+   TOOL(itm_hammer, itm_hatchet, NULL);
    COMP(itm_2x4, 5, itm_nail, 8, NULL);
 */
 
  CONSTRUCT("Build Roof", 4, &construct::able_between_walls,
                             &construct::done_nothing);
   STAGE(t_floor, 40);
-   TOOL(itm_hammer, itm_nailgun, NULL);
+   TOOL(itm_hammer, itm_hatchet, itm_nailgun, NULL);
    COMP(itm_2x4, 8, NULL);
    COMP(itm_nail, 40, NULL);
 
@@ -167,10 +198,10 @@ void game::construction_menu()
     bool has_tool[3] = {stage.tools[0].empty(),
                         stage.tools[1].empty(),
                         stage.tools[2].empty()};
-    for (int i = 0; i < 3; i++) {
-     while (has_tool[i])
-      i++;
-     for (int j = 0; j < stage.tools[i].size() && i < 3; j++) {
+    for (int i = 0; i < 3 && !has_tool[i]; i++) {
+     posy++;
+     posx = 33;
+     for (int j = 0; j < stage.tools[i].size(); j++) {
       itype_id tool = stage.tools[i][j];
       nc_color col = c_red;
       if (total_inv.has_amount(tool, 1)) {
@@ -410,135 +441,10 @@ void game::complete_construction()
  if (built.difficulty < 1)
   u.practice(sk_carpentry, 10);
  for (int i = 0; i < 3; i++) {
-  while (stage.components[i].empty()) 
-   i++;
-  if (i < 3) {
-   std::vector<component> player_has;
-   std::vector<component> map_has;
-   for (int j = 0; j < stage.components[i].size(); j++) {
-    component comp = stage.components[i][j];
-    if (itypes[comp.type]->is_ammo()) {
-// Check if we have components in both locations and enough to do the job
-     if ((u.inv.charges_of(comp.type) + map_inv.charges_of(comp.type)) >= comp.count &&
-	u.inv.charges_of(comp.type) > 0 && map_inv.charges_of(comp.type) > 0) {
-      player_has.push_back(comp);
-      map_has.push_back(comp);
-// If not, check to see if either location has enough
-     } else {
-      if (u.has_charges(comp.type, comp.count)) {
-       player_has.push_back(comp);
-// dummy component to make our indexes line up
-       map_has.push_back(comp);
-       map_has[0].count = 0;
-      } else if (map_inv.has_charges(comp.type, comp.count)) {
-       map_has.push_back(comp);
-       player_has.push_back(comp);
-       player_has[0].count = 0;
-      }
-     }
-    } else {
-// repeat the above
-     if ((u.inv.amount_of(comp.type) + map_inv.amount_of(comp.type)) >= comp.count &&
-	u.inv.amount_of(comp.type) > 0 && map_inv.amount_of(comp.type) > 0) {
-      player_has.push_back(comp);
-      map_has.push_back(comp);
-     } else {
-      if (u.has_amount(comp.type, comp.count)) {
-       player_has.push_back(comp);
-       map_has.push_back(comp);
-       map_has[0].count = 0;
-      } else if (map_inv.has_amount(comp.type, comp.count)) {
-       map_has.push_back(comp);
-       player_has.push_back(comp);
-       player_has[0].count = 0;
-      }
-     }
-    }
-   }
-
-   if (player_has[0].count == 0 && map_has[0].count > 0)
-// One on map, none in inventory, default to the one in the map
-    map_use.push_back(map_has[i]);
-
-   else if (player_has[0].count > 0 && map_has[0].count == 0)
-// One in inventory, none on map, default to the one in inventory
-    player_use.push_back(player_has[i]);
-
-   else { // Let the player pick which component they want to use
-    std::vector<std::string> options; // List for the menu_vec below
-// Populate options with the names of the items
-    for (int j = 0; j < map_has.size(); j++) {
-     if (map_has[j].count != 0) {
-      std::string tmpStr = itypes[map_has[j].type]->name + " (nearby)";
-      options.push_back(tmpStr);
-     }
-    }
-    for (int j = 0; j < player_has.size(); j++)
-     if (player_has[j].count != 0) 
-      options.push_back(itypes[player_has[j].type]->name);
-// Get the selection via a menu popup
-    int selection = menu_vec("Use which component first?", options) - 1;
-    if (selection < map_has.size()) {
-// Since we have dummy components, need to weed them out
-     while(map_has[selection].count == 0)
-      selection++;
-     map_use.push_back(map_has[selection]);
-// check if it's ammo
-     if (itypes[map_use[map_use.size()-1].type]->is_ammo()) {
-// if not enough on the ground, we have to pull from inventory
-      if (map_inv.charges_of(map_use[map_use.size()-1].type) < map_has[0].count) {
-       player_use.push_back(player_has[0]);
-       player_use[player_use.size()-1].count -= map_inv.charges_of(map_has[0].type);
-       map_use[map_use.size()-1].count = map_inv.charges_of(map_has[0].type);
-      }
-// not enough on the ground. go to inventory
-     } else if (map_inv.amount_of(map_has[0].type) < map_has[0].count) {
-      player_use.push_back(player_has[0]);
-      player_use[player_use.size()-1].count -= map_inv.amount_of(map_has[0].type);
-      map_use[map_use.size()-1].count = map_inv.amount_of(map_has[0].type);
-     } 
-// not a map selection
-    } else {
-     selection -= map_has.size();
-// weed out dummies
-     while(player_has[selection].count == 0)
-      selection++;
-     player_use.push_back(player_has[selection]);
-// ammo
-     if (itypes[player_use[player_use.size()-1].type]->is_ammo()) {
-// grab from the ground if required
-      if (u.inv.charges_of(player_use[player_use.size()-1].type) < player_has[0].count) {
-       map_use.push_back(map_has[0]);
-       map_use[map_use.size()-1].count -= u.inv.charges_of(player_has[0].type);
-       player_use[player_use.size()-1].count = u.inv.charges_of(player_has[0].type);
-      }
-// not ammo & we don't have enough in pockets
-     } else if (u.inv.amount_of(player_has[0].type) < player_has[0].count) {
-      map_use.push_back(map_has[0]);
-      map_use[map_use.size()-1].count -= u.inv.amount_of(player_use[player_use.size()-1].type);
-      player_use[player_use.size()-1].count = u.inv.amount_of(player_has[0].type);
-     }
-    }
-   }
-  }
- } // Done looking at components
+  if (!stage.components[i].empty())
+   consume_items(this, stage.components[i]);
+ }
  
-// Use up materials
- for (int i = 0; i < player_use.size(); i++) {
-  if (itypes[player_use[i].type]->is_ammo())
-   u.use_charges(player_use[i].type, player_use[i].count);
-  else
-   u.use_amount(player_use[i].type, player_use[i].count);
- }
- for (int i = 0; i < map_use.size(); i++) {
-  if (itypes[map_use[i].type]->is_ammo())
-   m.use_charges(point(u.posx, u.posy), PICKUP_RANGE,
-                 map_use[i].type, map_use[i].count);
-  else
-   m.use_amount(point(u.posx, u.posy), PICKUP_RANGE,
-                map_use[i].type, map_use[i].count);
- }
-
 // Make the terrain change
  int terx = u.activity.placement.x, tery = u.activity.placement.y;
  m.ter(terx, tery) = stage.terrain;
@@ -560,11 +466,36 @@ bool construct::able_empty(game *g, point p)
  return (g->m.move_cost(p.x, p.y) == 2);
 }
 
+bool construct::able_window(game *g, point p)
+{
+ return (g->m.ter(p.x, p.y) == t_window_frame ||
+         g->m.ter(p.x, p.y) == t_window_empty ||
+         g->m.ter(p.x, p.y) == t_window);
+}
+
+bool construct::able_window_pane(game *g, point p)
+{
+ return (g->m.ter(p.x, p.y) == t_window);
+}
+
 bool construct::able_broken_window(game *g, point p)
 {
  return (g->m.ter(p.x, p.y) == t_window_frame);
 }
 
+bool construct::able_door(game *g, point p)
+{
+ return (g->m.ter(p.x, p.y) == t_door_c ||
+         g->m.ter(p.x, p.y) == t_door_b ||
+         g->m.ter(p.x, p.y) == t_door_o ||
+         g->m.ter(p.x, p.y) == t_door_locked);
+}
+
+bool construct::able_door_broken(game *g, point p)
+{
+ return (g->m.ter(p.x, p.y) == t_door_b);
+}
+
 bool construct::able_wall(game *g, point p)
 {
  return (g->m.ter(p.x, p.y) == t_wall_h || g->m.ter(p.x, p.y) == t_wall_v ||
@@ -594,7 +525,7 @@ bool construct::able_dig(game *g, point p)
 
 bool construct::able_pit(game *g, point p)
 {
- return (g->m.ter(p.x, p.y) == t_pit || g->m.ter(p.x, p.y) == t_pit_shallow);
+ return (g->m.ter(p.x, p.y) == t_pit);//|| g->m.ter(p.x, p.y) == t_pit_shallow);
 }
 
 bool will_flood_stop(map *m, bool fill[SEEX * 3][SEEY * 3], int x, int y)
@@ -628,8 +559,19 @@ void construct::done_pit(game *g, point p)
   g->m.add_trap(p.x, p.y, tr_pit);
 }
 
+void construct::done_trap_pit(game *g, point p)
+{
+ if (g->m.ter(p.x, p.y) == t_pit_spiked)
+  g->m.add_trap(p.x, p.y, tr_spike_pit);
+}
+
 void construct::done_fill_pit(game *g, point p)
 {
  if (g->m.tr_at(p.x, p.y) == tr_pit)
   g->m.tr_at(p.x, p.y) = tr_null;
 }
+
+void construct::done_window_pane(game *g, point p)
+{
+ g->m.add_item(g->u.posx, g->u.posy, g->itypes[itm_glass_sheet], 0);
+}
