@@ -43,6 +43,9 @@ void dis_msg(game *g, dis_type type)
  case DI_BOOMERED:
   g->add_msg("You're covered in bile!");
   break;
+ case DI_SAP:
+  g->add_msg("You're coated in sap!");
+  break;
  case DI_SPORES:
   g->add_msg("You're covered in tiny spores!");
   break;
@@ -69,12 +72,17 @@ void dis_msg(game *g, dis_type type)
  case DI_ASTHMA:
   g->add_msg("You can't breathe... asthma attack!");
   break;
+ case DI_DEAF:
+  g->add_msg("You're deafened!");
+  break;
  case DI_BLIND:
   g->add_msg("You're blinded!");
   break;
  case DI_AMIGARA:
   g->add_msg("You can't look away from the fautline...");
   break;
+ default:
+  break;
  }
 }
   
@@ -92,7 +100,6 @@ void dis_effect(game *g, player &p, disease &dis)
   break;
 
  case DI_COLD:
-  p.moves -= int(dis.duration / 5);
   p.dex_cur -= int(dis.duration / 80);
   break;
 
@@ -111,11 +118,9 @@ void dis_effect(game *g, player &p, disease &dis)
   break;
 
  case DI_COLD_LEGS:
-  p.moves -= (dis.duration > 60 ? 30 : int(dis.duration / 2));
   break;
 
  case DI_COLD_FEET:
-  p.moves -= (dis.duration > 60 ? 15 : int(dis.duration / 4));
   if (dis.duration >= 200 ||
       (dis.duration >= 100 && one_in(300 - dis.duration)))
    p.add_disease(DI_FBFEET, 50, g);
@@ -128,7 +133,6 @@ void dis_effect(game *g, player &p, disease &dis)
   break;
    
  case DI_HEATSTROKE:
-  p.moves   -= 15;
   p.str_cur -=  2;
   p.per_cur -=  1;
   p.int_cur -=  2;
@@ -143,7 +147,6 @@ void dis_effect(game *g, player &p, disease &dis)
   break;
 
  case DI_FBFEET:
-  p.moves   -= 40;
   p.str_cur -=  1;
   break;
 
@@ -199,8 +202,11 @@ void dis_effect(game *g, player &p, disease &dis)
   p.per_cur -= 5;
   break;
 
+ case DI_SAP:
+  p.dex_cur -= 3;
+  break;
+
  case DI_SPORES:
-  p.moves -= 40;
   if (one_in(30))
    p.add_disease(DI_FUNGUS, -1, g);
   break;
@@ -233,7 +239,7 @@ void dis_effect(game *g, player &p, disease &dis)
    if (one_in(600 + bonus * 3)) {
     if (!p.is_npc())
      g->add_msg("You spasm suddenly!");
-    p.moves = 0;
+    p.moves -= 100;
     p.hurt(g, bp_torso, 0, 5);
    }
    if ((p.has_trait(PF_WEAKSTOMACH) && one_in(1600 + bonus *  8)) ||
@@ -285,9 +291,6 @@ void dis_effect(game *g, player &p, disease &dis)
   break;
 
  case DI_SLIMED:
-  p.moves -= 30;
-  if (p.moves < 1)
-   p.moves = 1;
   p.dex_cur -= 2;
   break;
 
@@ -432,7 +435,6 @@ void dis_effect(game *g, player &p, disease &dis)
   }
   p.per_cur -= 2;
   p.dex_cur -= 2;
-  p.moves -= 10;
   if (!p.has_trait(PF_POISRESIST))
    p.str_cur -= 3;
   else
@@ -451,14 +453,11 @@ void dis_effect(game *g, player &p, disease &dis)
   if ((p.has_trait(PF_WEAKSTOMACH) && one_in(350 + bonus)) ||
       one_in(900 + bonus)) 
    p.vomit(g);
-  p.moves -= 35;
   p.str_cur -= 3;
   p.dex_cur--;
   p.per_cur--;
-  if (p.has_trait(PF_POISRESIST)) {
-   p.moves += 15;
+  if (p.has_trait(PF_POISRESIST))
    p.str_cur += 2;
-  }
   break;
 
  case DI_SHAKES:
@@ -525,13 +524,12 @@ void dis_effect(game *g, player &p, disease &dis)
  case DI_WEBBED:
   p.str_cur -= 2;
   p.dex_cur -= 4;
-  p.moves -= 25;
   break;
 
  case DI_FORMICATION:
   p.int_cur -= 2;
   p.str_cur -= 1;
-  if (one_in(50 * p.int_cur)) {
+  if (one_in(10 + 40 * p.int_cur)) {
    int t;
    if (!p.is_npc()) {
     g->add_msg("You start scratching yourself all over!");
@@ -540,7 +538,7 @@ void dis_effect(game *g, player &p, disease &dis)
     g->add_msg("%s starts scratching %s all over!", p.name.c_str(),
                (p.male ? "himself" : "herself"));
    p.moves -= 150;
-   p.hurt(g, bp_torso, 0, 2);
+   p.hurt(g, bp_torso, 0, 1);
   }
   break;
 
@@ -582,7 +580,6 @@ void dis_effect(game *g, player &p, disease &dis)
 
  case DI_ADRENALINE:
   if (dis.duration > 150) {	// 5 minutes positive effects
-   p.moves += rng(40, 100);
    p.str_cur += 5;
    p.dex_cur += 3;
    p.int_cur -= 8;
@@ -605,7 +602,6 @@ void dis_effect(game *g, player &p, disease &dis)
     g->add_msg("Your asthma overcomes you.  You stop breathing and die...");
    p.hurtall(500);
   }
-  p.moves -= dis.duration / 5;
   p.str_cur -= 2;
   p.dex_cur -= 3;
   break;
@@ -616,12 +612,10 @@ void dis_effect(game *g, player &p, disease &dis)
    p.dex_cur += 2;
    p.int_cur += 3;
    p.per_cur += 3;
-   p.moves += 50;
   } else {
    p.str_cur -= 3;
    p.dex_cur -= 2;
    p.int_cur -= 1;
-   p.moves -= 40;
   }
   break;
 
@@ -704,6 +698,87 @@ void dis_effect(game *g, player &p, disease &dis)
    p.rem_disease(DI_TELEGLOW);
   }
   break;
+
+ case DI_ATTENTION:
+  if (one_in( 100000 / dis.duration )) {
+   int range = g->moncats[mcat_nether].size();
+   mon_id type = (g->moncats[mcat_nether])[rng(0, range - 1)];
+   monster beast(g->mtypes[type]);
+   int x, y, tries = 0, junk;
+   do {
+    x = p.posx + rng(-4, 4);
+    y = p.posy + rng(-4, 4);
+    tries++;
+   } while (((x == p.posx && y == p.posy) || g->mon_at(x, y) != -1) &&
+            tries < 10);
+   if (tries < 10) {
+    if (g->m.move_cost(x, y) == 0)
+     g->m.ter(x, y) = t_rubble;
+    beast.spawn(x, y);
+    g->z.push_back(beast);
+    if (g->u_see(x, y, junk))
+     g->add_msg("A portal opens nearby, and a monster crawls through!");
+    dis.duration /= 2;
+   }
+  }
+  break;
+
+ case DI_EVIL: {
+  bool lesser = false; // Worn or wielded; diminished effects
+  if (p.weapon.is_artifact() && p.weapon.is_tool()) {
+   it_artifact_tool *tool = dynamic_cast<it_artifact_tool*>(p.weapon.type);
+   for (int i = 0; i < tool->effects_carried.size(); i++) {
+    if (tool->effects_carried[i] == AEP_EVIL)
+     lesser = true;
+   }
+   for (int i = 0; i < tool->effects_wielded.size(); i++) {
+    if (tool->effects_wielded[i] == AEP_EVIL)
+     lesser = true;
+   }
+  }
+  for (int i = 0; !lesser && i < p.worn.size(); i++) {
+   if (p.worn[i].is_artifact()) {
+    it_artifact_armor *armor = dynamic_cast<it_artifact_armor*>(p.worn[i].type);
+    for (int i = 0; i < armor->effects_worn.size(); i++) {
+     if (armor->effects_worn[i] == AEP_EVIL)
+      lesser = true;
+    }
+   }
+  }
+
+  if (lesser) { // Only minor effects, some even good!
+   p.str_cur += (dis.duration > 4500 ? 10 : int(dis.duration / 450));
+   if (dis.duration < 600)
+    p.dex_cur++;
+   else
+    p.dex_cur -= (dis.duration > 3600 ? 10 : int((dis.duration - 600) / 300));
+   p.int_cur -= (dis.duration > 3000 ? 10 : int((dis.duration - 500) / 250));
+   p.per_cur -= (dis.duration > 4800 ? 10 : int((dis.duration - 800) / 400));
+  } else { // Major effects, all bad.
+   p.str_cur -= (dis.duration > 5000 ? 10 : int(dis.duration / 500));
+   p.dex_cur -= (dis.duration > 6000 ? 10 : int(dis.duration / 600));
+   p.int_cur -= (dis.duration > 4500 ? 10 : int(dis.duration / 450));
+   p.per_cur -= (dis.duration > 4000 ? 10 : int(dis.duration / 400));
+  }
+ } break;
+ }
+}
+
+int disease_speed_boost(disease dis)
+{
+ switch (dis.type) {
+ case DI_COLD:		return 0 - int(dis.duration / 5);
+ case DI_HEATSTROKE:	return -15;
+ case DI_SAP:		return -25;
+ case DI_SPORES:	return -15;
+ case DI_SLIMED:	return -25;
+ case DI_BADPOISON:	return -10;
+ case DI_FOODPOISON:	return -20;
+ case DI_WEBBED:	return -25;
+ case DI_ADRENALINE:	return (dis.duration > 150 ? 40 : -10);
+ case DI_ASTHMA:	return 0 - int(dis.duration / 5);
+ case DI_METH:		return (dis.duration > 600 ? 50 : -40);
+ default:		return 0;
  }
 }
 
@@ -726,8 +801,10 @@ std::string dis_name(disease dis)
  case DI_TEARGAS:	return "Tear gas";
  case DI_ONFIRE:	return "On Fire";
  case DI_BOOMERED:	return "Boomered";
+ case DI_SAP:		return "Sap-coated";
  case DI_SPORES:	return "Spores";
  case DI_SLIMED:	return "Slimed";
+ case DI_DEAF:		return "Deaf";
  case DI_BLIND:		return "Blind";
  case DI_POISON:	return "Poisoned";
  case DI_BADPOISON:	return "Badly Poisoned";
@@ -852,6 +929,9 @@ Your clothing and other equipment may be consumed by the flames.";
 Perception - 5\n\
 Range of Sight: 1;     All sight is tinted magenta";
 
+ case DI_SAP:		return "\
+Dexterity - 3;   Speed - 25";
+
  case DI_SPORES:	return "\
 Speed -40%\
 You can feel the tiny spores sinking directly into your flesh.";
@@ -859,6 +939,9 @@ You can feel the tiny spores sinking directly into your flesh.";
  case DI_SLIMED:	return "\
 Speed -40%;     Dexterity - 2";
 
+ case DI_DEAF:		return "\
+Sounds will not be reported.  You cannot talk with NPCs.";
+
  case DI_BLIND:		return "\
 Range of Sight: 0";
 
