@@ -13,6 +13,10 @@ enum event_type {
  EVENT_ROBOT_ATTACK,
  EVENT_SPAWN_WYRMS,
  EVENT_AMIGARA,
+ EVENT_ROOTS_DIE,
+ EVENT_TEMPLE_OPEN,
+ EVENT_TEMPLE_FLOOD,
+ EVENT_TEMPLE_SPAWN,
  NUM_EVENT_TYPES
 };
 
