@@ -16,6 +16,8 @@ item::item()
  bday = 0;
  invlet = 0;
  damage = 0;
+ burnt = 0;
+ poison = 0;
  type = NULL;
  curammo = NULL;
  corpse = NULL;
@@ -32,6 +34,8 @@ item::item(itype* it, unsigned int turn)
  name = "";
  invlet = 0;
  damage = 0;
+ burnt = 0;
+ poison = 0;
  active = false;
  curammo = NULL;
  corpse = NULL;
@@ -67,6 +71,8 @@ item::item(itype *it, unsigned int turn, char let)
  bday = turn;
  name = "";
  damage = 0;
+ burnt = 0;
+ poison = 0;
  active = false;
  if (it->is_gun()) {
   charges = 0;
@@ -102,6 +108,8 @@ void item::make_corpse(itype* it, mtype* mt, unsigned int turn)
  charges = -1;
  invlet = 0;
  damage = 0;
+ burnt = 0;
+ poison = 0;
  curammo = NULL;
  active = false;
  type = it;
@@ -142,7 +150,7 @@ item item::in_its_container(std::vector<itype*> *itypes)
 
 bool item::invlet_is_okay()
 {
- return ((invlet >= 'a' & invlet <= 'z') || (invlet >= 'A' && invlet <= 'Z'));
+ return ((invlet >= 'a' && invlet <= 'z') || (invlet >= 'A' && invlet <= 'Z'));
 }
 
 bool item::stacks_with(item rhs)
@@ -181,7 +189,9 @@ std::string item::save_info()
   ammotmp = 0; // Saves us from some bugs
  std::stringstream dump;// (std::stringstream::in | std::stringstream::out);
  dump << " " << int(invlet) << " " << int(type->id) << " " <<  int(charges) <<
-         " " << int(damage) << " " << ammotmp << " " << int(bday);
+         " " << int(damage) << " " << int(burnt) << " " << poison << " " <<
+         ammotmp << " " <<
+         int(bday);
  if (active)
   dump << " 1";
  else
@@ -208,9 +218,9 @@ void item::load_info(std::string data, game *g)
 {
  std::stringstream dump;
  dump << data;
- int idtmp, ammotmp, lettmp, damtmp, acttmp, owntmp, corp;
- dump >> lettmp >> idtmp >> charges >> damtmp >> ammotmp >> bday >> acttmp >>
-         owntmp >> corp >> mission_id >> player_id;
+ int idtmp, ammotmp, lettmp, damtmp, burntmp, acttmp, owntmp, corp;
+ dump >> lettmp >> idtmp >> charges >> damtmp >> burntmp >> poison >> ammotmp >>
+         bday >> acttmp >> owntmp >> corp >> mission_id >> player_id;
  if (corp != -1)
   corpse = g->mtypes[corp];
  else
@@ -229,6 +239,7 @@ void item::load_info(std::string data, game *g)
  make(g->itypes[idtmp]);
  invlet = char(lettmp);
  damage = damtmp;
+ burnt = burntmp;
  active = false;
  if (acttmp == 1)
   active = true;
@@ -506,6 +517,11 @@ std::string item::tname(game *g)
   ret << damtext;
  }
 
+ if (volume() >= 4 && burnt >= volume() * 2)
+  ret << "badly burnt ";
+ else if (burnt > 0)
+  ret << "burnt ";
+
  if (type->id == itm_corpse) {
   ret << corpse->name << " corpse";
   if (name != "")
@@ -620,11 +636,23 @@ int item::damage_bash()
 
 int item::damage_cut()
 {
+ if (is_gun()) {
+  for (int i = 0; i < contents.size(); i++) {
+   if (contents[i].type->id == itm_bayonet)
+    return contents[i].type->melee_cut;
+  }
+ }
  return type->melee_cut;
 }
 
 bool item::has_flag(item_flag f)
 {
+ if (is_gun()) {
+  for (int i = 0; i < contents.size(); i++) {
+   if (contents[i].has_flag(f))
+    return true;
+  }
+ }
  return (type->item_flags & mfb(f));
 }
 
@@ -644,6 +672,27 @@ bool item::goes_bad()
  return (food->spoils != 0);
 }
 
+bool item::count_by_charges()
+{
+ if (is_ammo())
+  return true;
+ if (is_food()) {
+  it_comest* food = dynamic_cast<it_comest*>(type);
+  return (food->charges > 1);
+ }
+ return false;
+}
+
+bool item::craft_has_charges()
+{
+ if (count_by_charges())
+  return true;
+ else if (ammo_type() == AT_NULL)
+  return true;
+
+ return false;
+}
+
 int item::weapon_value(int skills[num_skill_types])
 {
  int my_value = 0;
@@ -749,7 +798,7 @@ bool item::is_food(player *u)
      (dynamic_cast<it_ammo*>(type))->type == AT_BATT)
   return true;
  if (u->has_bionic(bio_furnace) && is_flammable(type->m1) &&
-     is_flammable(type->m2))
+     is_flammable(type->m2) && type->id != itm_corpse)
   return true;
  return false;
 }
@@ -832,6 +881,11 @@ bool item::is_other()
          !is_book() && !is_weap());
 }
 
+bool item::is_artifact()
+{
+ return type->is_artifact();
+}
+
 int item::reload_time(player &u)
 {
  int ret = 0;
@@ -860,6 +914,8 @@ int item::clip_size()
   return 0;
  it_gun* gun = dynamic_cast<it_gun*>(type);
  int ret = gun->clip;
+ if (gun->ammo != AT_40MM && charges > 0 && curammo->type == AT_40MM)
+  return 1; // M203 mod in use
  for (int i = 0; i < contents.size(); i++) {
   if (contents[i].is_gunmod()) {
    int bonus = (ret * (dynamic_cast<it_gunmod*>(contents[i].type))->clip) / 100;
@@ -974,8 +1030,12 @@ int item::pick_reload_ammo(player &u, bool interactive)
   debugmsg("RELOADING NON-GUN NON-TOOL");
   return false;
  }
- bool single_load = false;
- int max_load = 0;
+ bool has_m203 = false;
+ for (int i = 0; i < contents.size() && !has_m203; i++) {
+  if (contents[i].type->id == itm_m203)
+   has_m203 = true;
+ }
+
  std::vector<int> am;	// List of indicies of valid ammo
 
  if (type->is_gun()) {
@@ -988,14 +1048,15 @@ int item::pick_reload_ammo(player &u, bool interactive)
   } else {
   it_gun* tmp = dynamic_cast<it_gun*>(type);
    am = u.has_ammo(ammo_type());
-   max_load = tmp->clip;
-   if (tmp->skill_used == sk_shotgun)
-    single_load = true;
+   if (has_m203) {
+    std::vector<int> grenades = u.has_ammo(AT_40MM);
+    for (int i = 0; i < grenades.size(); i++)
+     am.push_back(grenades[i]);
+   }
   }
  } else {
   it_tool* tmp = dynamic_cast<it_tool*>(type);
   am = u.has_ammo(ammo_type());
-  max_load = tmp->max_charges;
  }
 
  int index = -1;
@@ -1050,9 +1111,11 @@ bool item::reload(player &u, int index)
  bool single_load = false;
  int max_load;
  if (is_gun()) {
-  it_gun* reloading = dynamic_cast<it_gun*>(type);
   single_load = has_flag(IF_RELOAD_ONE);
-  max_load = clip_size();
+  if (u.inv[index].ammo_type() == AT_40MM && ammo_type() != AT_40MM)
+   max_load = 1;
+  else
+   max_load = clip_size();
  } else if (is_tool()) {
   it_tool* tool = dynamic_cast<it_tool*>(type);
   single_load = false;
@@ -1062,8 +1125,14 @@ bool item::reload(player &u, int index)
 // If the gun is currently loaded with a different type of ammo, reloading fails
   if (is_gun() && charges > 0 && curammo->id != u.inv[index].type->id)
    return false;
-  if (is_gun())
+  if (is_gun()) {
+   if (!u.inv[index].is_ammo()) {
+    debugmsg("Tried to reload %s with %s!", tname().c_str(),
+             u.inv[index].tname().c_str());
+    return false;
+   }
    curammo = dynamic_cast<it_ammo*>((u.inv[index].type));
+  }
   if (single_load) {	// Only insert one cartridge!
    charges++;
    u.inv[index].charges--;
@@ -1090,6 +1159,12 @@ void item::use(player &u)
   charges--;
 }
 
+bool item::burn(int amount)
+{
+ burnt += amount;
+ return (burnt >= volume() * 3);
+}
+
 bool is_flammable(material m)
 {
  return (m == COTTON || m == WOOL || m == PAPER || m == WOOD || m == MNULL);
