@@ -3,6 +3,7 @@
 
 #include <string>
 #include <vector>
+#include <sstream>
 #include "color.h"
 #include "enums.h"
 #include "iuse.h"
@@ -10,6 +11,7 @@
 #include "bodypart.h"
 #include "skill.h"
 #include "bionics.h"
+#include "artifact.h"
 
 // mfb(n) converts a flag to its appropriate position in covers's bitfield
 #ifndef mfb
@@ -19,11 +21,13 @@
 enum itype_id {
 itm_null = 0,
 itm_corpse,
+// Special crafting-only pseudoitems
+itm_fire, itm_toolset,
 // Drinks
-itm_water, itm_water_dirty, itm_sewage, itm_salt_water, itm_oj, itm_apple_cider,
+itm_water, itm_sewage, itm_salt_water, itm_oj, itm_apple_cider,
  itm_energy_drink, itm_cola, itm_rootbeer, itm_milk, itm_V8, itm_broth,
  itm_soup, itm_whiskey, itm_vodka, itm_rum, itm_tequila, itm_beer, itm_bleach,
- itm_ammonia, itm_mutagen, itm_purifier,
+ itm_ammonia, itm_mutagen, itm_purifier, itm_tea, itm_coffee,
 // Monster Meats
 itm_meat, itm_veggy, itm_meat_tainted, itm_veggy_tainted, itm_meat_cooked,
  itm_veggy_cooked,
@@ -38,15 +42,16 @@ itm_apple, itm_orange, itm_lemon, itm_chips, itm_pretzels, itm_chocolate,
  itm_can_tuna, itm_can_catfood, itm_honeycomb, itm_royal_jelly, itm_fetus,
  itm_arm, itm_leg, itm_ant_egg, itm_marloss_berry, itm_flour, itm_sugar,
  itm_salt, itm_potato_raw, itm_potato_baked, itm_bread, itm_pie, itm_pizza,
+ itm_mre, itm_tea_raw, itm_coffee_raw,
 // Medication
 itm_bandages, itm_1st_aid, itm_vitamins, itm_aspirin, itm_caffeine,
  itm_pills_sleep, itm_iodine, itm_dayquil, itm_nyquil, itm_inhaler, itm_codeine,
  itm_oxycodone, itm_tramadol, itm_xanax, itm_adderall, itm_thorazine,
- itm_prozac, itm_cig, itm_weed, itm_coke, itm_meth, itm_heroin,
+ itm_prozac, itm_cig, itm_weed, itm_coke, itm_meth, itm_heroin, itm_cigar,
 // Do-nothing / Melee weapons
 itm_wrapper, itm_syringe, itm_rag, itm_fur, itm_leather, itm_superglue,
- itm_card_id, itm_electrohack, itm_string_6, itm_string_36, itm_rope_6,
- itm_rope_30, itm_chain, itm_processor, itm_RAM, itm_power_supply,
+ itm_id_science, itm_id_military, itm_electrohack, itm_string_6, itm_string_36,
+ itm_rope_6, itm_rope_30, itm_chain, itm_processor, itm_RAM, itm_power_supply,
  itm_amplifier, itm_transponder, itm_receiver, itm_antenna, itm_steel_chunk,
  itm_motor, itm_hose, itm_glass_sheet, itm_manhole_cover, itm_rock, itm_stick,
  itm_broom, itm_mop, itm_screwdriver, itm_wrench, itm_saw, itm_hacksaw,
@@ -54,8 +59,9 @@ itm_wrapper, itm_syringe, itm_rag, itm_fur, itm_leather, itm_superglue,
  itm_pan, itm_knife_butter, itm_knife_steak, itm_knife_butcher,
  itm_knife_combat, itm_2x4, itm_muffler, itm_pipe, itm_bat, itm_machete,
  itm_katana, itm_spear_wood, itm_spear_knife, itm_baton, itm_bee_sting,
- itm_wasp_sting, itm_chitin_piece, itm_canister_empty, itm_gold, itm_coal,
- itm_petrified_eye, itm_spiral_stone,
+ itm_wasp_sting, itm_chitin_piece, itm_biollante_bud, itm_canister_empty,
+ itm_gold, itm_coal, itm_petrified_eye, itm_spiral_stone, itm_rapier, itm_cane,
+ itm_binoculars,
 // Footwear
 itm_sneakers, itm_boots, itm_boots_steel, itm_boots_winter, itm_mocassins,
  itm_flip_flops, itm_dress_shoes, itm_heels, 
@@ -63,7 +69,7 @@ itm_sneakers, itm_boots, itm_boots_steel, itm_boots_winter, itm_mocassins,
 itm_jeans, itm_pants, itm_pants_leather, itm_pants_cargo, itm_pants_army,
  itm_skirt,
 // Full-body clothing
-itm_jumpsuit, itm_dress, itm_armor_chitin,
+itm_jumpsuit, itm_dress, itm_armor_chitin, itm_suit,
 // Torso clothing
 itm_tshirt, itm_polo_shirt, itm_dress_shirt, itm_tank_top, itm_sweatshirt,
  itm_sweater, itm_hoodie, itm_jacket_light, itm_jacket_jean, itm_blazer,
@@ -77,38 +83,44 @@ itm_gloves_light, itm_mittens, itm_gloves_wool, itm_gloves_winter,
 itm_mask_dust, itm_bandana, itm_scarf, itm_mask_filter, itm_mask_gas,
 // Eyewear
 itm_glasses_eye, itm_glasses_reading, itm_glasses_safety, itm_goggles_swim,
- itm_goggles_ski, itm_goggles_welding, itm_goggles_nv,
+ itm_goggles_ski, itm_goggles_welding, itm_goggles_nv, itm_glasses_monocle,
 // Headwear
 itm_hat_ball, itm_hat_boonie, itm_hat_cotton, itm_hat_knit, itm_hat_hunting,
  itm_hat_fur, itm_hat_hard, itm_helmet_bike, itm_helmet_skid, itm_helmet_ball,
- itm_helmet_army, itm_helmet_riot, itm_helmet_motor, itm_helmet_chitin,
+ itm_helmet_army, itm_helmet_riot, itm_helmet_motor, itm_helmet_chitin, itm_tophat,
 // High-storage
 itm_backpack, itm_purse, itm_mbag, itm_fanny, itm_holster, itm_bootstrap,
 // Ammunition
-itm_battery, itm_plut_cell, itm_nail, itm_bb, itm_bolt_wood, itm_bolt_steel,
- itm_shot_bird, itm_shot_00, itm_shot_slug, itm_22_lr, itm_22_cb,
- itm_22_ratshot, itm_9mm, itm_9mmP, itm_9mmP2, itm_38_special, itm_38_super,
- itm_10mm, itm_40sw, itm_44magnum, itm_45_acp, itm_45_jhp, itm_45_super,
- itm_57mm, itm_46mm, itm_762_m43, itm_762_m87, itm_223, itm_556,
- itm_556_incendiary, itm_270, itm_3006, itm_3006_incendiary, itm_308,
- itm_762_51, itm_762_51_incendiary, itm_laser_pack, itm_gasoline,
+itm_battery, itm_plut_cell, itm_nail, itm_bb, itm_arrow_wood, itm_arrow_cf,
+ itm_bolt_wood, itm_bolt_steel, itm_shot_bird, itm_shot_00, itm_shot_slug,
+ itm_shot_he, itm_22_lr, itm_22_cb, itm_22_ratshot, itm_9mm, itm_9mmP,
+ itm_9mmP2, itm_38_special, itm_38_super, itm_10mm, itm_40sw, itm_44magnum,
+ itm_45_acp, itm_45_jhp, itm_45_super, itm_57mm, itm_46mm, itm_762_m43,
+ itm_762_m87, itm_223, itm_556, itm_556_incendiary, itm_270, itm_3006,
+ itm_3006_incendiary, itm_308, itm_762_51, itm_762_51_incendiary,
+ itm_laser_pack, itm_40mm_concussive, itm_40mm_frag, itm_40mm_incendiary,
+ itm_40mm_teargas, itm_40mm_smoke, itm_40mm_flashbang, itm_12mm, itm_plasma,
+ itm_gasoline,
 // Guns
-itm_nailgun, itm_bbgun, itm_crossbow, itm_rifle_22, itm_rifle_9mm, itm_smg_9mm,
- itm_smg_45, itm_sig_mosquito, itm_sw_22, itm_glock_19, itm_usp_9mm, itm_sw_619,
- itm_taurus_38, itm_sig_40, itm_sw_610, itm_ruger_redhawk, itm_deagle_44,
- itm_usp_45, itm_m1911, itm_fn57, itm_hk_ucp, itm_shotgun_sawn, itm_shotgun_s,
- itm_shotgun_d,  itm_remington_870, itm_mossberg_500, itm_saiga_12,
- itm_american_180, itm_uzi, itm_tec9, itm_calico, itm_hk_mp5, itm_mac_10,
- itm_hk_ump45, itm_TDI, itm_fn_p90, itm_hk_mp7, itm_marlin_9a, itm_ruger_1022,
- itm_browning_blr, itm_remington_700, itm_sks, itm_ruger_mini, itm_savage_111f,
- itm_hk_g3, itm_hk_g36, itm_ak47, itm_fn_fal, itm_acr, itm_ar15, itm_m4a1,
- itm_scar_l, itm_scar_h, itm_steyr_aug, itm_m249, itm_v29, itm_ftk93,
- itm_flamethrower_simple, itm_flamethrower,
+itm_nailgun, itm_bbgun, itm_crossbow, itm_compbow, itm_longbow, itm_rifle_22,
+ itm_rifle_9mm, itm_smg_9mm, itm_smg_45, itm_sig_mosquito, itm_sw_22,
+ itm_glock_19, itm_usp_9mm, itm_sw_619, itm_taurus_38, itm_sig_40, itm_sw_610,
+ itm_ruger_redhawk, itm_deagle_44, itm_usp_45, itm_m1911, itm_fn57, itm_hk_ucp,
+ itm_shotgun_sawn, itm_shotgun_s, itm_shotgun_d,  itm_remington_870,
+ itm_mossberg_500, itm_saiga_12, itm_american_180, itm_uzi, itm_tec9,
+ itm_calico, itm_hk_mp5, itm_mac_10, itm_hk_ump45, itm_TDI, itm_fn_p90,
+ itm_hk_mp7, itm_marlin_9a, itm_ruger_1022, itm_browning_blr,
+ itm_remington_700, itm_sks, itm_ruger_mini, itm_savage_111f, itm_hk_g3,
+ itm_hk_g36, itm_ak47, itm_fn_fal, itm_acr, itm_ar15, itm_m4a1, itm_scar_l,
+ itm_scar_h, itm_steyr_aug, itm_m249, itm_v29, itm_ftk93,
+ itm_flamethrower_simple, itm_flamethrower, itm_launcher_simple, itm_m79,
+ itm_m320, itm_mgl, itm_coilgun, itm_hk_g80, itm_plasma_rifle,
 // Gun modifications
 itm_silencer, itm_grip, itm_barrel_big, itm_barrel_small, itm_barrel_rifled,
  itm_clip, itm_clip2, itm_stablizer, itm_blowback, itm_autofire, itm_retool_45,
  itm_retool_9mm, itm_retool_22, itm_retool_57, itm_retool_46, itm_retool_308,
- itm_retool_223, itm_conversion_battle, itm_conversion_sniper,
+ itm_retool_223, itm_conversion_battle, itm_conversion_sniper, itm_m203,
+ itm_bayonet,
 // Books
 itm_mag_porn, itm_mag_tv, itm_mag_news, itm_mag_cars, itm_mag_cooking,
  itm_mag_guns, itm_novel_romance, itm_novel_spy, itm_novel_scifi,
@@ -129,11 +141,12 @@ itm_lighter, itm_sewing_kit, itm_scissors, itm_hammer, itm_extinguisher,
  itm_bubblewrap, itm_beartrap, itm_board_trap, itm_tripwire, itm_crossbow_trap,
  itm_shotgun_trap, itm_blade_trap, itm_landmine, itm_geiger_off, itm_geiger_on,
  itm_teleporter, itm_canister_goo, itm_pipebomb, itm_pipebomb_act, itm_grenade,
- itm_grenade_act, itm_EMPbomb, itm_EMPbomb_act, itm_gasbomb, itm_gasbomb_act,
- itm_smokebomb, itm_smokebomb_act, itm_molotov, itm_molotov_lit, itm_dynamite,
+ itm_grenade_act, itm_flashbang, itm_flashbang_act, itm_EMPbomb,
+ itm_EMPbomb_act, itm_gasbomb, itm_gasbomb_act, itm_smokebomb,
+ itm_smokebomb_act, itm_molotov, itm_molotov_lit, itm_dynamite,
  itm_dynamite_act, itm_mininuke, itm_mininuke_act, itm_pheromone, itm_portal,
  itm_bot_manhack, itm_bot_turret, itm_UPS_off, itm_UPS_on, itm_tazer, itm_mp3,
- itm_mp3_on, itm_vortex_stone,
+ itm_mp3_on, itm_vortex_stone, itm_dogfood, itm_boobytrap, itm_c4,  itm_c4armed,
 // Bionics containers
 itm_bionics_battery,       itm_bionics_power,   itm_bionics_tools,
  itm_bionics_neuro,        itm_bionics_sensory, itm_bionics_aquatic,
@@ -151,24 +164,21 @@ itm_bio_claws, itm_bio_fusion, itm_bio_blaster,
 num_all_items
 };
 
-enum item_cat {
-IC_NULL,
-IC_GUN, IC_AMMO, IC_WEAPON, IC_TOOL, IC_FOOD, IC_DRUG, IC_BOOK, IC_ARMOR,
-IC_MISC
-};
-
 // IMPORTANT: If adding a new AT_*** ammotype, add it to the ammo_name function
 //  at the end of itypedef.cpp
 enum ammotype {
 AT_NULL,
 AT_BATT, AT_PLUT,
-AT_NAIL, AT_BB, AT_BOLT,
+AT_NAIL, AT_BB, AT_BOLT, AT_ARROW,
 AT_SHOT,
 AT_22, AT_9MM, AT_38, AT_40, AT_44, AT_45,
 AT_57, AT_46,
 AT_762, AT_223, AT_3006, AT_308,
+AT_40MM,
 AT_GAS,
 AT_FUSION,
+AT_12MM,
+AT_PLASMA,
 NUM_AMMO_TYPES
 };
 
@@ -184,15 +194,20 @@ IF_WRAP,	// Can wrap around your target, costing you and them movement
 IF_MESSY,	// Splatters blood, etc.
 IF_RELOAD_ONE,	// Reload cartridge by cartridge (e.g. most shotguns)
 IF_STR_RELOAD,  // Reloading time is reduced by Strength * 20
+IF_STR8_DRAW,   // Requires strength 8 to draw
+IF_STR10_DRAW,  // Requires strength 10 to draw
+IF_USE_UPS,	// Draws power from a UPS
 
-IF_AMMO_FLAME,	// Sets fire to terrain and monsters
-IF_AMMO_INCENDIARY, // Sparks explosive terrain
-IF_AMMO_EXPLOSIVE, // Small explosion
-IF_AMMO_FRAG,	// Frag explosion
-IF_AMMO_NAPALM,	// Firey explosion
-IF_AMMO_EXPLOSIVE_BIG, // Big explosion!
-IF_AMMO_SCENT,	// Scent burst
-IF_AMMO_TRAIL,	// Leaves a trail of smoke
+IF_AMMO_FLAME,		// Sets fire to terrain and monsters
+IF_AMMO_INCENDIARY,	// Sparks explosive terrain
+IF_AMMO_EXPLOSIVE,	// Small explosion
+IF_AMMO_FRAG,		// Frag explosion
+IF_AMMO_NAPALM,		// Firey explosion
+IF_AMMO_EXPLOSIVE_BIG,	// Big explosion!
+IF_AMMO_TEARGAS,	// Teargas burst
+IF_AMMO_SMOKE,  	// Smoke burst
+IF_AMMO_TRAIL,		// Leaves a trail of smoke
+IF_AMMO_FLASHBANG,	// Disorients and blinds
 NUM_ITEM_FLAGS
 };
 
@@ -203,7 +218,7 @@ itype_id default_ammo(ammotype guntype);
 
 struct itype
 {
- unsigned int id;	// ID # that matches its place in master itype list
+ int id;		// ID # that matches its place in master itype list
  			// Used for save files; aligns to itype_id above.
  unsigned char rarity;	// How often it's found
  unsigned int  price;	// Its value
@@ -227,16 +242,19 @@ struct itype
 
  unsigned item_flags : NUM_ITEM_FLAGS;
  
- virtual bool is_food()      { return false; }
- virtual bool is_ammo()      { return false; }
- virtual bool is_gun()       { return false; }
- virtual bool is_gunmod()    { return false; }
- virtual bool is_bionic()    { return false; }
- virtual bool is_armor()     { return false; }
- virtual bool is_book()      { return false; }
- virtual bool is_tool()      { return false; }
- virtual bool is_container() { return false; }
- virtual bool is_macguffin() { return false; }
+ virtual bool is_food()          { return false; }
+ virtual bool is_ammo()          { return false; }
+ virtual bool is_gun()           { return false; }
+ virtual bool is_gunmod()        { return false; }
+ virtual bool is_bionic()        { return false; }
+ virtual bool is_armor()         { return false; }
+ virtual bool is_book()          { return false; }
+ virtual bool is_tool()          { return false; }
+ virtual bool is_container()     { return false; }
+ virtual bool is_macguffin()     { return false; }
+ virtual bool is_artifact()      { return false; }
+ virtual bool count_by_charges() { return false; }
+ virtual std::string save_data() { return std::string(); }
 
  itype() {
   id = 0;
@@ -253,7 +271,7 @@ struct itype
   item_flags = 0;
  }
  
- itype(unsigned short pid, unsigned char prarity, unsigned int pprice,
+ itype(int pid, unsigned char prarity, unsigned int pprice,
        std::string pname, std::string pdes,
        char psym, nc_color pcolor, material pm1, material pm2,
        unsigned char pvolume, unsigned char pweight,
@@ -294,11 +312,12 @@ struct it_comest : public itype
  itype_id tool;		// Tool needed to consume (e.g. lighter for cigarettes)
 
  virtual bool is_food() { return true; }
+ virtual bool count_by_charges() { return charges > 1; }
 
  void (iuse::*use)(game *, player *, item *, bool);// Special effects of use
  add_type add;				// Effects of addiction
 
- it_comest(unsigned short pid, unsigned char prarity, unsigned int pprice,
+ it_comest(int pid, unsigned char prarity, unsigned int pprice,
            std::string pname, std::string pdes,
            char psym, nc_color pcolor, material pm1,
            unsigned char pvolume, unsigned char pweight,
@@ -338,7 +357,9 @@ struct it_ammo : public itype
  unsigned char count;	// Default charges
 
  virtual bool is_ammo() { return true; }
- it_ammo(unsigned short pid, unsigned char prarity, unsigned int pprice,
+ virtual bool count_by_charges() { return true; }
+
+ it_ammo(int pid, unsigned char prarity, unsigned int pprice,
         std::string pname, std::string pdes,
         char psym, nc_color pcolor, material pm1,
         unsigned char pvolume, unsigned char pweight,
@@ -374,7 +395,7 @@ struct it_gun : public itype
 
  virtual bool is_gun() { return true; }
 
- it_gun(unsigned short pid, unsigned char prarity, unsigned int pprice,
+ it_gun(int pid, unsigned char prarity, unsigned int pprice,
         std::string pname, std::string pdes,
         char psym, nc_color pcolor, material pm1, material pm2,
         unsigned char pvolume, unsigned char pweight,
@@ -410,7 +431,7 @@ struct it_gunmod : public itype
 
  virtual bool is_gunmod() { return true; }
 
- it_gunmod(unsigned short pid, unsigned char prarity, unsigned int pprice,
+ it_gunmod(int pid, unsigned char prarity, unsigned int pprice,
            std::string pname, std::string pdes,
            char psym, nc_color pcolor, material pm1, material pm2,
            unsigned char pvolume, unsigned char pweight,
@@ -449,8 +470,23 @@ struct it_armor : public itype
  unsigned char env_resist; // Resistance to environmental effects
  signed char warmth;
  unsigned char storage;
+
  virtual bool is_armor() { return true; }
- it_armor(unsigned short pid, unsigned char prarity, unsigned int pprice,
+ virtual bool is_artifact() { return false; }
+ virtual std::string save_data() { return std::string(); }
+
+ it_armor()
+ {
+  covers = 0;
+  encumber = 0;
+  dmg_resist = 0;
+  cut_resist = 0;
+  env_resist = 0;
+  warmth = 0;
+  storage = 0;
+ }
+
+ it_armor(int pid, unsigned char prarity, unsigned int pprice,
           std::string pname, std::string pdes,
           char psym, nc_color pcolor, material pm1, material pm2,
           unsigned char pvolume, unsigned char pweight,
@@ -483,7 +519,7 @@ struct it_book : public itype
  unsigned char time;	// How long, in 10-turns (aka minutes), it takes to read
 			// "To read" means getting 1 skill point, not all of em
  virtual bool is_book() { return true; }
- it_book(unsigned short pid, unsigned char prarity, unsigned int pprice,
+ it_book(int pid, unsigned char prarity, unsigned int pprice,
          std::string pname, std::string pdes,
          char psym, nc_color pcolor, material pm1, material pm2,
          unsigned char pvolume, unsigned char pweight,
@@ -515,7 +551,7 @@ struct it_container : public itype
  unsigned char contains;	// Internal volume
  unsigned flags : num_con_flags;
  virtual bool is_container() { return true; }
- it_container(unsigned short pid, unsigned char prarity, unsigned int pprice,
+ it_container(int pid, unsigned char prarity, unsigned int pprice,
               std::string pname, std::string pdes,
               char psym, nc_color pcolor, material pm1, material pm2,
               unsigned char pvolume, unsigned char pweight,
@@ -539,8 +575,23 @@ struct it_tool : public itype
  unsigned char turns_per_charge;
  itype_id revert_to;
  void (iuse::*use)(game *, player *, item *, bool);
- virtual bool is_tool() { return true; }
- it_tool(unsigned short pid, unsigned char prarity, unsigned int pprice,
+
+ virtual bool is_tool()          { return true; }
+ virtual bool is_artifact()      { return false; }
+ virtual std::string save_data() { return std::string(); }
+
+ it_tool()
+ {
+  ammo = AT_NULL;
+  max_charges = 0;
+  def_charges = 0;
+  charges_per_use = 0;
+  turns_per_charge = 0;
+  revert_to = itm_null;
+  use = &iuse::none;
+ }
+
+ it_tool(int pid, unsigned char prarity, unsigned int pprice,
          std::string pname, std::string pdes,
          char psym, nc_color pcolor, material pm1, material pm2,
          unsigned char pvolume, unsigned char pweight,
@@ -570,7 +621,7 @@ struct it_bionic : public itype
 
  virtual bool is_bionic()    { return true; }
 
- it_bionic(unsigned short pid, unsigned char prarity, unsigned int pprice,
+ it_bionic(int pid, unsigned char prarity, unsigned int pprice,
            std::string pname, std::string pdes,
            char psym, nc_color pcolor, material pm1, material pm2,
            unsigned char pvolume, unsigned char pweight,
@@ -584,7 +635,7 @@ struct it_bionic : public itype
    va_list ap;
    va_start(ap, pdifficulty);
    bionic_id tmp;
-   while (tmp = (bionic_id)va_arg(ap, int))
+   while ((tmp = (bionic_id)va_arg(ap, int)))
     options.push_back(tmp);
    va_end(ap);
  }
@@ -597,7 +648,7 @@ struct it_macguffin : public itype
  
  virtual bool is_macguffin() { return true; }
 
- it_macguffin(unsigned short pid, unsigned char prarity, unsigned int pprice,
+ it_macguffin(int pid, unsigned char prarity, unsigned int pprice,
               std::string pname, std::string pdes,
               char psym, nc_color pcolor, material pm1, material pm2,
               unsigned char pvolume, unsigned char pweight,
@@ -613,4 +664,119 @@ struct it_macguffin : public itype
  }
 };
 
+struct it_artifact_tool : public it_tool
+{
+ art_charge charge_type;
+ std::vector<art_effect_passive> effects_wielded;
+ std::vector<art_effect_active>  effects_activated;
+ std::vector<art_effect_passive> effects_carried;
+
+ virtual bool is_artifact()  { return true; }
+ virtual std::string save_data()
+ {
+  std::stringstream data;
+  data << "T " << price << " " << sym << " " << color_to_int(color) << " " <<
+          int(m1) << " " << int(m2) << " " << int(volume) << " " <<
+          int(weight) << " " << int(melee_dam) << " " << int(melee_cut) <<
+          " " << int(m_to_hit) << " " << int(item_flags) << " " <<
+          int(charge_type) << " " << max_charges << " " <<
+          effects_wielded.size();
+  for (int i = 0; i < effects_wielded.size(); i++)
+   data << " " << int(effects_wielded[i]);
+
+  data << " " << effects_activated.size();
+  for (int i = 0; i < effects_activated.size(); i++)
+   data << " " << int(effects_activated[i]);
+
+  data << " " << effects_carried.size();
+  for (int i = 0; i < effects_carried.size(); i++)
+   data << " " << int(effects_carried[i]);
+
+  data << " " << name << " - ";
+  std::string desctmp = description;
+  size_t endline;
+  do {
+   endline = desctmp.find("\n");
+   if (endline != std::string::npos)
+    desctmp.replace(endline, 1, " = ");
+  } while (endline != std::string::npos);
+  data << desctmp << " -";
+  return data.str();
+ }
+
+ it_artifact_tool() {
+  ammo = AT_NULL;
+  price = 0;
+  def_charges = 0;
+  charges_per_use = 1;
+  turns_per_charge = 0;
+  revert_to = itm_null;
+  use = &iuse::artifact;
+ };
+
+ it_artifact_tool(int pid, unsigned int pprice, std::string pname,
+                  std::string pdes, char psym, nc_color pcolor, material pm1,
+                  material pm2, unsigned char pvolume, unsigned char pweight,
+                  signed char pmelee_dam, signed char pmelee_cut,
+                  signed char pm_to_hit, unsigned pitem_flags)
+
+:it_tool(pid, 0, pprice, pname, pdes, psym, pcolor, pm1, pm2,
+         pvolume, pweight, pmelee_dam, pmelee_cut, pm_to_hit, pitem_flags,
+         0, 0, 1, 0, AT_NULL, itm_null, &iuse::artifact) { };
+};
+
+struct it_artifact_armor : public it_armor
+{
+ std::vector<art_effect_passive> effects_worn;
+
+ virtual bool is_artifact()  { return true; }
+
+ virtual std::string save_data()
+ {
+  std::stringstream data;
+  data << "A " << price << " " << sym << " " << color_to_int(color) << " " <<
+          int(m1) << " " << int(m2) << " " << int(volume) << " " <<
+          int(weight) << " " << int(melee_dam) << " " << int(melee_cut) <<
+          " " << int(m_to_hit) << " " << int(item_flags) << " " <<
+          int(covers) << " " << int(encumber) << " " << int(dmg_resist) <<
+          " " << int(cut_resist) << " " << int(env_resist) << " " <<
+          int(warmth) << " " << int(storage) << " " << effects_worn.size();
+  for (int i = 0; i < effects_worn.size(); i++)
+   data << " " << int(effects_worn[i]);
+
+  data << " " << name << " - ";
+  std::string desctmp = description;
+  size_t endline;
+  do {
+   endline = desctmp.find("\n");
+   if (endline != std::string::npos)
+    desctmp.replace(endline, 1, " = ");
+  } while (endline != std::string::npos);
+
+  data << desctmp << " -";
+
+  return data.str();
+ }
+
+ it_artifact_armor()
+ {
+  price = 0;
+ };
+
+ it_artifact_armor(int pid, unsigned int pprice, std::string pname,
+                   std::string pdes, char psym, nc_color pcolor, material pm1,
+                   material pm2, unsigned char pvolume, unsigned char pweight,
+                   signed char pmelee_dam, signed char pmelee_cut,
+                   signed char pm_to_hit, unsigned pitem_flags,
+
+                   unsigned char pcovers, signed char pencumber,
+                   unsigned char pdmg_resist, unsigned char pcut_resist,
+                   unsigned char penv_resist, signed char pwarmth,
+                   unsigned char pstorage)
+:it_armor(pid, 0, pprice, pname, pdes, psym, pcolor, pm1, pm2,
+          pvolume, pweight, pmelee_dam, pmelee_cut, pm_to_hit, pitem_flags,
+          pcovers, pencumber, pdmg_resist, pcut_resist, penv_resist, pwarmth,
+          pstorage) { };
+};
+
 #endif
