@@ -31,9 +31,11 @@ void iuse::royal_jelly(game *g, player *p, item *it, bool t)
   message = "Your sight returns!";
   p->rem_disease(DI_BLIND);
  }
- if (p->has_disease(DI_POISON) || p->has_disease(DI_FOODPOISON)) {
+ if (p->has_disease(DI_POISON) || p->has_disease(DI_FOODPOISON) ||
+     p->has_disease(DI_BADPOISON)) {
   message = "You feel much better!";
   p->rem_disease(DI_POISON);
+  p->rem_disease(DI_BADPOISON);
   p->rem_disease(DI_FOODPOISON);
  }
  if (p->has_disease(DI_ASTHMA)) {
@@ -513,7 +515,7 @@ void iuse::purifier(game *g, player *p, item *it, bool t)
 {
  std::vector<int> valid;	// Which flags the player has
  for (int i = 0; i < PF_MAX2; i++) {
-  if (p->has_mutation(pl_flag(i))|| p->has_trait(pl_flag(i)) && traits[i].curable)
+  if (p->has_mutation(pl_flag(i)))
    valid.push_back(i);
  }
  if (valid.size() == 0) {
@@ -592,6 +594,33 @@ void iuse::marloss(game *g, player *p, item *it, bool t)
  if (effect == 6)
   p->radiation = 0;
 }
+
+void iuse::dogfood(game *g, player *p, item *it, bool t)
+{
+ int dirx, diry;
+ g->draw();
+ mvprintw(0, 0, "Which direction?");
+ get_direction(dirx, diry, input());
+ if (dirx == -2) {
+  g->add_msg("Invalid direction.");
+  return;
+ }
+ p->moves -= 15;
+ dirx += p->posx;
+ diry += p->posy;
+ int mon_dex = g->mon_at(dirx,diry);
+ if(mon_dex != -1){
+	 if(g->z[mon_dex].type->id == mon_dog){
+		 g->add_msg("The dog seems to like you!");
+		 g->z[mon_dex].friendly = -1;
+	 } else {
+		 g->add_msg("The %s seems quit unimpressed!",g->z[mon_dex].type->name.c_str());
+	 }
+ } else {
+	 g->add_msg("You spill the dogfood all over the ground.");
+ }
+
+}
   
  
 
@@ -605,13 +634,19 @@ void iuse::lighter(game *g, player *p, item *it, bool t)
  get_direction(dirx, diry, input());
  if (dirx == -2) {
   g->add_msg("Invalid direction.");
+  it->charges++;
   return;
  }
  p->moves -= 15;
  dirx += p->posx;
  diry += p->posy;
- if (g->m.add_field(g, dirx, diry, fd_fire, 1))
-  g->m.field_at(dirx, diry).age = 1400;
+ if (g->m.flammable_items_at(dirx, diry)) {
+  if (g->m.add_field(g, dirx, diry, fd_fire, 1))
+   g->m.field_at(dirx, diry).age = 30;
+ } else {
+  g->add_msg("There's nothing to light there.");
+  it->charges++;
+ }
 }
 
 void iuse::sew(game *g, player *p, item *it, bool t)
@@ -826,7 +861,7 @@ void iuse::extinguisher(game *g, player *p, item *it, bool t)
 void iuse::hammer(game *g, player *p, item *it, bool t)
 {
  g->draw();
- mvprintz(0, 0, c_red, "Pick a direction in which to construct:");
+ mvprintz(0, 0, c_red, "Pick a direction in which to pry:");
  int dirx, diry;
  get_direction(dirx, diry, input());
  if (dirx == -2) {
@@ -835,74 +870,32 @@ void iuse::hammer(game *g, player *p, item *it, bool t)
  }
  dirx += p->posx;
  diry += p->posy;
- WINDOW* w = newwin(7, 40, 9, 30);
- wborder(w, LINE_XOXO, LINE_XOXO, LINE_OXOX, LINE_OXOX,
-            LINE_OXXO, LINE_OOXX, LINE_XXOO, LINE_XOOX );
  int nails = 0, boards = 0;
- std::string title;
  ter_id newter;
  switch (g->m.ter(dirx, diry)) {
- case t_door_b:
-  title = "Repair Door";
+ case t_window_boarded:
+  nails =  8;
+  boards = 3;
+  newter = t_window_empty;
+  break;
+ case t_door_boarded:
   nails = 12;
   boards = 3;
-  newter = t_door_c;
-  break;
- case t_door_c:
- case t_door_locked:
-  title = "Board Up Door";
-  nails = 12;
-  boards = 3;
-  newter = t_door_boarded;
-  break;
- case t_door_frame:
-  title = "Board Up Door Frame";
-  nails = 24;
-  boards = 6;
-  newter = t_door_boarded;
-  break;
- case t_window:
- case t_window_frame:
-  title = "Board Up Window";
-  nails = 4;
-  boards = 2;
-  newter = t_window_boarded;
+  newter = t_door_b;
   break;
  default:
-  title = "";
-  nails = 0;
-  boards = 0;
- }
- if (nails == 0) {
-  g->add_msg("Nothing to board up there!");
+  g->add_msg("Hammers can only remove boards from windows and doors.");
+  g->add_msg("To board up a window or door, press *");
   return;
  }
- nc_color col;
- mvwprintz(w, 1, 1, c_white, title.c_str());
- col = (p->has_charges(itm_nail, nails) ? c_green : c_red);
- mvwprintz(w, 2, 1, col, "> %d nails", nails);
- col = (p->has_amount(itm_2x4, boards) ? c_green : c_red);
- mvwprintz(w, 3, 1, col, "> %d two by fours", boards);
-
- if (p->has_charges(itm_nail, nails) && p->has_amount(itm_2x4, boards)) {
-  mvwprintz(w, 5, 1, c_yellow, "Perform action? (y/n)");
-  wrefresh(w);
-  char ch;
-  do
-   ch = getch();
-  while (ch != 'y' && ch != 'Y' && ch != 'n' && ch != 'N');
-  if (ch == 'y' || ch == 'Y') {
-   p->moves -= boards * 50;
-   p->use_charges(itm_nail, nails);
-   p->use_amount(itm_2x4, boards);
-   g->m.ter(dirx, diry) = newter;
-  }
- } else {
-  mvwprintz(w, 5, 1, c_red, "Cannot perform action.");
-  wrefresh(w);
-  getch();
- }
- delwin(w);
+ p->moves -= 500;
+ item it_nails(g->itypes[itm_nail], 0, g->nextinv);
+ it_nails.charges = nails;
+ g->m.add_item(p->posx, p->posy, it_nails);
+ item board(g->itypes[itm_2x4], 0, g->nextinv);
+ for (int i = 0; i < boards; i++)
+  g->m.add_item(p->posx, p->posy, board);
+ g->m.ter(dirx, diry) = newter;
 }
  
 void iuse::light_off(game *g, player *p, item *it, bool t)
@@ -939,13 +932,13 @@ void iuse::water_purifier(game *g, player *p, item *it, bool t)
   return;
  }
  item *pure = &(p->i_at(ch).contents[0]);
- if (pure->type->id != itm_water && pure->type->id != itm_water_dirty &&
-     pure->type->id != itm_salt_water) {
+ if (pure->type->id != itm_water && pure->type->id != itm_salt_water) {
   g->add_msg("You can only purify water.");
   return;
  }
  p->moves -= 150;
  pure->make(g->itypes[itm_water]);
+ pure->poison = 0;
 }
 
 void iuse::two_way_radio(game *g, player *p, item *it, bool t)
@@ -1100,8 +1093,33 @@ void iuse::crowbar(game *g, player *p, item *it, bool t)
    g->add_msg("You pry, but cannot lift the manhole cover.");
    p->moves -= 100;
   }
- } else
-  g->add_msg("There's nothing to pry there.");
+ } else {
+  int nails = 0, boards = 0;
+  ter_id newter;
+  switch (g->m.ter(dirx, diry)) {
+  case t_window_boarded:
+   nails =  8;
+   boards = 3;
+   newter = t_window_empty;
+   break;
+  case t_door_boarded:
+   nails = 12;
+   boards = 3;
+   newter = t_door_b;
+   break;
+  default:
+   g->add_msg("There's nothing to pry there.");
+   return;
+  }
+  p->moves -= 500;
+  item it_nails(g->itypes[itm_nail], 0, g->nextinv);
+  it_nails.charges = nails;
+  g->m.add_item(p->posx, p->posy, it_nails);
+  item board(g->itypes[itm_2x4], 0, g->nextinv);
+  for (int i = 0; i < boards; i++)
+   g->m.add_item(p->posx, p->posy, board);
+  g->m.ter(dirx, diry) = newter;
+ }
 }
 
 void iuse::makemound(game *g, player *p, item *it, bool t)
@@ -1207,13 +1225,20 @@ void iuse::set_trap(game *g, player *p, item *it, bool t)
  int practice;
 
  switch (it->type->id) {
+ case itm_boobytrap:
+  message << "You set the boobytrap up and activate the grenade.";
+  type = tr_boobytrap;
+  practice = 4;
+  break;
  case itm_bubblewrap:
   message << "You set the bubblewrap on the ground, ready to be popped.";
   type = tr_bubblewrap;
   practice = 2;
   break;
  case itm_beartrap:
-  buried = (p->has_amount(itm_shovel, 1) && query_yn("Bury the beartrap?"));
+  buried = (p->has_amount(itm_shovel, 1) &&
+            g->m.has_flag(diggable, posx, posy) &&
+            query_yn("Bury the beartrap?"));
   type = (buried ? tr_beartrap_buried : tr_beartrap);
   message << "You " << (buried ? "bury" : "set") << " the beartrap.";
   practice = (buried ? 7 : 4); 
@@ -1357,7 +1382,8 @@ void iuse::geiger(game *g, player *p, item *it, bool t)
 
 void iuse::teleport(game *g, player *p, item *it, bool t)
 {
- g->teleport();
+ p->moves -= 100;
+ g->teleport(p);
 }
 
 void iuse::can_goo(game *g, player *p, item *it, bool t)
@@ -1448,7 +1474,50 @@ void iuse::grenade_act(game *g, player *p, item *it, bool t)
  if (t) // Simple timer effects
   g->sound(pos.x, pos.y, 0, "Tick.");	// Vol 0 = only heard if you hold it
  else	// When that timer runs down...
-  g->explosion(pos.x, pos.y, 18, 12, false);
+  g->explosion(pos.x, pos.y, 12, 28, false);
+}
+
+void iuse::flashbang(game *g, player *p, item *it, bool t)
+{
+ g->add_msg("You pull the pin on the flashbang.");
+ it->make(g->itypes[itm_flashbang_act]);
+ it->charges = 5;
+ it->active = true;
+}
+
+void iuse::flashbang_act(game *g, player *p, item *it, bool t)
+{
+ point pos = g->find_item(it);
+ if (pos.x == -999 || pos.y == -999)
+  return;
+ if (t) // Simple timer effects
+  g->sound(pos.x, pos.y, 0, "Tick.");	// Vol 0 = only heard if you hold it
+ else	// When that timer runs down...
+  g->flashbang(pos.x, pos.y);
+}
+
+void iuse::c4(game *g, player *p, item *it, bool t)
+{
+ int time = query_int("Set the timer to (0 to cancel)?");
+ if (time == 0) {
+  g->add_msg("Never mind.");
+  return;
+ }
+ g->add_msg("You set the timer to %d.", time);
+ it->make(g->itypes[itm_c4armed]);
+ it->charges = time;
+ it->active = true;
+}
+
+void iuse::c4armed(game *g, player *p, item *it, bool t)
+{
+ point pos = g->find_item(it);
+ if (pos.x == -999 || pos.y == -999)
+  return;
+ if (t) // Simple timer effects
+  g->sound(pos.x, pos.y, 0, "Tick.");	// Vol 0 = only heard if you hold it
+ else	// When that timer runs down...
+  g->explosion(pos.x, pos.y, 40, 3, false);
 }
 
 void iuse::EMPbomb(game *g, player *p, item *it, bool t)
@@ -1773,10 +1842,6 @@ void iuse::tazer(game *g, player *p, item *it, bool t)
    g->add_msg("You attempt to shock the %s, but miss.", z->name().c_str());
    return;
   }
-  if (z->has_flag(MF_SHOCK)) {
-   g->add_msg("You shock the %s, but it seems immune!", z->name().c_str());
-   return;
-  }
   g->add_msg("You shock the %s!", z->name().c_str());
   int shock = rng(5, 25);
   z->moves -= shock * 100;
@@ -1882,10 +1947,10 @@ void iuse::mcg_note(game *g, player *p, item *it, bool t)
 {
  std::stringstream message;
  message << "Dear " << it->name << ":\n";
+/*
  faction* fac = NULL;
  direction dir = NORTH;
 // Pick an associated faction
-/*
  switch (it->associated_mission) {
  case MISSION_FIND_FAMILY_FACTION:
   fac = &(g->factions[rng(0, g->factions.size() - 1)]);
@@ -1923,3 +1988,250 @@ you can, I need to know you're alright.";
   popup(message.str().c_str());
 */
 }
+
+void iuse::artifact(game *g, player *p, item *it, bool t)
+{
+ if (!it->is_artifact()) {
+  debugmsg("iuse::artifact called on a non-artifact item! %s",
+           it->tname().c_str());
+  return;
+ } else if (!it->is_tool()) {
+  debugmsg("iuse::artifact called on a non-tool artifact! %s",
+           it->tname().c_str());
+  return;
+ }
+ it_artifact_tool *art = dynamic_cast<it_artifact_tool*>(it->type);
+ int num_used = rng(1, art->effects_activated.size());
+ if (num_used < art->effects_activated.size())
+  num_used += rng(1, art->effects_activated.size() - num_used);
+
+ std::vector<art_effect_active> effects = art->effects_activated;
+ for (int i = 0; i < num_used; i++) {
+  int index = rng(0, effects.size() - 1);
+  art_effect_active used = effects[index];
+  effects.erase(effects.begin() + index);
+
+  switch (used) {
+  case AEA_STORM: {
+   g->sound(p->posx, p->posy, 10, "Ka-BOOM!");
+   int num_bolts = rng(2, 4);
+   for (int j = 0; j < num_bolts; j++) {
+    int xdir = 0, ydir = 0;
+    while (xdir == 0 && ydir == 0) {
+     xdir = rng(-1, 1);
+     ydir = rng(-1, 1);
+    }
+    int dist = rng(4, 12);
+    int boltx = p->posx, bolty = p->posy;
+    for (int n = 0; n < dist; n++) {
+     boltx += xdir;
+     bolty += ydir;
+     g->m.add_field(g, boltx, bolty, fd_electricity, rng(2, 3));
+     if (one_in(4)) {
+      if (xdir == 0)
+       xdir = rng(0, 1) * 2 - 1;
+      else
+       xdir = 0;
+     }
+     if (one_in(4)) {
+      if (ydir == 0)
+       ydir = rng(0, 1) * 2 - 1;
+      else
+       ydir = 0;
+     }
+    }
+   }
+  } break;
+
+  case AEA_FIREBALL: {
+   point fireball = g->look_around();
+   if (fireball.x != -1 && fireball.y != -1)
+    g->explosion(fireball.x, fireball.y, 8, 0, true);
+  } break;
+
+  case AEA_ADRENALINE:
+   g->add_msg("You're filled with a roaring energy!");
+   p->add_disease(DI_ADRENALINE, rng(200, 250), g);
+   break;
+
+  case AEA_MAP: {
+   bool new_map = false;
+   for (int x = int(g->levx / 2) - 20; x <= int(g->levx / 2) + 20; x++) {
+    for (int y = int(g->levy / 2) - 20; y <= int(g->levy / 2) + 20; y++) {
+     if (!g->cur_om.seen(x, y)) {
+      new_map = true;
+      g->cur_om.seen(x, y) = true;
+     }
+    }
+   }
+   if (new_map) {
+    g->add_msg("You have a vision of the surrounding area...");
+    p->moves -= 100;
+   }
+  } break;
+
+  case AEA_BLOOD: {
+   bool blood = false;
+   int j;
+   for (int x = p->posx - 4; x <= p->posx + 4; x++) {
+    for (int y = p->posy - 4; y <= p->posy + 4; y++) {
+     if (!one_in(4) && g->m.add_field(g, x, y, fd_blood, 3) &&
+         (blood || g->u_see(x, y, j)))
+      blood = true;
+    }
+   }
+   if (blood)
+    g->add_msg("Blood soaks out of the ground and walls.");
+  } break;
+
+  case AEA_FATIGUE: {
+   g->add_msg("The fabric of space seems to decay.");
+   int x = rng(p->posx - 3, p->posx + 3), y = rng(p->posy - 3, p->posy + 3);
+   if (g->m.field_at(x, y).type == fd_fatigue &&
+       g->m.field_at(x, y).density < 3)
+    g->m.field_at(x, y).density++;
+   else
+    g->m.add_field(g, x, y, fd_fatigue, rng(1, 2));
+  } break;
+
+  case AEA_ACIDBALL: {
+   point acidball = g->look_around();
+   if (acidball.x != -1 && acidball.y != -1) {
+    for (int x = acidball.x - 1; x <= acidball.x + 1; x++) {
+     for (int y = acidball.y - 1; y <= acidball.y + 1; y++) {
+      if (g->m.field_at(x, y).type == fd_acid &&
+          g->m.field_at(x, y).density < 3)
+       g->m.field_at(x, y).density++;
+      else
+       g->m.add_field(g, x, y, fd_acid, rng(2, 3));
+     }
+    }
+   }
+  } break;
+
+  case AEA_PULSE:
+   g->sound(p->posx, p->posy, 30, "The earth shakes!");
+   for (int x = p->posx - 2; x <= p->posx + 2; x++) {
+    for (int y = p->posy - 2; y <= p->posy + 2; y++) {
+     std::string junk;
+     g->m.bash(x, y, 40, junk);
+     g->m.bash(x, y, 40, junk);  // Multibash effect, so that doors &c will fall
+     g->m.bash(x, y, 40, junk);
+     if (g->m.is_destructable(x, y) && rng(1, 10) >= 3)
+      g->m.ter(x, y) = t_rubble;
+    }
+   }
+   break;
+
+  case AEA_HEAL:
+   g->add_msg("You feel healed.");
+   p->healall(2);
+   break;
+
+  case AEA_CONFUSED:
+   for (int x = p->posx - 8; x <= p->posx + 8; x++) {
+    for (int y = p->posy - 8; y <= p->posy + 8; y++) {
+     int mondex = g->mon_at(x, y);
+     if (mondex != -1)
+      g->z[mondex].add_effect(ME_STUNNED, rng(5, 15));
+    }
+   }
+
+  case AEA_ENTRANCE:
+   for (int x = p->posx - 8; x <= p->posx + 8; x++) {
+    for (int y = p->posy - 8; y <= p->posy + 8; y++) {
+     int mondex = g->mon_at(x, y);
+     if (mondex != -1 &&  g->z[mondex].friendly == 0 &&
+         rng(0, 600) > g->z[mondex].hp)
+      g->z[mondex].make_friendly();
+    }
+   }
+   break;
+
+  case AEA_BUGS: {
+   int roll = rng(1, 10);
+   mon_id bug = mon_null;
+   int num = 0;
+   std::vector<point> empty;
+   for (int x = p->posx - 1; x <= p->posx + 1; x++) {
+    for (int y = p->posy - 1; y <= p->posy + 1; y++) {
+     if (g->is_empty(x, y))
+      empty.push_back( point(x, y) );
+    }
+   }
+   if (empty.empty() == 0 || roll <= 4)
+    g->add_msg("Flies buzz around you.");
+   else if (roll <= 7) {
+    g->add_msg("Giant flies appear!");
+    bug = mon_fly;
+    num = rng(2, 4);
+   } else if (roll <= 9) {
+    g->add_msg("Giant bees appear!");
+    bug = mon_bee;
+    num = rng(1, 3);
+   } else {
+    g->add_msg("Giant wasps appear!");
+    bug = mon_wasp;
+    num = rng(1, 2);
+   }
+   if (bug != mon_null) {
+    monster spawned(g->mtypes[bug]);
+    for (int i = 0; i < num && !empty.empty(); i++) {
+     int index = rng(0, empty.size() - 1);
+     point spawnp = empty[index];
+     empty.erase(empty.begin() + index);
+     spawned.spawn(spawnp.x, spawnp.y);
+     g->z.push_back(spawned);
+    }
+   }
+  } break;
+    
+
+  case AEA_RADIATION:
+   g->add_msg("Horrible gasses are emitted!");
+   for (int x = p->posx - 1; x <= p->posx + 1; x++) {
+    for (int y = p->posy - 1; y <= p->posy + 1; y++)
+     g->m.add_field(g, x, y, fd_nuke_gas, rng(2, 3));
+   }
+   break;
+
+  case AEA_PAIN:
+   g->add_msg("You're wracked with pain!");
+   p->pain += rng(5, 15);
+   break;
+
+  case AEA_MUTATE:
+   if (!one_in(3))
+    p->mutate(g);
+   break;
+
+  case AEA_PARALYZE:
+   g->add_msg("You're paralyzed!");
+   p->moves -= rng(50, 200);
+   break;
+
+  case AEA_FIRESTORM:
+   g->add_msg("Fire rains down around you!");
+   for (int x = p->posx - 3; x <= p->posx + 3; x++) {
+    for (int y = p->posy - 3; y <= p->posy + 3; y++) {
+     if (!one_in(3)) {
+      if (g->m.add_field(g, x, y, fd_fire, 1 + rng(0, 1) * rng(0, 1)))
+       g->m.field_at(x, y).age = 30;
+     }
+    }
+   }
+   break;
+
+  case AEA_ATTENTION:
+   g->add_msg("You feel like your action has attracted attention.");
+   p->add_disease(DI_ATTENTION, 600 * rng(3, 6), g);
+   break;
+
+  case AEA_TELEGLOW:
+   g->add_msg("You feel unhinged.");
+   p->add_disease(DI_TELEGLOW, 100 * rng(3, 12), g);
+   break;
+
+  }
+ }
+}
