@@ -39,6 +39,8 @@ class iuse
   void mutagen		(game *g, player *p, item *it, bool t);
   void purifier		(game *g, player *p, item *it, bool t);
   void marloss		(game *g, player *p, item *it, bool t);
+  void dogfood		(game *g, player *p, item *it, bool t);
+
 // TOOLS
   void lighter		(game *g, player *p, item *it, bool t);
   void sew		(game *g, player *p, item *it, bool t);
@@ -65,6 +67,10 @@ class iuse
   void pipebomb_act	(game *g, player *p, item *it, bool t);
   void grenade		(game *g, player *p, item *it, bool t);
   void grenade_act	(game *g, player *p, item *it, bool t);
+  void flashbang	(game *g, player *p, item *it, bool t);
+  void flashbang_act	(game *g, player *p, item *it, bool t);
+  void c4    		(game *g, player *p, item *it, bool t);
+  void c4armed  	(game *g, player *p, item *it, bool t);
   void EMPbomb		(game *g, player *p, item *it, bool t);
   void EMPbomb_act	(game *g, player *p, item *it, bool t);
   void gasbomb		(game *g, player *p, item *it, bool t);
@@ -90,6 +96,10 @@ class iuse
 // MACGUFFINS
   void mcg_note		(game *g, player *p, item *it, bool t);
 // ARTIFACTS
+// This function is used when an artifact is activated
+// It examines the item's artifact-specific properties
+// See artifact.h for a list
+  void artifact		(game *g, player *p, item *it, bool t);
   void heal		(game *g, player *p, item *it, bool t);
   void twist_space	(game *g, player *p, item *it, bool t);
   void mass_vampire	(game *g, player *p, item *it, bool t);
