@@ -127,7 +127,19 @@ bool map::is_outside(int x, int y)
          ter(x + 1, y - 1) != t_floor_wax &&
          ter(x + 1, y    ) != t_floor_wax &&
          ter(x + 1, y + 1) != t_floor_wax   );
-;
+}
+
+bool map::flammable_items_at(int x, int y)
+{
+ for (int i = 0; i < i_at(x, y).size(); i++) {
+  item *it = &(i_at(x, y)[i]);
+  if (it->made_of(PAPER) || it->made_of(WOOD) || it->made_of(COTTON) ||
+      it->made_of(POWDER) || it->made_of(VEGGY) || it->is_ammo() ||
+      it->type->id == itm_whiskey || it->type->id == itm_vodka ||
+      it->type->id == itm_rum || it->type->id == itm_tequila)
+   return true;
+ }
+ return false;
 }
 
 point map::random_outdoor_tile()
@@ -148,8 +160,11 @@ point map::random_outdoor_tile()
 bool map::bash(int x, int y, int str, std::string &sound)
 {
  sound = "";
- if (field_at(x, y).type == fd_web)
-  field_at(x, y).type == fd_null;
+ bool smashed_web = false;
+ if (field_at(x, y).type == fd_web) {
+  smashed_web = true;
+  field_at(x, y) = field();
+ }
 
  for (int i = 0; i < i_at(x, y).size(); i++) {	// Destroy glass items (maybe)
   if (i_at(x, y)[i].made_of(GLASS) && one_in(2)) {
@@ -250,7 +265,7 @@ bool map::bash(int x, int y, int str, std::string &sound)
   }
   break;
  case t_toilet:
-  if (str >= dice(8, 10) - 8) {
+  if (str >= dice(8, 4) - 8) {
    sound += "porcelain breaking!";
    ter(x, y) = t_rubble;
    return true;
@@ -277,6 +292,7 @@ bool map::bash(int x, int y, int str, std::string &sound)
  case t_wall_glass_v:
  case t_wall_glass_h_alarm:
  case t_wall_glass_v_alarm:
+ case t_door_glass_c:
   if (str >= rng(0, 20)) {
    sound += "glass breaking!";
    ter(x, y) = t_floor;
@@ -344,7 +360,7 @@ bool map::bash(int x, int y, int str, std::string &sound)
   sound += "thump!";
   return true;
  }
- return false;	// If we kick empty space, the action is cancelled
+ return smashed_web;// If we kick empty space, the action is cancelled
 }
 
 // map::destroy is only called (?) if the terrain is NOT bashable.
@@ -434,8 +450,7 @@ void map::shoot(game *g, int x, int y, int &dam, bool hit_items, unsigned flags)
  case t_window:
  case t_window_alarm:
   dam -= rng(0, 5);
-  if (dam > 0)
-   ter(x, y) = t_window_frame;
+  ter(x, y) = t_window_frame;
   break;
 
  case t_window_boarded:
@@ -449,8 +464,7 @@ void map::shoot(game *g, int x, int y, int &dam, bool hit_items, unsigned flags)
  case t_wall_glass_h_alarm:
  case t_wall_glass_v_alarm:
   dam -= rng(0, 8);
-  if (dam > 0)
-   ter(x, y) = t_floor;
+  ter(x, y) = t_floor;
   break;
 
  case t_paper:
@@ -495,6 +509,9 @@ void map::shoot(game *g, int x, int y, int &dam, bool hit_items, unsigned flags)
    dam -= (rng(0, 1) * rng(0, 1) * rng(0, 1));
  }
 
+ if (flags & mfb(IF_AMMO_TRAIL) && !one_in(4))
+  add_field(g, x, y, fd_smoke, rng(1, 2));
+
 // Now, destroy items on that tile.
 
  if ((move_cost(x, y) == 2 && !hit_items) || !inbounds(x, y))
@@ -576,7 +593,8 @@ bool map::hit_with_acid(game *g, int x, int y)
   case t_gas_pump_smashed:
    return false;
 
-  case t_card_reader:
+  case t_card_science:
+  case t_card_military:
    ter(x, y) = t_card_reader_broken;
    break;
  }
@@ -608,6 +626,9 @@ bool map::open_door(int x, int y, bool inside)
  } else if (ter(x, y) == t_door_metal_c) {
   ter(x, y) = t_door_metal_o;
   return true;
+ } else if (ter(x, y) == t_door_glass_c) {
+  ter(x, y) = t_door_glass_o;
+  return true;
  } else if (inside &&
             (ter(x, y) == t_door_locked || ter(x, y) == t_door_locked_alarm)) {
   ter(x, y) = t_door_o;
@@ -639,6 +660,9 @@ bool map::close_door(int x, int y)
  } else if (ter(x, y) == t_door_metal_o) {
   ter(x, y) = t_door_metal_c;
   return true;
+ } else if (ter(x, y) == t_door_glass_o) {
+  ter(x, y) = t_door_glass_c;
+  return true;
  }
  return false;
 }
@@ -667,29 +691,16 @@ std::vector<item>& map::i_at(int x, int y)
 
 item map::water_from(int x, int y)
 {
- item ret((*itypes)[itm_null], 0);
- int rn = rng(1, 10);
- if (ter(x, y) == t_water_sh) {
-  if (rn <= 3)
-   ret.type = (*itypes)[itm_water_dirty];
-  else
-   ret.type = (*itypes)[itm_water];
- } else if (ter(x, y) == t_water_dp) {
-  if (rn <= 2)
-   ret.type = (*itypes)[itm_water_dirty];
-  else
-   ret.type = (*itypes)[itm_water];
- } else if (ter(x, y) == t_sewage) {
-  if (rn <= 9)
-   ret.type = (*itypes)[itm_water_dirty];
-  else
-   ret.type = (*itypes)[itm_water];
- } else if (ter(x, y) == t_toilet) {
-  if (rn <= 8)
-   ret.type = (*itypes)[itm_water_dirty];
-  else
-   ret.type = (*itypes)[itm_water];
- }
+ item ret((*itypes)[itm_water], 0);
+ if (ter(x, y) == t_water_sh && one_in(3))
+  ret.poison = rng(1, 4);
+ else if (ter(x, y) == t_water_dp && one_in(4))
+  ret.poison = rng(1, 4);
+ else if (ter(x, y) == t_sewage)
+  ret.poison = rng(1, 7);
+ else if (ter(x, y) == t_toilet && !one_in(3))
+  ret.poison = rng(1, 3);
+
  return ret;
 }
 
@@ -725,6 +736,8 @@ void map::add_item(int x, int y, itype* type, int birthday)
 {
  item tmp(type, birthday);
  tmp = tmp.in_its_container(itypes);
+ if (tmp.made_of(LIQUID) && has_flag(swimmable, x, y))
+  return;
  add_item(x, y, tmp);
 }
 
@@ -732,6 +745,8 @@ void map::add_item(int x, int y, item new_item)
 {
  if (!inbounds(x, y))
   return;
+ if (new_item.made_of(LIQUID) && has_flag(swimmable, x, y))
+  return;
  if (has_flag(noitem, x, y) || i_at(x, y).size() >= 26) {// Too many items there
   std::vector<point> okay;
   for (int i = x - 1; i <= x + 1; i++) {
@@ -787,7 +802,8 @@ void map::process_active_items(game *g)
  }
 }
 
-void map::use_amount(point origin, int range, itype_id type, int quantity)
+void map::use_amount(point origin, int range, itype_id type, int quantity,
+                     bool use_container)
 {
  for (int radius = 0; radius <= range && quantity > 0; radius++) {
   for (int x = origin.x - radius; x <= origin.x + radius; x++) {
@@ -797,13 +813,19 @@ void map::use_amount(point origin, int range, itype_id type, int quantity)
     else {
      for (int n = 0; n < i_at(x, y).size() && quantity > 0; n++) {
       item* curit = &(i_at(x, y)[n]);
-      for (int m = 0; m < curit->contents.size(); m++) {
+      bool used_contents = false;
+      for (int m = 0; m < curit->contents.size() && quantity > 0; m++) {
        if (curit->contents[m].type->id == type) {
+        quantity--;
         curit->contents.erase(curit->contents.begin() + m);
         m--;
+        used_contents = true;
        }
       }
-      if (curit->type->id == type) {
+      if (use_container && used_contents) {
+       i_rem(x, y, n);
+       n--;
+      } else if (curit->type->id == type && quantity > 0) {
        quantity--;
        i_rem(x, y, n);
        n--;
@@ -828,7 +850,7 @@ void map::use_charges(point origin, int range, itype_id type, int quantity)
 // Check contents first
       for (int m = 0; m < curit->contents.size() && quantity > 0; m++) {
        if (curit->contents[m].type->id == type) {
-        if (curit->contents[m].charges < quantity) {
+        if (curit->contents[m].charges <= quantity) {
          quantity -= curit->contents[m].charges;
          if (curit->contents[m].destroyed_at_zero_charges()) {
           curit->contents.erase(curit->contents.begin() + m);
@@ -843,7 +865,7 @@ void map::use_charges(point origin, int range, itype_id type, int quantity)
       }
 // Now check the actual item
       if (curit->type->id == type) {
-       if (curit->charges < quantity) {
+       if (curit->charges <= quantity) {
         quantity -= curit->charges;
         if (curit->destroyed_at_zero_charges()) {
          i_rem(x, y, n);
@@ -977,12 +999,14 @@ void map::draw(game *g, WINDOW* w)
  int light = g->u.sight_range(g->light_level());
  for  (int realx = g->u.posx - SEEX; realx <= g->u.posx + SEEX; realx++) {
   for (int realy = g->u.posy - SEEY; realy <= g->u.posy + SEEY; realy++) {
-   if (rl_dist(g->u.posx, g->u.posy, realx, realy) > light) {
+   int dist = rl_dist(g->u.posx, g->u.posy, realx, realy);
+   if (dist > light) {
     if (g->u.has_disease(DI_BOOMERED))
      mvwputch(w, realx+SEEX - g->u.posx, realy+SEEY - g->u.posy, c_magenta,'#');
     else
      mvwputch(w, realx+SEEX - g->u.posx, realy+SEEY - g->u.posy, c_dkgray, '#');
-   } else if (sees(g->u.posx, g->u.posy, realx, realy, light, t))
+   } else if (dist <= g->u.clairvoyance() ||
+              sees(g->u.posx, g->u.posy, realx, realy, light, t))
     drawsq(w, g->u, realx, realy, false, true);
   }
  }
@@ -1121,7 +1145,8 @@ bool map::sees(int Fx, int Fy, int Tx, int Ty, int range, int &tc)
  }
 }
 
-std::vector<point> map::route(int Fx, int Fy, int Tx, int Ty)
+// Bash defaults to true.
+std::vector<point> map::route(int Fx, int Fy, int Tx, int Ty, bool bash)
 {
 /* TODO: If the origin or destination is out of bound, figure out the closest
  * in-bounds point and go to that, then to the real origin/destination.
@@ -1164,7 +1189,7 @@ std::vector<point> map::route(int Fx, int Fy, int Tx, int Ty)
 
  do {
   //debugmsg("Open.size() = %d", open.size());
-  int best;
+  int best = 9999;
   int index = -1;
   for (int i = 0; i < open.size(); i++) {
    if (i == 0 || score[open[i].x][open[i].y] < best) {
@@ -1180,7 +1205,7 @@ std::vector<point> map::route(int Fx, int Fy, int Tx, int Ty)
      done = true;
      parent[x][y] = open[index];
     } else if (inbounds(x, y) &&
-               (move_cost(x, y) > 0 || has_flag(bashable, x, y))) {
+               (move_cost(x, y) > 0 || (bash && has_flag(bashable, x, y)))) {
      if (list[x][y] == ASL_NONE) {	// Not listed, so make it open
       list[x][y] = ASL_OPEN;
       open.push_back(point(x, y));
@@ -1188,14 +1213,14 @@ std::vector<point> map::route(int Fx, int Fy, int Tx, int Ty)
       gscore[x][y] = gscore[open[index].x][open[index].y] + move_cost(x, y);
       if (ter(x, y) == t_door_c)
        gscore[x][y] += 4;	// A turn to open it and a turn to move there
-      else if (move_cost(x, y) == 0 && has_flag(bashable, x, y))
+      else if (move_cost(x, y) == 0 && (bash && has_flag(bashable, x, y)))
        gscore[x][y] += 18;	// Worst case scenario with damage penalty
       score[x][y] = gscore[x][y] + 2 * rl_dist(x, y, Tx, Ty);
      } else if (list[x][y] == ASL_OPEN) { // It's open, but make it our child
       int newg = gscore[open[index].x][open[index].y] + move_cost(x, y);
       if (ter(x, y) == t_door_c)
        newg += 4;	// A turn to open it and a turn to move there
-      else if (move_cost(x, y) == 0 && has_flag(bashable, x, y))
+      else if (move_cost(x, y) == 0 && (bash && has_flag(bashable, x, y)))
        newg += 18;	// Worst case scenario with damage penalty
       if (newg < gscore[x][y]) {
        gscore[x][y] = newg;
@@ -1342,7 +1367,7 @@ void map::saven(overmap *om, unsigned int turn, int worldx, int worldy,
  for (int i = 0; i < grid[n].spawns.size(); i++) {
   tmpsp = grid[n].spawns[i];
   fout << "S " << int(tmpsp.type) << " " << tmpsp.count << " " << tmpsp.posx <<
-          " " << tmpsp.posy << std::endl;
+          " " << tmpsp.posy << " " << (tmpsp.friendly ? "1" : "0") << std::endl;
  }
 // Output the computer
  if (grid[n].comp.name != "")
@@ -1425,8 +1450,9 @@ bool map::loadn(game *g, int worldx, int worldy, int gridx, int gridy)
     mapin >> itx >> ity >> t >> d >> a;
     grid[gridn].fld[itx][ity] = field(field_id(t), d, a);
    } else if (!mapin.eof() && ch == 'S') {
-    mapin >> t >> a >> itx >> ity;
-    spawn_point tmp(mon_id(t), a, itx, ity);
+    char tmpfriend;
+    mapin >> t >> a >> itx >> ity >> tmpfriend;
+    spawn_point tmp(mon_id(t), a, itx, ity, (tmpfriend == '1'));
     grid[gridn].spawns.push_back(tmp);
    } else if (!mapin.eof() && ch == 'c') {
     getline(mapin, databuff);
@@ -1462,7 +1488,6 @@ bool map::loadn(game *g, int worldx, int worldy, int gridx, int gridy)
 
 void map::spawn_monsters(game *g)
 {
- int t;
  for (int gx = 0; gx < 3; gx++) {
   for (int gy = 0; gy < 3; gy++) {
    int n = gx + gy * 3;
@@ -1471,24 +1496,27 @@ void map::spawn_monsters(game *g)
      int tries = 0;
      int mx = grid[n].spawns[i].posx, my = grid[n].spawns[i].posy;
      monster tmp(g->mtypes[grid[n].spawns[i].type]);
-     tmp.spawnposx = mx;
-     tmp.spawnposy = my;
      tmp.spawnmapx = g->levx;
      tmp.spawnmapy = g->levy;
-// TODO: this is a hacky hacky hack
-     if (tmp.type->id == mon_dog_thing)
+     if (grid[n].spawns[i].friendly)
       tmp.friendly = -1;
      int fx = mx + gx * SEEX, fy = my + gy * SEEY;
 
      while ((!g->is_empty(fx, fy) || !tmp.can_move_to(g->m, fx, fy)) && 
             tries < 10) {
-      mx = grid[n].spawns[i].posx + rng(-3, 3);
-      my = grid[n].spawns[i].posy + rng(-3, 3);
+      mx = (grid[n].spawns[i].posx + rng(-3, 3)) % SEEX;
+      my = (grid[n].spawns[i].posy + rng(-3, 3)) % SEEY;
+      if (mx < 0)
+       mx += SEEX;
+      if (my < 0)
+       my += SEEY;
       fx = mx + gx * SEEX;
       fy = my + gy * SEEY;
       tries++;
      }
      if (tries != 10) {
+      tmp.spawnposx = fx;
+      tmp.spawnposy = fy;
       tmp.spawn(fx, fy);
       g->z.push_back(tmp);
      }
@@ -1508,10 +1536,18 @@ bool inbounds(int x, int y)
 
 void cast_to_nonant(int &x, int &y, int &n)
 {
+ if (x < 0 || x >= SEEX * 3 || y < 0 || y >= SEEY * 3) {
+  n = 0;
+  x = -1;
+  y = -1;
+  return;
+ }
  n = int(x / SEEX) + int(y / SEEY) * 3;
 
- x %= SEEX;
- y %= SEEY;
+ while (x >= SEEX)
+  x -= SEEX;
+ while (y >= SEEY)
+  y -= SEEY;
 
  if (n < 0)
   n = 0;
