@@ -30,20 +30,21 @@ void game::init_mapitems()
 
  setvector(
    mapitems[mi_livingroom],
-	itm_rootbeer, itm_pizza, itm_cola, itm_cig, itm_weed, itm_coke,
-	itm_meth, itm_sneakers, itm_boots, itm_boots_winter, itm_flip_flops,
-	itm_dress_shoes, itm_heels, itm_coat_rain, itm_poncho, itm_gloves_light,
-	itm_mittens, itm_gloves_light, itm_mittens, itm_gloves_wool,
-	itm_gloves_winter, itm_gloves_leather, itm_gloves_fingerless,
-	itm_bandana, itm_scarf, itm_hat_cotton, itm_hat_knit, itm_hat_fur,
-	itm_helmet_bike, itm_helmet_motor, itm_mag_tv, itm_mag_news,
-	itm_lighter, itm_extinguisher, itm_mp3, NULL);
+	itm_rootbeer, itm_pizza, itm_cola, itm_cig, itm_cigar, itm_weed,
+	itm_coke, itm_meth, itm_sneakers, itm_boots, itm_boots_winter,
+	itm_flip_flops, itm_dress_shoes, itm_heels, itm_coat_rain, itm_poncho,
+	itm_gloves_light, itm_mittens, itm_gloves_light, itm_mittens,
+	itm_gloves_wool, itm_gloves_winter, itm_gloves_leather,
+	itm_gloves_fingerless, itm_bandana, itm_scarf, itm_hat_cotton,
+	itm_hat_knit, itm_hat_fur, itm_helmet_bike, itm_helmet_motor,
+	itm_mag_tv, itm_mag_news, itm_lighter, itm_extinguisher, itm_mp3, NULL);
 
  setvector(
    mapitems[mi_kitchen],
 	itm_pot, itm_pan, itm_knife_butter, itm_knife_steak, itm_knife_butcher,
 	itm_cookbook, itm_rag, itm_hotplate, itm_flashlight, itm_extinguisher,
 	itm_whiskey, itm_bleach, itm_ammonia, itm_flour, itm_sugar, itm_salt,
+	itm_tea_raw, itm_coffee_raw,
 	NULL);
 
  setvector(
@@ -60,12 +61,12 @@ void game::init_mapitems()
 	itm_hacksaw, itm_xacto, itm_gloves_leather, itm_mask_dust,
 	itm_glasses_safety, itm_battery, itm_nail, itm_nailgun,
 	itm_manual_mechanics, itm_hammer, itm_flashlight, itm_soldering_iron,
-	itm_bubblewrap, NULL);
+	itm_bubblewrap, itm_binoculars, NULL);
 
  setvector(
    mapitems[mi_bedroom],
-	itm_inhaler, itm_cig, itm_weed, itm_coke, itm_meth, itm_heroin,
-	itm_sneakers, itm_mocassins, itm_bandana, itm_glasses_eye,
+	itm_inhaler, itm_cig, itm_cigar, itm_weed, itm_coke, itm_meth,
+	itm_heroin, itm_sneakers, itm_mocassins, itm_bandana, itm_glasses_eye,
 	itm_glasses_reading, itm_hat_ball, itm_backpack, itm_purse, itm_mbag,
 	itm_fanny, itm_battery, itm_bb, itm_bbgun, itm_mag_porn, itm_mag_tv,
 	itm_mag_news, itm_novel_romance, itm_novel_drama, itm_manual_mechanics,
@@ -79,7 +80,8 @@ void game::init_mapitems()
 	itm_glock_19, itm_usp_9mm, itm_sw_619, itm_taurus_38, itm_sig_40,
 	itm_sw_610, itm_ruger_redhawk, itm_deagle_44, itm_usp_45, itm_m1911,
 	itm_fn57, itm_mac_10, itm_shotgun_sawn, itm_silencer, itm_grip,
-	itm_clip, itm_grenade, itm_EMPbomb, itm_gasbomb, itm_tazer, NULL);
+	itm_clip, itm_grenade, itm_EMPbomb, itm_gasbomb, itm_tazer,
+	itm_longbow, itm_compbow, itm_arrow_wood, itm_arrow_cf, NULL);
 
  setvector(
    mapitems[mi_dresser],
@@ -88,11 +90,13 @@ void game::init_mapitems()
 	itm_sweatshirt, itm_sweater, itm_hoodie, itm_jacket_light,
 	itm_jacket_jean, itm_blazer, itm_jacket_leather, itm_poncho,
 	itm_trenchcoat, itm_peacoat, itm_vest, itm_mag_porn, itm_lighter,
-	itm_sewing_kit, itm_flashlight, NULL);
+	itm_sewing_kit, itm_flashlight, itm_suit, itm_tophat,
+	itm_glasses_monocle, NULL);
 
  setvector(
    mapitems[mi_snacks],
-	itm_chips, itm_pretzels, itm_chocolate, itm_jerky, itm_candy, NULL);
+	itm_chips, itm_pretzels, itm_chocolate, itm_jerky, itm_candy, itm_tea_raw,
+	itm_coffee_raw, NULL);
 
  setvector(
    mapitems[mi_fridgesnacks],
@@ -102,9 +106,9 @@ void game::init_mapitems()
 
  setvector(
    mapitems[mi_behindcounter],
-	itm_aspirin, itm_caffeine, itm_cig, itm_battery, itm_shotgun_sawn,
-	itm_mag_porn, itm_lighter, itm_flashlight, itm_extinguisher,
-	itm_tazer, itm_mp3, NULL);
+	itm_aspirin, itm_caffeine, itm_cig, itm_cigar, itm_battery,
+	itm_shotgun_sawn, itm_mag_porn, itm_lighter, itm_flashlight,
+	itm_extinguisher, itm_tazer, itm_mp3, NULL);
 
  setvector(
    mapitems[mi_magazines],
@@ -170,7 +174,8 @@ void game::init_mapitems()
    mapitems[mi_consumer_electronics],
         itm_amplifier, itm_antenna, itm_battery, itm_soldering_iron,
         itm_screwdriver, itm_processor, itm_RAM, itm_mp3, itm_flashlight,
-        itm_radio, itm_hotplate, itm_receiver, itm_transponder, itm_tazer, itm_two_way_radio, NULL);
+        itm_radio, itm_hotplate, itm_receiver, itm_transponder, itm_tazer,
+	itm_two_way_radio, NULL);
 
  setvector(
    mapitems[mi_sports],
@@ -181,12 +186,13 @@ void game::init_mapitems()
 
  setvector(
    mapitems[mi_camping],
-	itm_rope_30, itm_hatchet, itm_pot, itm_pan, itm_hotplate,
-	itm_knife_combat, itm_machete, itm_vest, itm_backpack, itm_bb,
-	itm_bolt_steel, itm_bbgun, itm_crossbow, itm_manual_knives,
+	itm_rope_30, itm_hatchet, itm_pot, itm_pan, itm_binoculars,
+	itm_hotplate, itm_knife_combat, itm_machete, itm_vest, itm_backpack,
+	itm_bb, itm_bolt_steel, itm_bbgun, itm_crossbow, itm_manual_knives,
 	itm_manual_first_aid, itm_manual_traps, itm_lighter, itm_sewing_kit,
 	itm_hammer, itm_flashlight, itm_water_purifier, itm_radio, itm_beartrap,
-	itm_UPS_off, itm_string_36, NULL);
+        itm_UPS_off, itm_string_36, itm_longbow, itm_compbow, itm_arrow_wood,
+        itm_arrow_cf, NULL);
 
  setvector(
    mapitems[mi_allsporting],
@@ -194,11 +200,12 @@ void game::init_mapitems()
 	itm_gloves_fingerless, itm_glasses_safety, itm_goggles_swim,
 	itm_goggles_ski, itm_hat_ball, itm_helmet_bike, itm_helmet_ball,
 	itm_manual_brawl, itm_rope_30, itm_hatchet, itm_pot, itm_pan,
-	itm_hotplate, itm_knife_combat, itm_machete, itm_vest, itm_backpack,
-	itm_bb, itm_bolt_steel, itm_bbgun, itm_crossbow, itm_manual_knives,
-	itm_manual_first_aid, itm_manual_traps, itm_lighter, itm_sewing_kit,
-	itm_hammer, itm_flashlight, itm_water_purifier, itm_radio, itm_beartrap,
-	itm_extinguisher, itm_string_36, NULL);
+	itm_binoculars, itm_hotplate, itm_knife_combat, itm_machete, itm_vest,
+	itm_backpack, itm_bb, itm_bolt_steel, itm_bbgun, itm_crossbow,
+	itm_manual_knives, itm_manual_first_aid, itm_manual_traps, itm_lighter,
+	itm_sewing_kit, itm_hammer, itm_flashlight, itm_water_purifier,
+	itm_radio, itm_beartrap, itm_extinguisher, itm_string_36, itm_longbow,
+	itm_compbow, itm_arrow_wood, itm_arrow_cf, NULL);
 
  setvector(
    mapitems[mi_alcohol],
@@ -299,13 +306,14 @@ void game::init_mapitems()
 
  setvector(
    mapitems[mi_allclothes],
-	itm_jeans, itm_pants, itm_pants_leather, itm_pants_cargo, itm_skirt,
-	itm_tshirt, itm_polo_shirt, itm_dress_shirt, itm_tank_top,
-	itm_sweatshirt, itm_sweater, itm_hoodie, itm_jacket_light,
-	itm_jacket_jean, itm_blazer, itm_jacket_leather, itm_coat_winter,
-	itm_peacoat, itm_gloves_light, itm_mittens, itm_gloves_wool,
-	itm_gloves_winter, itm_gloves_leather, itm_scarf, itm_hat_cotton,
-	itm_hat_knit, itm_hat_fur, itm_UPS_off, NULL);
+	itm_jeans, itm_pants, itm_suit, itm_tophat, itm_glasses_monocle,
+	itm_pants_leather, itm_pants_cargo, itm_skirt, itm_tshirt,
+	itm_polo_shirt, itm_dress_shirt, itm_tank_top, itm_sweatshirt,
+	itm_sweater, itm_hoodie, itm_jacket_light, itm_jacket_jean,
+	itm_blazer, itm_jacket_leather, itm_coat_winter, itm_peacoat,
+	itm_gloves_light, itm_mittens, itm_gloves_wool, itm_gloves_winter,
+	itm_gloves_leather, itm_scarf, itm_hat_cotton, itm_hat_knit,
+	itm_hat_fur, itm_UPS_off, NULL);
 
  setvector(
    mapitems[mi_novels],
@@ -339,10 +347,10 @@ void game::init_mapitems()
 
  setvector(
    mapitems[mi_office],
-	itm_cola, itm_aspirin, itm_glasses_eye, itm_glasses_reading, itm_purse,
-	itm_mbag, itm_battery, itm_mag_news, itm_manual_business,
+	itm_cola, itm_aspirin, itm_cigar, itm_glasses_eye, itm_glasses_reading,
+	itm_purse, itm_mbag, itm_battery, itm_mag_news, itm_manual_business,
 	itm_textbook_business, itm_lighter, itm_extinguisher, itm_flashlight,
-	itm_radio, itm_bubblewrap, NULL);
+	itm_radio, itm_bubblewrap, itm_coffee_raw, NULL);
 
  setvector(
    mapitems[mi_vault],
@@ -408,11 +416,50 @@ void game::init_mapitems()
    mapitems[mi_bionics_common],
 	itm_bionics_battery, itm_bionics_power, itm_bionics_tools, NULL);
 
+ setvector(
+   mapitems[mi_bots],
+	itm_bot_manhack, itm_bot_turret, NULL);
+
+ setvector(
+   mapitems[mi_launchers],
+	itm_40mm_concussive, itm_40mm_frag, itm_40mm_incendiary,
+	itm_40mm_teargas, itm_40mm_smoke, itm_40mm_flashbang, itm_m79,
+	itm_m320, itm_mgl, itm_m203, NULL);
+
+ setvector(
+   mapitems[mi_mil_rifles],
+	itm_556, itm_556_incendiary, itm_762_51, itm_762_51_incendiary,
+	itm_laser_pack, itm_12mm, itm_plasma, itm_m4a1, itm_scar_l, itm_scar_h,
+	itm_m249, itm_ftk93, itm_hk_g80, itm_plasma_rifle, itm_silencer,
+	itm_clip, itm_m203, itm_UPS_off, NULL);
+
+ setvector(
+   mapitems[mi_grenades],
+	itm_grenade, itm_flashbang, itm_EMPbomb, itm_gasbomb, itm_smokebomb,
+	itm_dynamite, itm_mininuke, itm_c4, NULL);
+
+ setvector(
+   mapitems[mi_mil_armor],
+	itm_pants_army, itm_kevlar, itm_vest, itm_mask_gas, itm_goggles_nv,
+	itm_helmet_army, itm_backpack, itm_UPS_off, NULL);
+
+ setvector(
+   mapitems[mi_mil_food],
+	itm_chocolate, itm_can_beans, itm_mre, itm_1st_aid, itm_codeine,
+	itm_water, itm_purifier, NULL);
+
+ setvector(
+   mapitems[mi_bionics_mil],
+	itm_bionics_battery, itm_bionics_power, itm_bionics_sensory,
+	itm_bionics_combat_aug, itm_bionics_desert, itm_bionics_armor,
+	itm_bionics_espionage, itm_bionics_defense, itm_bionics_medical,
+	itm_bionics_super, itm_bionics_ranged, NULL);
+
  setvector(
    mapitems[mi_weapons],
 	itm_chain, itm_hammer, itm_wrench, itm_hammer_sledge, itm_hatchet,
 	itm_ax, itm_knife_combat, itm_pipe, itm_bat, itm_machete, itm_katana,
-	itm_baton, itm_tazer, NULL);
+	itm_baton, itm_tazer, itm_rapier, NULL);
 
  setvector(
    mapitems[mi_survival_armor],
@@ -425,10 +472,10 @@ void game::init_mapitems()
  setvector(
    mapitems[mi_survival_tools],
 	itm_bandages, itm_1st_aid, itm_caffeine, itm_iodine, itm_electrohack,
-	itm_string_36, itm_rope_30, itm_chain, itm_bottle_plastic, itm_lighter,
-	itm_sewing_kit, itm_extinguisher, itm_flashlight, itm_crowbar,
-	itm_chainsaw_off, itm_beartrap, itm_grenade, itm_EMPbomb, itm_hotplate,
-	itm_UPS_off, NULL);
+	itm_string_36, itm_rope_30, itm_chain, itm_binoculars,
+	itm_bottle_plastic, itm_lighter, itm_sewing_kit, itm_extinguisher,
+	itm_flashlight, itm_crowbar, itm_chainsaw_off, itm_beartrap,
+	itm_grenade, itm_EMPbomb, itm_hotplate, itm_UPS_off, NULL);
 
  setvector(
    mapitems[mi_sewage_plant],
@@ -481,16 +528,17 @@ void game::init_mapitems()
    mapitems[mi_spider],
 	itm_corpse, itm_mutagen, itm_purifier, itm_meat, itm_meat_tainted,
 	itm_arm, itm_leg, itm_1st_aid, itm_codeine, itm_oxycodone, itm_weed,
-	itm_wrapper, itm_fur, itm_leather, itm_card_id, itm_rope_30, itm_stick,
-	itm_hatchet, itm_ax, itm_bee_sting, itm_chitin_piece, itm_vest,
-	itm_mask_gas, itm_goggles_nv, itm_hat_boonie, itm_helmet_riot,
-	itm_bolt_steel, itm_shot_00, itm_762_m87, itm_556, itm_556_incendiary,
-	itm_3006_incendiary, itm_762_51, itm_762_51_incendiary, itm_saiga_12,
-	itm_hk_mp5, itm_TDI, itm_savage_111f, itm_sks, itm_ak47, itm_m4a1,
-	itm_steyr_aug, itm_v29, itm_flamethrower, itm_flashlight, itm_radio,
-	itm_geiger_off, itm_teleporter, itm_canister_goo, itm_dynamite,
-	itm_mininuke, itm_bot_manhack, itm_UPS_off, itm_bionics_battery,
-	itm_bionics_tools, NULL);
+	itm_coke, itm_wrapper, itm_fur, itm_leather, itm_id_science,
+	itm_id_military, itm_rope_30, itm_stick, itm_hatchet, itm_ax,
+	itm_bee_sting, itm_chitin_piece, itm_vest, itm_mask_gas, itm_goggles_nv,
+	itm_hat_boonie, itm_helmet_riot, itm_bolt_steel, itm_shot_00,
+	itm_762_m87, itm_556, itm_556_incendiary, itm_3006_incendiary,
+	itm_762_51, itm_762_51_incendiary, itm_saiga_12, itm_hk_mp5, itm_TDI,
+	itm_savage_111f, itm_sks, itm_ak47, itm_m4a1, itm_steyr_aug, itm_v29,
+	itm_flamethrower, itm_flashlight, itm_radio, itm_geiger_off,
+	itm_teleporter, itm_canister_goo, itm_dynamite, itm_mininuke,
+	itm_bot_manhack, itm_UPS_off, itm_bionics_battery, itm_bionics_tools,
+	itm_arrow_cf, NULL);
 
  setvector(
    mapitems[mi_ant_food],
@@ -503,6 +551,10 @@ void game::init_mapitems()
    mapitems[mi_ant_egg],
 	itm_ant_egg, NULL);	//TODO: More items here?
 
+ setvector(
+   mapitems[mi_biollante],
+	itm_biollante_bud, NULL);
+
  setvector(
    mapitems[mi_bugs],
 	itm_chitin_piece, NULL);
@@ -531,36 +583,40 @@ void game::init_mapitems()
 // TODO: Replace kevlar with the ceramic plate armor
  setvector(
    mapitems[mi_military],
-	itm_water, itm_can_beans, itm_bandages, itm_1st_aid, itm_iodine,
-	itm_codeine, itm_cig, itm_knife_combat, itm_boots_steel, itm_pants_army,
-	itm_kevlar, itm_vest, itm_gloves_fingerless, itm_mask_gas,
-	itm_glasses_safety, itm_goggles_nv, itm_hat_boonie, itm_helmet_army,
-	itm_backpack, itm_holster, itm_bootstrap, itm_9mm, itm_45_acp,
-	itm_556, itm_556_incendiary, itm_762_51, itm_762_51_incendiary,
-	itm_laser_pack, itm_usp_9mm, itm_usp_45, itm_m4a1, itm_scar_l,
-	itm_scar_h, itm_m249, itm_ftk93, itm_silencer, itm_clip, itm_lighter,
-	itm_flashlight, itm_two_way_radio, itm_landmine, itm_grenade,
-	itm_EMPbomb, itm_gasbomb, itm_smokebomb, itm_UPS_off, itm_tazer, NULL);
+	itm_water, itm_mre, itm_bandages, itm_1st_aid, itm_iodine, itm_codeine,
+	itm_cig, itm_knife_combat, itm_boots_steel, itm_pants_army, itm_kevlar,
+	itm_vest, itm_gloves_fingerless, itm_mask_gas, itm_glasses_safety,
+	itm_goggles_nv, itm_hat_boonie, itm_helmet_army, itm_backpack,
+	itm_holster, itm_bootstrap, itm_9mm, itm_45_acp, itm_556,
+	itm_556_incendiary, itm_762_51, itm_762_51_incendiary, itm_laser_pack,
+	itm_40mm_concussive, itm_40mm_frag, itm_40mm_incendiary,
+	itm_40mm_teargas, itm_40mm_smoke, itm_40mm_flashbang, itm_usp_9mm,
+	itm_usp_45, itm_m4a1, itm_scar_l, itm_scar_h, itm_m249, itm_ftk93,
+	itm_m320, itm_mgl, itm_silencer, itm_clip, itm_lighter, itm_flashlight,
+	itm_two_way_radio, itm_landmine, itm_grenade, itm_flashbang,
+	itm_EMPbomb, itm_gasbomb, itm_smokebomb, itm_UPS_off, itm_tazer,
+	itm_c4, itm_hk_g80, itm_12mm, itm_binoculars, NULL);
 
  setvector(
    mapitems[mi_science],
 	itm_water, itm_bleach, itm_ammonia, itm_mutagen, itm_purifier,
-	itm_iodine, itm_inhaler, itm_adderall, itm_card_id, itm_electrohack,
+	itm_iodine, itm_inhaler, itm_adderall, itm_id_science, itm_electrohack,
 	itm_RAM, itm_screwdriver, itm_canister_empty, itm_coat_lab,
 	itm_gloves_medical, itm_mask_dust, itm_mask_filter, itm_glasses_eye,
 	itm_glasses_safety, itm_textbook_computers, itm_textbook_electronics,
 	itm_textbook_chemistry, itm_SICP, itm_textbook_robots,
 	itm_soldering_iron, itm_geiger_off, itm_teleporter, itm_canister_goo,
 	itm_EMPbomb, itm_pheromone, itm_portal, itm_bot_manhack, itm_UPS_off,
-	itm_tazer, itm_bionics_hazmat, NULL);
+	itm_tazer, itm_bionics_hazmat, itm_plasma, NULL);
 
  setvector(
    mapitems[mi_rare],
-	itm_mutagen, itm_purifier, itm_royal_jelly, itm_fetus, itm_card_id,
-	itm_electrohack, itm_processor, itm_armor_chitin, itm_plut_cell,
-	itm_laser_pack, itm_m249, itm_v29, itm_ftk93, itm_conversion_battle,
-	itm_conversion_sniper, itm_canister_goo, itm_mininuke, itm_portal,
-	NULL);
+	itm_mutagen, itm_purifier, itm_royal_jelly, itm_fetus, itm_id_science,
+	itm_id_military, itm_electrohack, itm_processor, itm_armor_chitin,
+	itm_plut_cell, itm_laser_pack, itm_m249, itm_v29, itm_ftk93,
+	itm_conversion_battle, itm_conversion_sniper, itm_canister_goo,
+	itm_mininuke, itm_portal, itm_c4, itm_12mm, itm_hk_g80,
+	itm_plasma, itm_plasma_rifle, NULL);
 
  setvector(
    mapitems[mi_stash_food],
@@ -571,7 +627,7 @@ void game::init_mapitems()
    mapitems[mi_stash_ammo],
 	itm_bolt_steel, itm_shot_00, itm_shot_slug, itm_22_lr, itm_9mm,
 	itm_38_super, itm_10mm, itm_44magnum, itm_45_acp, itm_57mm, itm_46mm,
-	itm_762_m87, itm_556, itm_3006, itm_762_51, NULL);
+	itm_762_m87, itm_556, itm_3006, itm_762_51, itm_arrow_cf, NULL);
 
  setvector(
    mapitems[mi_stash_wood],
@@ -582,6 +638,18 @@ void game::init_mapitems()
 	itm_pills_sleep, itm_oxycodone, itm_xanax, itm_adderall, itm_weed,
 	itm_coke, itm_meth, itm_heroin, NULL);
 
+ setvector(
+   mapitems[mi_drugdealer],
+	itm_energy_drink, itm_whiskey, itm_jerky, itm_bandages, itm_caffeine,
+	itm_oxycodone, itm_adderall, itm_cig, itm_weed, itm_coke, itm_meth,
+	itm_heroin, itm_syringe, itm_electrohack, itm_hatchet, itm_nailboard,
+	itm_knife_combat, itm_bat, itm_machete, itm_katana, itm_pants_cargo,
+	itm_hoodie, itm_gloves_fingerless, itm_backpack, itm_holster,
+	itm_shot_00, itm_9mm, itm_45_acp, itm_glock_19, itm_shotgun_sawn,
+	itm_uzi, itm_tec9, itm_mac_10, itm_silencer, itm_clip2, itm_autofire,
+	itm_mag_porn, itm_lighter, itm_crowbar, itm_pipebomb, itm_grenade,
+	itm_mininuke, NULL);
+
  setvector(
    mapitems[mi_wreckage],
 	itm_chain, itm_steel_chunk, itm_rock, NULL);
@@ -589,11 +657,11 @@ void game::init_mapitems()
 // This one kind of an inverted list; what a traveling salesman will NOT carry
  setvector(
    mapitems[mi_trader_avoid],
-	itm_null, itm_water_dirty, itm_meat, itm_veggy, itm_meat_tainted,
-	itm_veggy_tainted, itm_meat_cooked, itm_veggy_cooked,
-	itm_mushroom_poison, itm_spaghetti_cooked, itm_macaroni_cooked,
-	itm_fetus, itm_arm, itm_leg, itm_wrapper, itm_manhole_cover, itm_rock,
-	itm_stick, itm_bag_plastic, itm_flashlight_on, itm_radio_on,
-	itm_chainsaw_on, itm_grenade_act, itm_EMPbomb_act, itm_gasbomb_act,
-	itm_molotov_lit, itm_dynamite_act, itm_mininuke_act, itm_mp3_on, NULL);
+	itm_null, itm_meat, itm_veggy, itm_meat_tainted, itm_veggy_tainted,
+	itm_meat_cooked, itm_veggy_cooked, itm_mushroom_poison,
+	itm_spaghetti_cooked, itm_macaroni_cooked, itm_fetus, itm_arm, itm_leg,
+	itm_wrapper, itm_manhole_cover, itm_rock, itm_stick, itm_bag_plastic,
+	itm_flashlight_on, itm_radio_on, itm_chainsaw_on, itm_grenade_act,
+	itm_EMPbomb_act, itm_gasbomb_act, itm_molotov_lit, itm_dynamite_act,
+	itm_mininuke_act, itm_mp3_on,itm_c4, NULL);
 }
