@@ -51,7 +51,7 @@ int player::hit_roll()
  if (unarmed_attack()) {
   best_bonus = sklevel[sk_unarmed];
   if (sklevel[sk_unarmed] > 4)
-   best_bonus += sklevel[sk_unarmed] - 2; // Extra bonus for high levels
+   best_bonus += sklevel[sk_unarmed] - 4; // Extra bonus for high levels
  }
 
 // Using a bashing weapon?
@@ -117,24 +117,23 @@ int player::hit_mon(game *g, monster *z)
   stumble(g);
   return 0;
  }
- if (z->has_flag(MF_SHOCK) && !wearing_something_on(bp_hands) &&
-     (unarmed || weapon.conductive())) {
-  if (is_u)
-   g->add_msg("The %s's electric body shocks you!", z->name().c_str());
-  hurtall(rng(1, 3));
- }
 // For very high hit rolls, we crit!
- bool critical_hit = (hit_roll() >= 50 + 10 * z->dodge_roll());
+ bool critical_hit = scored_crit(z->dodge_roll());
  int dam = base_damage(true);
  int cutting_penalty = 0; // Moves lost from getting a cutting weapon stuck
 
 // Drunken Master damage bonuses
  if (has_trait(PF_DRUNKEN) && has_disease(DI_DRUNK)) {
 // Remember, a single drink gives 600 levels of DI_DRUNK
-  if (unarmed)
-   dam += disease_level(DI_DRUNK) / 250;
-  else
-   dam += disease_level(DI_DRUNK) / 400;
+  int mindrunk, maxdrunk;
+  if (unarmed) {
+   mindrunk = disease_level(DI_DRUNK) / 600;
+   maxdrunk = disease_level(DI_DRUNK) / 250;
+  } else {
+   mindrunk = disease_level(DI_DRUNK) / 900;
+   maxdrunk = disease_level(DI_DRUNK) / 400;
+  }
+  dam += rng(mindrunk, maxdrunk);
  }
 
  if (unarmed) { // Unarmed bonuses
@@ -145,10 +144,10 @@ int player::hit_mon(game *g, monster *z)
     z_armor = 0;
    dam += 10 - z_armor;
   }
- } else if (rng(1, 45 - dex_cur) < 2 * sklevel[sk_unarmed] &&
-            rng(1, 65 - dex_cur) < 2 * sklevel[sk_unarmed]   ) {
-// If we're not unarmed, there's still a possibility of getting in a bonus
-// unarmed attack.
+ }
+ if (rng(1, 45 - dex_cur) < 2 * sklevel[sk_unarmed] &&
+     rng(1, 65 - dex_cur) < 2 * sklevel[sk_unarmed]   ) {
+// Bonus unarmed attack!
   if (is_u || can_see) {
    switch (rng(1, 4)) {
     case 1: g->add_msg("%s kick%s the %s!", You.c_str(), (is_u ? "" : "s"),
@@ -161,29 +160,34 @@ int player::hit_mon(game *g, monster *z)
                        z->name().c_str()); break;
    }
   }
-  dam += rng(1, sklevel[sk_unarmed]);
+  if (sklevel[sk_unarmed] >= 4)
+   dam += rng(1, sklevel[sk_unarmed] / 2);
+  else
+   dam++;
   practice(sk_unarmed, 2);
  }
 // Melee skill bonus
  dam += rng(0, sklevel[sk_melee]);
 // Bashing damage bonus
- int bash_dam = weapon.type->melee_dam,
+ int bash_dam = weapon.damage_bash(),
      bash_cap = 5 + str_cur + sklevel[sk_bashing];
  if (bash_dam > bash_cap)// Cap for weak characters
   bash_dam = (bash_cap * 3 + bash_dam) / 4;
  if (bashing)
-  bash_dam += rng(0, sklevel[sk_bashing]) * sqrt(str_cur);
+  bash_dam += rng(0, sklevel[sk_bashing] + sqrt(str_cur));
+ if (z->has_flag(MF_PLASTIC))
+  bash_dam /= rng(2, 4);
  int bash_min = bash_dam / 4;
- if (bash_min < sklevel[sk_bashing] * 4)
-  bash_min = sklevel[sk_bashing] * 4;
+ if (bash_min < sklevel[sk_bashing] )
+  bash_min = sklevel[sk_bashing];
  dam += rng(bash_min, bash_dam);
 // Take some moves away from the target; at this point it's skill & bash damage
  z->moves -= rng(0, dam * 2);
 // Spears treat cutting damage specially.
  if (weapon.has_flag(IF_SPEAR) &&
-     weapon.type->melee_cut > z->type->armor - int(sklevel[sk_stabbing])) {
+     weapon.damage_cut() > z->type->armor - int(sklevel[sk_stabbing])) {
   int z_armor = z->type->armor - int(sklevel[sk_stabbing]);
-  dam += int(weapon.type->melee_cut / 5);
+  dam += int(weapon.damage_cut() / 5);
   int minstab = sklevel[sk_stabbing] *  5 + weapon.volume() * 2,
       maxstab = sklevel[sk_stabbing] * 15 + weapon.volume() * 4;
   int monster_penalty = rng(minstab, maxstab);
@@ -192,17 +196,17 @@ int player::hit_mon(game *g, monster *z)
   else if (monster_penalty >= 50)
    g->add_msg("The %s is skewered and flinches!", z->name().c_str());
   z->moves -= monster_penalty;
-  cutting_penalty = weapon.type->melee_cut * 4 + z_armor * 8 -
+  cutting_penalty = weapon.damage_cut() * 4 + z_armor * 8 -
                     dice(sklevel[sk_stabbing], 10);
   practice(sk_stabbing, 2);
 // Cutting damage bonus
- } else if (weapon.type->melee_cut >
+ } else if (weapon.damage_cut() >
             z->type->armor - int(sklevel[sk_cutting] / 2)) {
   int z_armor = z->type->armor - int(sklevel[sk_cutting] / 2);
   if (z_armor < 0)
    z_armor = 0;
-  dam += weapon.type->melee_cut - z_armor;
-  cutting_penalty = weapon.type->melee_cut * 3 + z_armor * 8 -
+  dam += weapon.damage_cut() - z_armor;
+  cutting_penalty = weapon.damage_cut() * 3 + z_armor * 8 -
                     dice(sklevel[sk_cutting], 10);
  }
  if (weapon.has_flag(IF_MESSY)) { // e.g. chainsaws
@@ -222,8 +226,8 @@ int player::hit_mon(game *g, monster *z)
 
 // Bonus attacks!
 
- bool shock_them = (!z->has_flag(MF_SHOCK) && has_bionic(bio_shock) &&
-                    power_level >= 2 && unarmed && one_in(3));
+ bool shock_them = (has_bionic(bio_shock) && power_level >= 2 && unarmed &&
+                    one_in(3));
  bool drain_them = (has_bionic(bio_heat_absorb) && power_level >= 1 &&
                     !is_armed() && z->has_flag(MF_WARM));
  bool  bite_them = (has_trait(PF_FANGS) && z->armor() < 18 &&
@@ -238,8 +242,8 @@ int player::hit_mon(game *g, monster *z)
  if (critical_hit) {
   bool headshot = (!z->has_flag(MF_NOHEAD) && !one_in(3));
 // Second chance for shock_them, drain_them, bite_them and peck_them
-  shock_them = (shock_them || (!z->has_flag(MF_SHOCK) && has_bionic(bio_shock)&&
-                               power_level >= 2 && unarmed && !one_in(3)));
+  shock_them = (shock_them || (has_bionic(bio_shock)&& power_level >= 2 &&
+                               unarmed && !one_in(3)));
   drain_them = (drain_them || (has_bionic(bio_heat_absorb) && !is_armed() &&
                                power_level >= 1 && z->has_flag(MF_WARM) &&
                                !one_in(3)));
@@ -249,15 +253,15 @@ int player::hit_mon(game *g, monster *z)
                                one_in(4)));
 
   if (weapon.has_flag(IF_SPEAR) || weapon.has_flag(IF_STAB)) {
-   dam += weapon.type->melee_cut;
-   dam += weapon.type->melee_cut * double(sklevel[sk_stabbing] / 10);
+   dam += weapon.damage_cut();
+   dam += weapon.damage_cut() * double(sklevel[sk_stabbing] / 10);
    practice(sk_stabbing, 5);
   }
 
   if (unarmed) {
-   dam += rng(2, 6) * sklevel[sk_unarmed];
+   dam += rng(1, 4) * sklevel[sk_unarmed];
    if (sklevel[sk_unarmed] > 5)
-    dam += 4 * (sklevel[sk_unarmed - 3]);
+    dam += 4 * (sklevel[sk_unarmed - 5]);
    z->moves -= dam;	// Stunning blow
    if (weapon.type->id == itm_bio_claws) {
     if (sklevel[sk_cutting] >= 3)
@@ -300,7 +304,7 @@ int player::hit_mon(game *g, monster *z)
     double cut_multiplier = double(sklevel[sk_cutting] / 12);
     if (cut_multiplier > 1.5)
      cut_multiplier = 1.5;
-    dam += cut_multiplier * weapon.type->melee_cut;
+    dam += cut_multiplier * weapon.damage_cut();
     headshot &= z->hp < dam;
     if (stabbing) {
      if (headshot && can_see)
@@ -507,12 +511,12 @@ bool player::hit_player(player &p, body_part &bp, int &hitdam, int &hitcut)
    hitdam *= rng(2, 3);
  }
 // Weapon adds (melee_dam / 4) to (melee_dam)
- hitdam += rng(weapon.type->melee_dam / 4, weapon.type->melee_dam);
+ hitdam += rng(weapon.damage_bash() / 4, weapon.damage_bash());
  if (bashing)
   hitdam += rng(0, sklevel[sk_bashing]) * sqrt(str_cur);
 
  hitdam += int(pow(1.5, sklevel[sk_melee]));
- hitcut = weapon.type->melee_cut;
+ hitcut = weapon.damage_cut();
  if (hitcut > 0)
   hitcut += int(sklevel[sk_cutting] / 3);
  if (hitdam < 0) hitdam = 0;
@@ -536,7 +540,68 @@ bool player::hit_player(player &p, body_part &bp, int &hitdam, int &hitcut)
  return true;
 }
 
+bool player::scored_crit(int target_dodge)
+{
+ bool to_hit_crit = false, dex_crit = false, skill_crit = false;
+ int num_crits = 0;
 
+ int chance = 25;
+ if (weapon.type->m_to_hit > 0) {
+  for (int i = 1; i <= weapon.type->m_to_hit; i++)
+   chance += (50 / (2 + i));
+ } else if (chance < 0) {
+  for (int i = 0; i > weapon.type->m_to_hit; i--)
+   chance /= 2;
+ }
+ if (rng(0, 99) < chance)
+  num_crits++;
+
+ chance = 25;
+ if (dex_cur > 8) {
+  for (int i = 9; i <= dex_cur; i++)
+   chance += (21 - i); // 12, 11, 10...
+ } else {
+  int decrease = 5;
+  for (int i = 7; i >= dex_cur; i--) {
+   chance -= decrease;
+   if (i % 2 == 0)
+    decrease--;
+  }
+ }
+ if (rng(0, 99) < chance)
+  num_crits++;
+
+ int best_skill = 0;
+ if (weapon.is_bashing_weapon() && sklevel[sk_bashing] > best_skill)
+  best_skill = sklevel[sk_bashing];
+ if (weapon.is_cutting_weapon() && sklevel[sk_cutting] > best_skill)
+  best_skill = sklevel[sk_cutting];
+ if ((weapon.has_flag(IF_SPEAR) || weapon.has_flag(IF_STAB)) &&
+     sklevel[sk_stabbing] > best_skill)
+  best_skill = sklevel[sk_stabbing];
+ if (unarmed_attack() && sklevel[sk_unarmed] > best_skill)
+  best_skill = sklevel[sk_unarmed];
+
+ best_skill += int(sklevel[sk_melee] / 2.5);
+
+ chance = 25;
+ if (best_skill > 3) {
+  for (int i = 3; i < best_skill; i++)
+   chance += (50 / (2 + i));
+ } else if (chance < 3) {
+  for (int i = 3; i > best_skill; i--)
+   chance /= 2;
+ }
+ if (rng(0, 99) < chance)
+  num_crits++;
+
+ if (num_crits == 3)
+  return true;
+ else if (num_crits == 2)
+  return (hit_roll() >= target_dodge * 1.5);
+
+ return false;
+}
 
 int player::dodge()
 {
@@ -544,7 +609,8 @@ int player::dodge()
 //  the dodge skill.
  if (has_disease(DI_SLEEP) || has_disease(DI_LYING_DOWN))
   return 0;
- practice(sk_dodge, 5);
+ if (activity.type != ACT_NULL)
+  return 0;
  int ret = 4 + (dex_cur / 2);
  ret += sklevel[sk_dodge];
  ret -= (encumb(bp_legs) / 2) + encumb(bp_torso);
