@@ -93,14 +93,14 @@ void monster::plan(game *g)
   }
   return;
  }
- if (is_fleeing(g->u) && has_flag(MF_SEES) && g->sees_u(posx, posy, tc) &&
+ if (is_fleeing(g->u) && can_see() && g->sees_u(posx, posy, tc) &&
      (!g->u.has_trait(PF_ANIMALEMPATH) || !has_flag(MF_ANIMAL))) {
   wandx = posx * 2 - g->u.posx;
   wandy = posy * 2 - g->u.posy;
   wandf = 40;
  }
 // If we can see, and we can see a character, start moving towards them
- if (!is_fleeing(g->u) && has_flag(MF_SEES)) {
+ if (!is_fleeing(g->u) && can_see()) {
   if (g->sees_u(posx, posy, tc)) {
    dist = rl_dist(posx, posy, g->u.posx, g->u.posy);
    closest = -2;
@@ -180,11 +180,8 @@ void monster::move(game *g)
 */
 
  moves -= 100;
- int rn=0, hmove=0;
  bool moved=false;
  point next;
- rn = rng(0, 50);
- hmove = rng(0, 5);
  int mondex = (plans.size() > 0 ? g->mon_at(plans[0].x, plans[0].y) : -1);
 
  if (plans.size() > 0 &&
@@ -245,6 +242,36 @@ void monster::move(game *g)
   stumble(g, moved);
 }
 
+// footsteps will determine how loud a monster's normal movement is
+// and create a sound in the monsters location when they move
+void monster::footsteps(game *g, int x, int y)
+{
+ if (has_flag(MF_FLIES))
+  return; // Flying monsters don't have footsteps!
+ int volume = 6; // same as player's footsteps
+ if (has_flag(MF_DIGS))
+  volume = 10;
+ switch (type->size) {
+  case MS_TINY:
+   return; // No sound for the tinies
+  case MS_SMALL:
+   volume /= 3;
+   break;
+  case MS_MEDIUM:
+   break;
+  case MS_LARGE:
+   volume *= 1.5;
+   break;
+  case MS_HUGE:
+   volume *= 2;
+   break;
+  default: break;
+ }
+ int dist = rl_dist(x, y, g->u.posx, g->u.posy);
+ g->add_footstep(x, y, volume, dist);
+ return;
+}
+
 void monster::friendly_move(game *g)
 {
  point next;
@@ -457,6 +484,7 @@ void monster::move_to(game *g, int x, int y)
    moves -= (g->m.move_cost(x, y) - 2) * 50;
   posx = x;
   posy = y;
+  footsteps(g, x, y);
   if (!has_flag(MF_DIGS) && !has_flag(MF_FLIES) &&
       g->m.tr_at(posx, posy) != tr_null) { // Monster stepped on a trap!
    trap* tr = g->traps[g->m.tr_at(posx, posy)];
@@ -523,19 +551,31 @@ void monster::stumble(game *g, bool moved)
 
 /* will_reach() is used for determining whether we'll get to stairs (and 
  * potentially other locations of interest).  It is generally permissive.
+ * TODO: Pathfinding;
+         Make sure that non-smashing monsters won't "teleport" through windows
+         Injure monsters if they're gonna be walking through pits or whatevs
  */
 bool monster::will_reach(game *g, int x, int y)
 {
+ if (is_fleeing(g->u))
+  return false;
+
+ if (has_flag(MF_DIGS))
+  return false;
+
+ if (has_flag(MF_IMMOBILE) && (posx != x || posy != y))
+  return false;
+
  if (has_flag(MF_SMELLS) && g->scent(posx, posy) > 0 &&
-     g->scent(x, y) >= g->scent(posx, posy))
+     g->scent(x, y) > g->scent(posx, posy))
   return true;
 
- if (has_flag(MF_HEARS) && wandf > 0 && rl_dist(wandx, wandy, x, y) <= 3 &&
+ if (can_hear() && wandf > 0 && rl_dist(wandx, wandy, x, y) <= 2 &&
      rl_dist(posx, posy, wandx, wandy) <= wandf)
   return true;
 
  int t;
- if (has_flag(MF_SEES) && g->m.sees(posx, posy, x, y, g->light_level(), t))
+ if (can_see() && g->m.sees(posx, posy, x, y, g->light_level(), t))
   return true;
 
  return false;
@@ -543,7 +583,7 @@ bool monster::will_reach(game *g, int x, int y)
 
 int monster::turns_to_reach(game *g, int x, int y)
 {
- std::vector<point> path = g->m.route(posx, posy, x, y);
+ std::vector<point> path = g->m.route(posx, posy, x, y, has_flag(MF_BASHES));
  if (path.size() == 0)
   return 999;
 
