@@ -81,7 +81,7 @@ mon("dog",		'd',	c_white,	MS_SMALL,	FLESH,
 	(mfb(MF_SEES)|mfb(MF_SMELLS)|mfb(MF_HEARS)|mfb(MF_ANIMAL)|mfb(MF_WARM)|
 	 mfb(MF_FUR)),
 //	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
-	  3,  5,  1,150, 12,  2,  3,  3,  3,  0,  0, 25, 0,
+	 3,  5,  1,150, 12,  2,  3,  3,  3,  0,  0, 25,  0,
 	&mdeath::normal,	&mattack::none, "\
 A medium-sized domesticated dog, gone feral."
 );
@@ -119,7 +119,7 @@ mandibles."
 mon("queen ant",	'a',	c_ltred,	MS_LARGE,	FLESH,
 	(mfb(MF_SMELLS)|mfb(MF_QUEEN)),
 //	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
-	  0, 13,  2, 60,  6,  3,  4,  4,  1, 14,-40,180, 5,
+	  0, 13,  2, 60,  6,  3,  4,  4,  1, 14,-40,180, 1,
 	&mdeath::normal,	&mattack::antqueen, "\
 This ant has a long, bloated thorax, bulging\n\
 with hundreds of small ant eggs.  It moves\n\
@@ -137,9 +137,17 @@ chitin weakened by the fungus sprouting\n\
 from every joint on its body."
 );
 
+mon("giant fly",	'a',	c_ltgray,	MS_SMALL,	FLESH,
+	(mfb(MF_SMELLS)|mfb(MF_FLIES)|mfb(MF_STUMBLES)),
+//	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
+	  0,  8,  5,120,  3,  1,  3,  0,  5,  0,  0, 25,  0,
+	&mdeath::normal,	&mattack::none, "\
+A large housefly the size of a small dog.\n\
+It buzzes around incessantly."
+);
+
 mon("giant bee",	'a',	c_yellow,	MS_SMALL,	FLESH,
-	(mfb(MF_SMELLS)|mfb(MF_VENOM)|mfb(MF_FLIES)|mfb(MF_STUMBLES)|
-	 mfb(MF_ANIMAL)),
+	(mfb(MF_SMELLS)|mfb(MF_VENOM)|mfb(MF_FLIES)|mfb(MF_STUMBLES)),
 //	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
 	  2, 15,  4,140,  4,  1,  1,  5,  6,  5,-50, 20,  0,
 	&mdeath::normal,	&mattack::none, "\
@@ -160,8 +168,8 @@ a vicious sting on its abdomen."
 // GIANT WORMS
 
 mon("graboid",		'S',	c_red,		MS_HUGE,	FLESH,
-	(mfb(MF_DIGS)|mfb(MF_HEARS)|mfb(MF_GOODHEARING)|mfb(MF_ATTACKMON)|
-	 mfb(MF_DESTROYS)|mfb(MF_WARM)|mfb(MF_LEATHER)),
+	(mfb(MF_DIGS)|mfb(MF_HEARS)|mfb(MF_GOODHEARING)|mfb(MF_DESTROYS)|
+	 mfb(MF_WARM)|mfb(MF_LEATHER)),
 //	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
 	  1, 17,  5,180, 11,  3,  8,  4,  0,  5,  0,180,  0,
 	&mdeath::worm,		&mattack::none, "\
@@ -172,8 +180,8 @@ enormous body is hidden underground."
 );
 
 mon("giant worm",	'S',	c_pink,		MS_LARGE,	FLESH,
-	(mfb(MF_DIGS)|mfb(MF_HEARS)|mfb(MF_GOODHEARING)|mfb(MF_ATTACKMON)|
-	 mfb(MF_WARM)|mfb(MF_LEATHER)),
+	(mfb(MF_DIGS)|mfb(MF_HEARS)|mfb(MF_GOODHEARING)|mfb(MF_WARM)|
+	 mfb(MF_LEATHER)),
 //	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
 	 30, 10,  3, 85,  9,  4,  5,  2,  0,  0,  0, 50,  0,
 	&mdeath::worm,		&mattack::none, "\
@@ -227,7 +235,7 @@ yellow fluid."
 
 mon("shocker zombie",	'Z',	c_ltcyan,	MS_MEDIUM,	FLESH,
 	(mfb(MF_SEES)|mfb(MF_HEARS)|mfb(MF_SMELLS)|mfb(MF_WARM)|mfb(MF_BASHES)|
-	 mfb(MF_POISON)|mfb(MF_SHOCK)),
+	 mfb(MF_POISON)),
 //	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
 	  3, 10,  5,110,  8,  1,  6,  0,  4,  0, 40, 65, 25,
 	&mdeath::normal,	&mattack::shockstorm, "\
@@ -365,6 +373,45 @@ moves, plant matter drops off its body\n\
 and immediately takes root."
 );
 
+mon("creeper hub",	'V',	c_dkgray,	MS_MEDIUM,	VEGGY,
+	(mfb(MF_NOHEAD)|mfb(MF_IMMOBILE)),
+//	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
+	  0, 16,  5,100,  0,  0,  0,  0,  0,  8,  0,100, 2,
+	&mdeath::kill_vines,	&mattack::grow_vine, "\
+A thick stalk, rooted to the ground.\n\
+It rapidly sprouts thorny vines in all\n\
+directions."
+);
+
+mon("creeping vine",	'v',	c_green,	MS_TINY,	VEGGY,
+	(mfb(MF_NOHEAD)|mfb(MF_HARDTOSHOOT)|mfb(MF_PLASTIC)|mfb(MF_IMMOBILE)),
+//	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
+	  0,  4,  5, 75,  0,  0,  0,  0,  0,  2,  0, 20, 2,
+	&mdeath::vine_cut,	&mattack::vine, "\
+A thorny vine.  It twists wildly as\n\
+it grows, spreading rapidly."
+);
+
+mon("biollante",	'F',	c_magenta,	MS_LARGE,	VEGGY,
+	(mfb(MF_NOHEAD)|mfb(MF_IMMOBILE)),
+//	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
+	  0, 20,  5,100,  0,  0,  0,  0,  0,  0,-80,120, 2,
+	&mdeath::normal,	&mattack::spit_sap, "\
+A thick stalk topped with a purple\n\
+flower.  The flower's petals are closed,\n\
+and pulsate ominously."
+);
+
+mon("triffid heart",	'T',	c_red,		MS_HUGE,	VEGGY,
+	(mfb(MF_NOHEAD)|mfb(MF_IMMOBILE)|mfb(MF_QUEEN)),
+//	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
+          0, 45,  5,100,  0,  0,  0,  0,  0, 14,  0,300, 5,
+	&mdeath::triffid_heart,	&mattack::triffid_heartbeat, "\
+A knot of roots that looks bizarrely like a\n\
+heart.  It beats slowly with sap, powering\n\
+the root walls around it."
+);
+
 mon("fungaloid",	'F',	c_ltgray,	MS_MEDIUM,	VEGGY,
 	(mfb(MF_HEARS)|mfb(MF_SMELLS)|mfb(MF_POISON)|mfb(MF_NOHEAD)),
 //	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
@@ -408,7 +455,7 @@ A wispy spore, about the size of a fist,\n\
 wafting on the breeze."
 );
 
-mon("fungal spire",	'T',	c_ltgray,	MS_HUGE,	VEGGY,
+mon("fungal spire",	'T',	c_ltgray,	MS_HUGE,	STONE,
 	mfb(MF_NOHEAD)|mfb(MF_POISON)|mfb(MF_IMMOBILE)|mfb(MF_QUEEN),
 //	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
 	  0, 40,  5,100,  0,  0,  0,  0,  0, 10,  0,300, 5,
@@ -421,7 +468,7 @@ continuously growing new defenses."
 mon("fungal wall",	'F',	c_dkgray,	MS_HUGE,	VEGGY,
 	mfb(MF_NOHEAD)|mfb(MF_POISON)|mfb(MF_IMMOBILE),
 //	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
-	  0,  5,  0,100,  0,  0,  0,  0,  0, 10,  0, 60, 3,
+	  0,  5,  0,100,  0,  0,  0,  0,  0, 10,  0, 60, 8,
 	&mdeath::disintegrate,	&mattack::fungus, "\
 A veritable wall of fungus, grown as a\n\
 natural defense by the fungal spire. It\n\
@@ -519,7 +566,7 @@ mon("giant mosquito",	'y',	c_ltgray,	MS_SMALL,	FLESH,
 	(mfb(MF_SMELLS)|mfb(MF_HEARS)|mfb(MF_STUMBLES)|mfb(MF_VENOM)|
 	 mfb(MF_FLIES)),
 //	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
-	 30,  6,  3,140,  8,  2,  2,  2,  5,  0,  0, 20, 0,
+	 22, 12,  3,120,  8,  1,  1,  1,  5,  0,  0, 20, 0,
 	&mdeath::normal,	&mattack::none, "\
 An enormous mosquito, fluttering erratically,\n\
 its face dominated by a long, spear-tipped\n\
@@ -714,7 +761,7 @@ hair impossibly twisted."
 
 mon("vortex",		'v',	c_white,	MS_SMALL,	POWDER,
 	(mfb(MF_HEARS)|mfb(MF_GOODHEARING)|mfb(MF_STUMBLES)|mfb(MF_NOHEAD)|
-	 mfb(MF_HARDTOSHOOT)|mfb(MF_FLIES)|mfb(MF_PLASTIC)|mfb(MF_SHOCK)|
+	 mfb(MF_HARDTOSHOOT)|mfb(MF_FLIES)|mfb(MF_PLASTIC)|
 	 mfb(MF_FRIENDLY_SPECIAL)),
 //	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
 	  2, 30,  5,120,  0,  0,  0,  0,  0,  0,  0, 20, 6,
@@ -728,7 +775,7 @@ mon("flying polyp",	'H',	c_dkgray,	MS_HUGE,	FLESH,
 	(mfb(MF_SMELLS)|mfb(MF_HEARS)|mfb(MF_GOODHEARING)|mfb(MF_NOHEAD)|
 	 mfb(MF_BASHES)|mfb(MF_FLIES)|mfb(MF_ATTACKMON)|mfb(MF_PLASTIC)),
 //	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
-	  1, 42,  5,280, 16,  5,  8, 12,  7,  8,  0,350, 0,
+	  1, 42,  5,280, 16,  3,  8,  6,  7,  8,  0,350, 0,
 	&mdeath::melt,		&mattack::none, "\
 An amorphous mass of twisting black flesh\n\
 that flies through the air swiftly."
