@@ -11,8 +11,8 @@
 #define NUM_ESCAPE_ITEMS 12
 itype_id ESCAPE_ITEMS[NUM_ESCAPE_ITEMS] = {
  itm_cola, itm_caffeine, itm_energy_drink, itm_canister_goo, itm_smokebomb,
- itm_smokebomb_act, itm_adderall, itm_coke, itm_meth, itm_portal,
- itm_teleporter, itm_pheromone
+ itm_smokebomb_act, itm_adderall, itm_coke, itm_meth, itm_teleporter,
+ itm_pheromone
 };
 #endif
 
@@ -43,9 +43,9 @@ struct ratio_index
 void npc::move(game *g)
 {
  npc_action action = npc_undecided;
- int danger = 0, target = -1;
+ int danger = 0, total_danger = 0, target = -1;
 
- choose_monster_target(g, target, danger);
+ choose_monster_target(g, target, danger, total_danger);
  if (g->debugmon)
   debugmsg("NPC %s: target = %d, danger = %d", name.c_str(), target, danger);
 
@@ -60,10 +60,10 @@ void npc::move(game *g)
  }
 // TODO: Place player-aiding actions here, with a weight
 
- if (!bravery_check(danger) ||
+ if (!bravery_check(danger) || !bravery_check(total_danger) || 
      (target == TARGET_PLAYER && attitude == NPCATT_FLEE))
   action = method_of_fleeing(g, target);
- else if (danger > 0)
+ else if (danger > 0 || (target == TARGET_PLAYER && attitude == NPCATT_KILL))
   action = method_of_attack(g, target, danger);
 
  else {	// No present danger
@@ -90,6 +90,14 @@ void npc::move(game *g)
   }
  }
 
+/* Sometimes we'll be following the player at this point, but close enough that
+ * "following" means standing still.  If that's the case, if there are any
+ * monsters around, we should attack them after all!
+ */
+ if (action == npc_follow_player && danger > 0 &&
+     rl_dist(posx, posy, g->u.posx, g->u.posy) <= follow_distance())
+  action = method_of_attack(g, target, danger);
+
  if (g->debugmon)
   debugmsg("%s chose action %s.", name.c_str(), npc_action_name(action).c_str());
 
@@ -128,14 +136,16 @@ void npc::execute_action(game *g, npc_action action, int target)
   move_pause();
   break;
 
- case npc_reload:
+ case npc_reload: {
   moves -= weapon.reload_time(*this);
-  weapon.reload(*this, false);
+  int ammo_index = weapon.pick_reload_ammo(*this, false);
+  if (!weapon.reload(*this, ammo_index))
+   debugmsg("NPC reload failed.");
   recoil = 6;
   if (g->u_see(posx, posy, linet))
    g->add_msg("%s reloads %s %s.", name.c_str(), (male ? "his" : "her"),
               weapon.tname().c_str());
-  break;
+  } break;
 
  case npc_sleep:
 /* TODO: Open a dialogue with the player, allowing us to ask if it's alright if
@@ -303,31 +313,36 @@ void npc::execute_action(game *g, npc_action action, int target)
  }
 }
 
-void npc::choose_monster_target(game *g, int &enemy, int &danger)
+void npc::choose_monster_target(game *g, int &enemy, int &danger,
+                                int &total_danger)
 {
  int linet = 0;
  bool defend_u = g->sees_u(posx, posy, linet) && is_defending();
  int highest_priority = 0;
+ total_danger = 0;
 
  for (int i = 0; i < g->z.size(); i++) {
   monster *mon = &(g->z[i]);
   if (g->pl_sees(this, mon, linet)) {
-   int distance = (100 * trig_dist(posx, posy, mon->posx, mon->posy)) /
+   int distance = (100 * rl_dist(posx, posy, mon->posx, mon->posy)) /
                   mon->speed;
    double hp_percent = (mon->type->hp - mon->hp) / mon->type->hp;
    int priority = mon->type->difficulty * (1 + hp_percent);
    priority -= distance;
    int monster_danger = (mon->type->difficulty * mon->hp) / mon->type->hp;
+   if (!mon->is_fleeing(*this))
+    monster_danger++;
 
    if (mon->friendly != 0) {
     priority = -999;
-    monster_danger = -999;
+    monster_danger *= -1;
    }/* else if (mon->speed < current_speed()) {
     priority -= 10;
     monster_danger -= 10;
    } else
     priority *= 1 + (.1 * distance);
 */
+   total_danger += int(monster_danger / (distance == 0 ? 1 : distance));
 
    if (monster_danger > danger) {
     danger = monster_danger;
@@ -342,7 +357,7 @@ void npc::choose_monster_target(game *g, int &enemy, int &danger)
     enemy = i;
    } else if (defend_u) {
     priority = mon->type->difficulty * (1 + hp_percent);
-    distance = (100 * trig_dist(g->u.posx, g->u.posy, mon->posx, mon->posy)) /
+    distance = (100 * rl_dist(g->u.posx, g->u.posy, mon->posx, mon->posy)) /
                mon->speed;
     priority -= distance;
     if (mon->speed < current_speed())
@@ -410,7 +425,7 @@ npc_action npc::method_of_attack(game *g, int target, int danger)
    return npc_avoid_friendly_fire;
   else if (dist <= confident_range() / 3 && weapon.charges >= gun->burst &&
            gun->burst > 1 &&
-           (target_HP >= weapon.curammo->damage * 3) || emergency(danger * 2))
+           (target_HP >= weapon.curammo->damage * 3 || emergency(danger * 2)))
    return npc_shoot_burst;
   else
    return npc_shoot;
@@ -418,16 +433,27 @@ npc_action npc::method_of_attack(game *g, int target, int danger)
 
 // Check if there's something better to wield
  bool has_empty_gun = false, has_better_melee = false;
+ std::vector<int> empty_guns;
  for (int i = 0; i < inv.size(); i++) {
   if (inv[i].is_gun() && inv[i].charges > 0)
    return npc_wield_loaded_gun;
-  else if (inv[i].is_gun() && enough_time_to_reload(g, target, inv[i]))
+  else if (inv[i].is_gun() && enough_time_to_reload(g, target, inv[i])) {
    has_empty_gun = true;
-  else if (inv[i].melee_value(sklevel) > weapon.melee_value(sklevel) * 1.1)
+   empty_guns.push_back(i);
+  } else if (inv[i].melee_value(sklevel) > weapon.melee_value(sklevel) * 1.1)
    has_better_melee = true;
  }
 
- if (has_empty_gun)
+ bool has_ammo_for_empty_gun = false;
+ for (int i = 0; i < empty_guns.size(); i++) {
+  for (int j = 0; j < inv.size(); j++) {
+   if (inv[j].is_ammo() &&
+       inv[j].ammo_type() == inv[ empty_guns[i] ].ammo_type())
+    has_ammo_for_empty_gun = true;
+  }
+ }
+
+ if (has_empty_gun && has_ammo_for_empty_gun)
   return npc_wield_empty_gun;
  else if (has_better_melee)
   return npc_wield_melee;
@@ -477,7 +503,7 @@ npc_action npc::address_needs(game *g, int danger)
 npc_action npc::address_player(game *g)
 {
  int linet;
- if (attitude == NPCATT_TALK || attitude == NPCATT_TRADE &&
+ if ((attitude == NPCATT_TALK || attitude == NPCATT_TRADE) &&
      g->sees_u(posx, posy, linet)) {
   if (rl_dist(posx, posy, g->u.posx, g->u.posy) <= 6)
    return npc_talk_to_player; // Close enough to talk to you
@@ -505,8 +531,6 @@ npc_action npc::long_term_goal_action(game *g)
 {
  if (g->debugmon)
   debugmsg("long_term_goal_action()");
- int linet;
- int light = g->light_level();
  path.clear();
 
  if (mission == NPC_MISSION_SHOPKEEP)
@@ -586,7 +610,7 @@ void npc::use_escape_item(game *g, int index, int target)
 int npc::confident_range(int index)
 {
  
- if (index == -1 && !weapon.is_gun() || weapon.charges <= 0)
+ if (index == -1 || !weapon.is_gun() || weapon.charges <= 0)
   return 1;
 
  double deviation = 0;
@@ -633,7 +657,7 @@ int npc::confident_range(int index)
  } else { // We aren't firing a gun, we're throwing something!
 
   item *thrown = &(inv[index]);
-  int max = throw_range(index); // The max distance we can throw
+  max = throw_range(index); // The max distance we can throw
   int deviation = 0;
   if (sklevel[sk_throw] < 8)
    deviation += rng(0, 8 - sklevel[sk_throw]);
@@ -657,6 +681,9 @@ int npc::confident_range(int index)
  }
 
 // Using 180 for now for extra-confident NPCs.
+ int ret = (max > int(180 / deviation) ? max : int(180 / deviation));
+ if (weapon.is_gun() && weapon.charges > 0 && ret > weapon.curammo->range)
+  return weapon.curammo->range;
  return (max > int(180 / deviation) ? max : int(180 / deviation));
 }
 
@@ -665,7 +692,7 @@ bool npc::wont_hit_friend(game *g, int tarx, int tary, int index)
 {
  int linet = 0, dist = sight_range(g->light_level());
  int confident = confident_range(index);
- if (rl_dist(posx, posy, tarx, tary) <= confident / 2)
+ if (rl_dist(posx, posy, tarx, tary) <= int(confident * .8))
   return true; // If we're *really* sure that our aim is dead-on
 
  std::vector<point> traj;
@@ -692,7 +719,8 @@ bool npc::wont_hit_friend(game *g, int tarx, int tary, int index)
 // Hit an NPC that's on our team?
     for (int n = 0; n < g->active_npc.size(); n++) {
      npc* guy = &(g->active_npc[n]);
-     if ((is_friend() == guy->is_friend()) && guy->posx == x && guy->posy == y)
+     if (guy != this && (is_friend() == guy->is_friend()) &&
+         guy->posx == x && guy->posy == y)
       return false;
     }
    }
@@ -773,14 +801,17 @@ void npc::move_to(game *g, int x, int y)
   }
  }
  if (rl_dist(posx, posy, x, y) > 1) {
+/*
   debugmsg("Tried to move_to more than one space! (%d, %d) to (%d, %d)",
            posx, posy, x, y);
-  //debugmsg("Route is size %d.", path.size());
+  debugmsg("Route is size %d.", path.size());
+*/
   int linet;
+  std::vector<point> newpath;
   if (g->m.sees(posx, posy, x, y, -1, linet))
-   path = line_to(posx, posy, x, y, linet);
-  moves -= 100;
-  return;
+   newpath = line_to(posx, posy, x, y, linet);
+  x = newpath[0].x;
+  y = newpath[0].y;
  }
  if (x == posx && y == posy)	// We're just pausing!
   moves -= 100;
@@ -824,17 +855,16 @@ void npc::move_to_next(game *g)
   path.erase(path.begin());
 }
 
+// TODO: Rewrite this.  It doesn't work well and is ugly.
 void npc::avoid_friendly_fire(game *g, int target)
 {
- int blockx, blocky, tarx, tary;
+ int tarx, tary;
  if (target == TARGET_PLAYER) {
   tarx = g->u.posx;
   tary = g->u.posy;
  } else if (target >= 0) {
   tarx = g->z[target].posx;
   tary = g->z[target].posy;
-  blockx = g->u.posx;
-  blocky = g->u.posy;
   if (!one_in(3))
    say(g, "<move> so I can shoot that %s!", g->z[target].name().c_str());
  } else {
@@ -844,7 +874,6 @@ void npc::avoid_friendly_fire(game *g, int target)
  }
 
  int xdir = (tarx > posx ? 1 : -1), ydir = (tary > posy ? 1 : -1);
- int xdif = abs(tarx - posx), ydif = abs(tary - posy);
  direction dir_to_target = direction_from(posx, posy, tarx, tary);
  std::vector<point> valid_moves;
 /* Ugh, big ugly switch.  This fills valid_moves with a list of moves from most
@@ -985,7 +1014,6 @@ void npc::find_item(game *g)
 {
  fetching_item = false;
  int best_value = minimum_item_value();
- double bestWgt = 0., bestVol = 0.;
  int range = sight_range(g->light_level());
  int minx = posx - range, maxx = posx + range,
      miny = posy - range, maxy = posy + range;
@@ -1006,9 +1034,9 @@ void npc::find_item(game *g)
      int itval = value(g->m.i_at(x, y)[i]);
      int wgt = g->m.i_at(x, y)[i].weight(), vol = g->m.i_at(x, y)[i].volume();
      if (itval > best_value &&
-         (itval > worst_item_value ||
+         //(itval > worst_item_value ||
           (weight_carried() + wgt <= weight_capacity() / 4 &&
-           volume_carried() + vol <= volume_capacity()       ))) {
+           volume_carried() + vol <= volume_capacity()       )) {
       itx = x;
       ity = y;
       index = i;
@@ -1049,9 +1077,9 @@ void npc::pick_up_item(game *g)
  for (int i = 0; i < items->size(); i++) {
   int itval = value((*items)[i]), vol = (*items)[i].volume(),
       wgt = (*items)[i].weight();
-  if (itval >= minimum_item_value() && (itval >= worst_item_value ||
+  if (itval >= minimum_item_value() &&// (itval >= worst_item_value ||
       (volume_carried() + total_volume + vol <= volume_capacity() &&
-       weight_carried() + total_weight + wgt <= weight_capacity() / 4))) {
+       weight_carried() + total_weight + wgt <= weight_capacity() / 4)) {
    pickup.push_back(i);
    total_volume += vol;
    total_weight += wgt;
@@ -1263,7 +1291,7 @@ void npc::alt_attack(game *g, int target)
   move_pause();
   return;
  }
- int dist = trig_dist(posx, posy, tarx, tary);
+ int dist = rl_dist(posx, posy, tarx, tary);
 /* ALT_ATTACK_ITEMS is an array which stores the itype_id of all alternate
  * items, from least to most important.
  * See npc.h for definition of ALT_ATTACK_ITEMS
@@ -1301,8 +1329,7 @@ void npc::alt_attack(game *g, int target)
 
 // Are we going to throw this item?
  if (!thrown_item(used))
-  //activate_item(g, index);
-  debugmsg("npc::activate_item() needs to be written!");
+  activate_item(g, index);
  else { // We are throwing it!
 
   std::vector<point> trajectory;
@@ -1329,7 +1356,7 @@ void npc::alt_attack(game *g, int target)
      for (int x = posx - dist; x <= posx + dist; x++) {
       for (int y = posy - dist; y <= posy + dist; y++) {
        int newtarget = g->mon_at(x, y);
-       int newdist = trig_dist(posx, posy, x, y);
+       int newdist = rl_dist(posx, posy, x, y);
 // TODO: Change "newdist >= 2" to "newdist >= safe_distance(used)"
 // Molotovs are safe at 2 tiles, grenades at 4, mininukes at 8ish
        if (newdist <= conf && newdist >= 2 && newtarget != -1 &&
@@ -1348,7 +1375,7 @@ void npc::alt_attack(game *g, int target)
     for (int dist = 2; dist <= conf; dist++) {
      for (int x = posx - dist; x <= posx + dist; x++) {
       for (int y = posy - dist; y <= posy + dist; y++) {
-       int new_dist = trig_dist(posx, posy, x, y);
+       int new_dist = rl_dist(posx, posy, x, y);
        if (new_dist > best_dist && wont_hit_friend(g, x, y, index)) {
         best_dist = new_dist;
         tarx = x;
@@ -1378,6 +1405,19 @@ void npc::alt_attack(game *g, int target)
  } // Done with throwing-item block
 }
 
+void npc::activate_item(game *g, int index)
+{
+ item *it = &(inv[index]);
+ iuse use;
+ if (it->is_tool()) {
+  it_tool* tool = dynamic_cast<it_tool*>(it->type);
+  (use.*tool->use)(g, this, it, false);
+ } else if (it->is_food()) {
+  it_comest* comest = dynamic_cast<it_comest*>(it->type);
+  (use.*comest->use)(g, this, it, false);
+ }
+}
+
 bool thrown_item(item *used)
 {
  if (used == NULL) {
@@ -1542,9 +1582,9 @@ void npc::pick_and_eat(game *g)
   int eaten_hunger = -1, eaten_thirst = -1;
   it_comest* food = NULL;
   if (inv[i].is_food())
-   it_comest* food = dynamic_cast<it_comest*>(inv[i].type);
+   food = dynamic_cast<it_comest*>(inv[i].type);
   else if (inv[i].is_food_container())
-   it_comest* food = dynamic_cast<it_comest*>(inv[i].contents[0].type);
+   food = dynamic_cast<it_comest*>(inv[i].contents[0].type);
   if (food != NULL) {
    eaten_hunger = hunger - food->nutr;
    eaten_thirst = thirst - food->quench;
