@@ -316,6 +316,32 @@ bool query_yn(const char *mes, ...)
  return false;
 }
 
+int query_int(const char *mes, ...)
+{
+ va_list ap;
+ va_start(ap, mes);
+ char buff[1024];
+ vsprintf(buff, mes, ap);
+ va_end(ap);
+ int win_width = strlen(buff) + 10;
+ WINDOW* w = newwin(3, win_width, 11, 0);
+ wborder(w, LINE_XOXO, LINE_XOXO, LINE_OXOX, LINE_OXOX,
+            LINE_OXXO, LINE_OOXX, LINE_XXOO, LINE_XOOX );
+ mvwprintz(w, 1, 1, c_ltred, "%s (0-9)", buff);
+ wrefresh(w);
+
+ int temp;
+ do
+  temp = getch();
+ while ((temp-48)<0 || (temp-48)>9);
+ werase(w);
+ wrefresh(w);
+ delwin(w);
+ refresh();
+
+ return temp-48;
+}
+
 std::string string_input_popup(const char *mes, ...)
 {
  std::string ret;
@@ -348,7 +374,7 @@ std::string string_input_popup(const char *mes, ...)
    delwin(w);
    refresh();
    return ret;
-  } else if (ch == KEY_BACKSPACE && posx > startx) {
+  } else if ((ch == KEY_BACKSPACE || ch == 127) && posx > startx) {
    ret = ret.substr(0, ret.size() - 1);
    mvwputch(w, 1, posx, c_ltgray, '_');
    posx--;
@@ -394,7 +420,7 @@ std::string string_input_popup(int max_length, const char *mes, ...)
    delwin(w);
    refresh();
    return ret;
-  } else if (ch == KEY_BACKSPACE && posx > startx) {
+  } else if ((ch == KEY_BACKSPACE || ch == 127) && posx > startx) {
    ret = ret.substr(0, ret.size() - 1);
    mvwputch(w, 1, posx, c_ltgray, '_');
    posx--;
@@ -651,5 +677,6 @@ char rand_char()
   case 8:	return '*';
   case 9:	return '^';
  }
+ return '?';
 }
 #endif
