@@ -65,21 +65,21 @@ oter_id shop(int dir)
  if (one_in(20))
   type = 14;
  switch (type) {
-  case  0: ret = ot_s_lot;	       break;
-  case  1: ret = ot_s_gas_north;       break;
-  case  2: ret = ot_s_pharm_north;     break;
-  case  3: ret = ot_s_grocery_north;   break;
-  case  4: ret = ot_s_hardware_north;  break;
-  case  5: ret = ot_s_sports_north;    break;
-  case  6: ret = ot_s_liquor_north;    break;
-  case  7: ret = ot_s_gun_north;       break;
-  case  8: ret = ot_s_clothes_north;   break;
-  case  9: ret = ot_s_library_north;   break;
-  case 10: ret = ot_sub_station_north; break;
-  case 11: ret = ot_bank_north;        break;
-  case 12: ret = ot_bar_north;         break;
+  case  0: ret = ot_s_lot;	         break;
+  case  1: ret = ot_s_gas_north;         break;
+  case  2: ret = ot_s_pharm_north;       break;
+  case  3: ret = ot_s_grocery_north;     break;
+  case  4: ret = ot_s_hardware_north;    break;
+  case  5: ret = ot_s_sports_north;      break;
+  case  6: ret = ot_s_liquor_north;      break;
+  case  7: ret = ot_s_gun_north;         break;
+  case  8: ret = ot_s_clothes_north;     break;
+  case  9: ret = ot_s_library_north;     break;
+  case 10: ret = ot_sub_station_north;   break;
+  case 11: ret = ot_bank_north;          break;
+  case 12: ret = ot_bar_north;           break;
   case 13: ret = ot_s_electronics_north; break;
-  case 14: ret = ot_police_north;      break;
+  case 14: ret = ot_police_north;        break;
  }
  if (ret == ot_s_lot)
   return ret;
@@ -506,8 +506,11 @@ void overmap::generate_sub(overmap* above)
  std::vector<city> ant_points;
  std::vector<city> goo_points;
  std::vector<city> lab_points;
- std::vector<city> shaft_points;
+ std::vector<point> shaft_points;
  std::vector<city> mine_points;
+ std::vector<point> bunker_points;
+ std::vector<point> triffid_points;
+ std::vector<point> temple_points;
  for (int i = 0; i < OMAPX; i++) {
   for (int j = 0; j < OMAPY; j++) {
    seen(i, j) = false;	// Start by setting all squares to unseen
@@ -550,6 +553,13 @@ void overmap::generate_sub(overmap* above)
    } else if (above->ter(i, j) == ot_forest_water)
     ter(i, j) = ot_cavern;
 
+   else if (above->ter(i, j) == ot_triffid_grove ||
+            above->ter(i, j) == ot_triffid_roots)
+    triffid_points.push_back( point(i, j) );
+
+   else if (above->ter(i, j) == ot_temple_stairs)
+    temple_points.push_back( point(i, j) );
+
    else if (above->ter(i, j) == ot_lab_core ||
             (posz == -1 && above->ter(i, j) == ot_lab_stairs))
     lab_points.push_back(city(i, j, rng(1, 5 + posz)));
@@ -557,8 +567,11 @@ void overmap::generate_sub(overmap* above)
    else if (above->ter(i, j) == ot_lab_stairs)
     ter(i, j) = ot_lab;
 
+   else if (above->ter(i, j) == ot_bunker && posz == -1)
+    bunker_points.push_back( point(i, j) );
+
    else if (above->ter(i, j) == ot_mine_entrance)
-    shaft_points.push_back(city(i, j, 0));
+    shaft_points.push_back( point(i, j) );
 
    else if (above->ter(i, j) == ot_mine_shaft ||
             above->ter(i, j) == ot_mine_down    ) {
@@ -578,10 +591,11 @@ void overmap::generate_sub(overmap* above)
      ter(i, j) = ot_silo_finale;
     else
      ter(i, j) = ot_silo;
-
    }
+
   }
  }
+
  for (int i = 0; i < goo_points.size(); i++)
   build_slimepit(goo_points[i].x, goo_points[i].y, goo_points[i].s);
  place_hiways(sewer_points,  ot_sewer_nesw);
@@ -593,6 +607,8 @@ void overmap::generate_sub(overmap* above)
   build_lab(lab_points[i].x, lab_points[i].y, lab_points[i].s);
  for (int i = 0; i < ant_points.size(); i++)
   build_anthill(ant_points[i].x, ant_points[i].y, ant_points[i].s);
+ polish(ot_subway_ns, ot_subway_nesw);
+ polish(ot_ants_ns, ot_ants_nesw);
  for (int i = 0; i < above->cities.size(); i++) {
   if (one_in(3))
    zg.push_back(
@@ -606,8 +622,6 @@ void overmap::generate_sub(overmap* above)
  place_rifts();
  for (int i = 0; i < mine_points.size(); i++)
   build_mine(mine_points[i].x, mine_points[i].y, mine_points[i].s);
- polish(ot_subway_ns, ot_subway_nesw);
- polish(ot_ants_ns, ot_ants_nesw);
 // Basements done last so sewers, etc. don't overwrite them
  for (int i = 0; i < OMAPX; i++) {
   for (int j = 0; j < OMAPY; j++) {
@@ -618,6 +632,22 @@ void overmap::generate_sub(overmap* above)
  }
  for (int i = 0; i < shaft_points.size(); i++)
   ter(shaft_points[i].x, shaft_points[i].y) = ot_mine_shaft;
+ for (int i = 0; i < bunker_points.size(); i++)
+  ter(bunker_points[i].x, bunker_points[i].y) = ot_bunker;
+ for (int i = 0; i < triffid_points.size(); i++) {
+  if (posz == -1)
+   ter( triffid_points[i].x, triffid_points[i].y ) = ot_triffid_roots;
+  else
+   ter( triffid_points[i].x, triffid_points[i].y ) = ot_triffid_finale;
+ }
+
+ for (int i = 0; i < temple_points.size(); i++) {
+  if (posz == -5)
+   ter( temple_points[i].x, temple_points[i].y ) = ot_temple_finale;
+  else
+   ter( temple_points[i].x, temple_points[i].y ) = ot_temple_stairs;
+ }
+
 }
 
 void overmap::make_tutorial()
@@ -667,24 +697,11 @@ std::vector<point> overmap::find_all(point origin, oter_id type, int type_range,
 
 std::vector<point> overmap::find_terrain(std::string term, int cursx, int cursy)
 {
- int range = 1;
  std::vector<point> found;
- for (int i = 0; i < num_ter_types; i++) {
-  if (oterlist[i].name.find(term) != std::string::npos) {
-   if (i == ot_forest || i == ot_hive || i == ot_hiway_ns ||
-       i == ot_bridge_ns)
-    range = 2;
-   else if (i >= ot_road_ns && i < ot_road_nesw_manhole)
-    range = ot_road_nesw_manhole - i + 1;
-   else if (i >= ot_river_center && i < ot_river_nw)
-    range = ot_river_nw - i + 1;
-   else if (i >= ot_house_north && i < ot_lab)
-    range = 4;
-   else if (i == ot_lab)
-    range = 2;
-   int maxdist = OMAPX;
-   found = find_all(point(cursx,cursy), oter_id(i), range, maxdist, true);
-   i = num_ter_types;
+ for (int x = 0; x < OMAPX; x++) {
+  for (int y = 0; y < OMAPY; y++) {
+   if (seen(x, y) && oterlist[ter(x, y)].name.find(term) != std::string::npos)
+    found.push_back( point(x, y) );
   }
  }
  return found;
@@ -714,7 +731,7 @@ void overmap::draw(WINDOW *w, game *g, int &cursx, int &cursy,
  if (g->u.active_mission >= 0 &&
      g->u.active_mission < g->u.active_missions.size())
   target = g->u.active_missions[g->u.active_mission].target;
-  bool see, target_drawn;
+  bool see;
   oter_id cur_ter;
   nc_color ter_color;
   long ter_sym;
@@ -742,7 +759,6 @@ void overmap::draw(WINDOW *w, game *g, int &cursx, int &cursy,
 // Now actually draw the map
   for (int i = -25; i < 25; i++) {
    for (int j = -12; j <= (ch == 'j' ? 13 : 12); j++) {
-    target_drawn = false;
     omx = cursx + i;
     omy = cursy + j;
     see = false;
@@ -928,7 +944,7 @@ point overmap::choose_point(game *g)
    ret = point(-1, -1);
   else if (ch == 'N') {
    timeout(-1);
-   add_note(cursx, cursy, string_input_popup(49, "Enter note")); //49: max note length
+   add_note(cursx, cursy, string_input_popup(49, "Enter note")); // 49 char max
    timeout(BLINK_SPEED);
   } else if(ch == 'D'){
    timeout(-1);
@@ -960,7 +976,7 @@ point overmap::choose_point(game *g)
     if(terlist.size() != 0){
      int i = 0;
      //Navigate through results
-     do{
+     do {
       //Draw search box
       wborder(w_search, LINE_XOXO, LINE_XOXO, LINE_OXOX, LINE_OXOX,
               LINE_OXXO, LINE_OOXX, LINE_XXOO, LINE_XOOX );
@@ -1010,6 +1026,9 @@ point overmap::choose_point(game *g)
  werase(w_map);
  wrefresh(w_map);
  delwin(w_map);
+ werase(w_search);
+ wrefresh(w_search);
+ delwin(w_search);
  erase();
  g->refresh_all();
  return ret;
@@ -1941,8 +1960,10 @@ void overmap::place_specials()
    for (int i = 0; i < NUM_OMSPECS; i++) {
     omspec_place place;
     overmap_special special = overmap_specials[i];
+    int min = special.min_dist_from_city, max = special.max_dist_from_city;
     if ((placed[i] < special.max_appearances || special.max_appearances == 0) &&
-        dist_from_city(p) >= special.min_dist_from_city &&
+        (min == -1 || dist_from_city(p) >= min) &&
+        (max == -1 || dist_from_city(p) <= max) &&
         (place.*special.able)(this, p))
      valid.push_back( omspec_id(i) );
    }
@@ -1961,25 +1982,32 @@ void overmap::place_specials()
 
 void overmap::place_special(overmap_special special, point p)
 {
+ bool rotated = false;
 // First, place terrain...
  ter(p.x, p.y) = special.ter;
 // Next, obey any special effects the flags might have
  if (special.flags & mfb(OMS_FLAG_ROTATE_ROAD)) {
-  if (is_road(p.x + 1, p.y))
+  if (is_road(p.x, p.y - 1))
+   rotated = true;
+  else if (is_road(p.x + 1, p.y)) {
    ter(p.x, p.y) = oter_id( int(ter(p.x, p.y)) + 1);
-  else if (is_road(p.x, p.y + 1))
+   rotated = true;
+  } else if (is_road(p.x, p.y + 1)) {
    ter(p.x, p.y) = oter_id( int(ter(p.x, p.y)) + 2);
-  else if (is_road(p.x - 1, p.y))
+   rotated = true;
+  } else if (is_road(p.x - 1, p.y)) {
    ter(p.x, p.y) = oter_id( int(ter(p.x, p.y)) + 3);
+   rotated = true;
+  }
  }
 
- if (special.flags & mfb(OMS_FLAG_ROTATE_RANDOM))
+ if (!rotated && special.flags & mfb(OMS_FLAG_ROTATE_RANDOM))
   ter(p.x, p.y) = oter_id( int(ter(p.x, p.y)) + rng(0, 3) );
   
  if (special.flags & mfb(OMS_FLAG_3X3)) {
   for (int x = -1; x <= 1; x++) {
    for (int y = -1; y <= 1; y++) {
-    if (x == 0 & y == 0)
+    if (x == 0 && y == 0)
      y++; // Already handled
     point np(p.x + x, p.y + y);
     ter(np.x, np.y) = special.ter;
@@ -1987,6 +2015,30 @@ void overmap::place_special(overmap_special special, point p)
   }
  }
 
+ if (special.flags & mfb(OMS_FLAG_3X3_SECOND)) {
+  int startx = -1, starty = -1;
+  if (is_road(p.x, p.y - 1)) { // Road to north
+   startx = p.x - 1;
+   starty = p.y;
+  } else if (is_road(p.x + 1, p.y)) { // Road to east
+   startx = p.x - 2;
+   starty = p.y - 1;
+  } else if (is_road(p.x, p.y + 1)) { // Road to south
+   startx = p.x - 1;
+   starty = p.y - 2;
+  } else if (is_road(p.x - 1, p.y)) { // Road to west
+   startx = p.x;
+   starty = p.y - 1;
+  }
+  if (startx != -1) {
+   for (int x = startx; x < startx + 3; x++) {
+    for (int y = starty; y < starty + 3; y++)
+     ter(x, y) = oter_id(special.ter + 1);
+   }
+   ter(p.x, p.y) = special.ter;
+  }
+ }
+
  if (special.flags & mfb(OMS_FLAG_BLOB)) {
   for (int x = -2; x <= 2; x++) {
    for (int y = -2; y <= 2; y++) {
@@ -2078,7 +2130,7 @@ void overmap::place_mongroups()
     }
    }
    if (swamp_count >= 15) // 30% swamp!
-    zg.push_back(mongroup(mcat_swamp, x * 2, y * 2, 3, rng(500, 2000)));
+    zg.push_back(mongroup(mcat_swamp, x * 2, y * 2, 3, rng(200, 800)));
   }
  }
 
@@ -2090,12 +2142,6 @@ void overmap::place_mongroups()
 	         rng(20, 40), rng(500, 1000)));
  }
 
- numgroups = rng(0, 6);
- for (int i = 0; i < numgroups; i++) {
-  zg.push_back(
-	mongroup(mcat_plants, rng(0, OMAPX * 2 - 1), rng(0, OMAPY * 2 - 1),
-	         rng(30, 50), rng(800, 1300)));
- }
 // Forest groups cover the entire map
  zg.push_back(
 	mongroup(mcat_forest, 0, OMAPY, OMAPY,
