@@ -9,6 +9,7 @@
 #include "trap.h"
 #include "morale.h"
 #include "inventory.h"
+#include "artifact.h"
 #include <vector>
 #include <string>
 
@@ -25,9 +26,9 @@ public:
  player& operator= (player rhs);
 
 // newcharacter.cpp 
- bool create(game *g, character_type type);
- int  random_good_trait(character_type type);
- int  random_bad_trait (character_type type);
+ bool create(game *g, character_type type, std::string tempname = "");
+ int  random_good_trait();
+ int  random_bad_trait ();
  void normalize(game *g);	// Starting set up of HP and inventory
 // </newcharacter.cpp>
 
@@ -60,6 +61,8 @@ public:
  void mutate(game *g);
 
  int  sight_range(int light_level);
+ int  overmap_sight_range(int light_level);
+ int  clairvoyance(); // Sight through walls &c
  bool has_two_arms();
  bool can_wear_boots();
  bool is_armed();	// True if we're wielding something; true for bionics
@@ -68,6 +71,7 @@ public:
 
  void pause();		// '.' command; pauses & reduces recoil
  int  hit_roll(); // Our basic hit roll, compared to our target's dodge roll
+ bool scored_crit(int target_dodge = 0);
  int  hit_mon(game *g, monster *z); // Handles hitting a monster up to its death
 // hit_player returns false on a miss, and modifies bp, hitdam, and hitcut
  bool hit_player(player &p, body_part &bp, int &hitdam, int &hitcut);
@@ -161,15 +165,19 @@ public:
  item &i_at(char let);	// Returns the item with inventory letter let
  item &i_of_type(itype_id type); // Returns the first item with this type
  std::vector<item> inv_dump(); // Inventory + weapon + worn (for death, etc)
- void use_amount(itype_id it, int quantity);// Uses up items
- void use_charges(itype_id it, int quantity);// Uses up charges
  int  butcher_factor();	// Automatically picks our best butchering tool
-
  bool is_wearing(itype_id it);	// Are we wearing a specific itype?
+ bool has_artifact_with(art_effect_passive effect);
+
 // has_amount works ONLY for quantity.
- bool has_amount(itype_id it, int quantity);
 // has_charges works ONLY for charges.
+ void use_amount(itype_id it, int quantity, bool use_container = false);
+ void use_charges(itype_id it, int quantity);// Uses up charges
+ bool has_amount(itype_id it, int quantity);
  bool has_charges(itype_id it, int quantity);
+ int  amount_of(itype_id it);
+ int  charges_of(itype_id it);
+
  bool has_weapon_or_armor(char let);	// Has an item with invlet let
  bool has_item(char let);		// Has an item with invlet let
  bool has_item(item *it);		// Has a specific item
