@@ -6,6 +6,7 @@
 #include "line.h"
 #include "skill.h"
 #include "rng.h"
+#include "item.h"
 
 int time_to_fire(player &p, it_gun* firing);
 int recoil_add(player &p);
@@ -18,6 +19,8 @@ void shoot_player(game *g, player &p, player *h, int &dam, double goodhit);
 void splatter(game *g, std::vector<point> trajectory, int dam,
               monster* mon = NULL);
 
+void ammo_effects(game *g, int x, int y, long flags);
+
 void game::fire(player &p, int tarx, int tary, std::vector<point> &trajectory,
                 bool burst)
 {
@@ -31,8 +34,13 @@ void game::fire(player &p, int tarx, int tary, std::vector<point> &trajectory,
  }
  bool is_bolt = false;
  unsigned int flags = p.weapon.curammo->item_flags;
- if (p.weapon.curammo->type == AT_BOLT)	// Bolts are silent
+ if (p.weapon.curammo->type == AT_BOLT || p.weapon.curammo->type == AT_ARROW)	// Bolts and arrows are silent
   is_bolt = true;
+ if ((p.weapon.has_flag(IF_STR8_DRAW)  && p.str_cur <  8) ||
+     (p.weapon.has_flag(IF_STR10_DRAW) && p.str_cur < 10)   ) {
+  add_msg("You're not strong enough to draw the bow!");
+  return;
+ }
 
  int x = p.posx, y = p.posy;
  it_gun* firing = dynamic_cast<it_gun*>(p.weapon.type);
@@ -114,6 +122,7 @@ void game::fire(player &p, int tarx, int tary, std::vector<point> &trajectory,
    }
    
    if (dam <= 0) { // Ran out of momentum.
+    ammo_effects(this, trajectory[i].x, trajectory[i].y, flags);
     if (is_bolt &&
         ((p.weapon.curammo->m1 == WOOD && !one_in(4)) ||
          (p.weapon.curammo->m1 != WOOD && !one_in(15))))
@@ -137,7 +146,9 @@ void game::fire(player &p, int tarx, int tary, std::vector<point> &trajectory,
     if (i < trajectory.size() - 1) // Unintentional hit
      goodhit = double(rand() / (RAND_MAX + 1.0)) / 2;
     
-    splatter(this, trajectory, dam, &z[mondex]);
+    std::vector<point> blood_traj = trajectory;
+    blood_traj.insert(blood_traj.begin(), point(p.posx, p.posy));
+    splatter(this, blood_traj, dam, &z[mondex]);
     shoot_monster(this, p, z[mondex], dam, goodhit);
 
 
@@ -152,24 +163,27 @@ void game::fire(player &p, int tarx, int tary, std::vector<point> &trajectory,
     else
      h = &(active_npc[npc_at(tx, ty)]);
 
-    splatter(this, trajectory, dam);
-    shoot_player(this, p, h, dam, missed_by);
+    std::vector<point> blood_traj = trajectory;
+    blood_traj.insert(blood_traj.begin(), point(p.posx, p.posy));
+    splatter(this, blood_traj, dam);
+    shoot_player(this, p, h, dam, goodhit);
 
    } else
     m.shoot(this, tx, ty, dam, i == trajectory.size() - 1, flags);
   } // Done with the trajectory!
 
+  int lastx = trajectory[trajectory.size() - 1].x;
+  int lasty = trajectory[trajectory.size() - 1].y;
+  ammo_effects(this, lastx, lasty, flags);
+
+  if (m.move_cost(lastx, lasty) == 0) {
+   lastx = trajectory[trajectory.size() - 2].x;
+   lasty = trajectory[trajectory.size() - 2].y;
+  }
   if (is_bolt &&
       ((p.weapon.curammo->m1 == WOOD && !one_in(5)) ||
-       (p.weapon.curammo->m1 != WOOD && !one_in(15)))) {
-    int lastx = trajectory[trajectory.size() - 1].x;
-    int lasty = trajectory[trajectory.size() - 1].y;
-    if (m.move_cost(lastx, lasty) == 0) {
-     lastx = trajectory[trajectory.size() - 2].x;
-     lasty = trajectory[trajectory.size() - 2].y;
-    }
+       (p.weapon.curammo->m1 != WOOD && !one_in(15))  ))
     m.add_item(lastx, lasty, ammotmp);
-  }
  }
 
  if (p.weapon.charges == 0)
@@ -229,8 +243,8 @@ void game::throw_item(player &p, int tarx, int tary, item &thrown,
  }
 
  std::string message;
- int dam = (thrown.weight() + thrown.type->melee_dam + p.str_cur) /
-            double(2 + double(thrown.volume() / 6));
+ int dam = (thrown.weight() / 4 + thrown.type->melee_dam / 2 + p.str_cur / 2) /
+            double(2 + double(thrown.volume() / 4));
  int i, tx, ty;
  for (i = 0; i < trajectory.size() && dam > 0; i++) {
   message = "";
@@ -444,7 +458,7 @@ std::vector<point> game::target(int &x, int &y, int lowx, int lowy, int hix,
    if (target == t.size()) target = 0;
    x = t[target].posx;
    y = t[target].posy;
-  } else if (ch == '.' || ch == 'f' || ch == 'F') {
+  } else if (ch == '.' || ch == 'f' || ch == 'F' || ch == '\n') {
    for (int i = 0; i < t.size(); i++) {
     if (t[i].posx == x && t[i].posy == y)
      target = i;
@@ -504,7 +518,16 @@ int time_to_fire(player &p, it_gun* firing)
    return 30;
   else
    return (150 - 15 * p.sklevel[sk_rifle]);
- break;
+ case (sk_archery):
+  if (p.sklevel[sk_archery] > 8)
+   return 20;
+  else
+   return (220 - 25 * p.sklevel[sk_archery]); break;
+ case sk_launcher:
+  if (p.sklevel[sk_launcher] > 8)
+   return 30;
+  else
+   return (200 - 20 * p.sklevel[sk_launcher]);
  default:
   debugmsg("Why is shooting %s using %s skill?", (firing->name).c_str(),
 		skill_name(firing->skill_used).c_str());
@@ -541,7 +564,12 @@ void make_gun_sound_effect(game *g, player &p, bool burst)
  if (p.weapon.curammo->type == AT_FUSION || p.weapon.curammo->type == AT_BATT ||
      p.weapon.curammo->type == AT_PLUT)
   g->sound(p.posx, p.posy, 8, "Fzzt!");
- else if (p.weapon.curammo->type != AT_BOLT)
+ else if (p.weapon.curammo->type == AT_40MM)
+  g->sound(p.posx, p.posy, 8, "Thunk!");
+ else if (p.weapon.curammo->type == AT_GAS)
+  g->sound(p.posx, p.posy, 4, "Fwoosh!");
+ else if (p.weapon.curammo->type != AT_BOLT &&
+          p.weapon.curammo->type != AT_ARROW)
   g->sound(p.posx, p.posy, noise, gunsound);
 }
 
@@ -749,7 +777,7 @@ void splatter(game *g, std::vector<point> trajectory, int dam, monster* mon)
  int distance = 1;
  if (dam > 50)
   distance = 3;
- else if (dam > 15)
+ else if (dam > 20)
   distance = 2;
 
  std::vector<point> spurt = continue_line(trajectory, distance);
@@ -763,3 +791,41 @@ void splatter(game *g, std::vector<point> trajectory, int dam, monster* mon)
    g->m.add_field(g, tarx, tary, blood, 1);
  }
 }
+
+void ammo_effects(game *g, int x, int y, long flags)
+{
+ if (flags & mfb(IF_AMMO_EXPLOSIVE))
+  g->explosion(x, y, 24, 0, false);
+
+ if (flags & mfb(IF_AMMO_FRAG))
+  g->explosion(x, y, 12, 28, false);
+
+ if (flags & mfb(IF_AMMO_NAPALM))
+  g->explosion(x, y, 18, 0, true);
+
+ if (flags & mfb(IF_AMMO_EXPLOSIVE_BIG))
+  g->explosion(x, y, 40, 0, false);
+
+ if (flags & mfb(IF_AMMO_TEARGAS)) {
+  for (int i = -2; i <= 2; i++) {
+   for (int j = -2; j <= 2; j++)
+    g->m.add_field(g, x + i, y + j, fd_tear_gas, 3);
+  }
+ }
+ 
+ if (flags & mfb(IF_AMMO_SMOKE)) {
+  for (int i = -1; i <= 1; i++) {
+   for (int j = -1; j <= 1; j++)
+    g->m.add_field(g, x + i, y + j, fd_smoke, 3);
+  }
+ }
+
+ if (flags & mfb(IF_AMMO_FLASHBANG))
+  g->flashbang(x, y);
+
+ if (flags & mfb(IF_AMMO_FLAME)) {
+  if (g->m.add_field(g, x, y, fd_fire, 1))
+   g->m.field_at(x, y).age = 800;
+ }
+
+}
