@@ -8,7 +8,8 @@ enum skill {
 // Melee
  sk_dodge, sk_melee, sk_unarmed, sk_bashing, sk_cutting, sk_stabbing,
 // Combat
- sk_throw, sk_gun, sk_pistol, sk_shotgun, sk_smg, sk_rifle,
+ sk_throw, sk_gun, sk_pistol, sk_shotgun, sk_smg, sk_rifle, sk_archery,
+  sk_launcher,
 // Crafting
  sk_mechanics, sk_electronics, sk_cooking, sk_tailor, sk_carpentry,
 // Medical
@@ -16,7 +17,7 @@ enum skill {
 // Social
  sk_speech, sk_barter,
 // Other
- sk_computer, sk_butcher, sk_traps, sk_swimming,
+ sk_computer, sk_survival, sk_traps, sk_swimming,
  num_skill_types	// MUST be last!
 };
 
